@@ -1,6 +1,7 @@
 #!/usr/bin/ruby
 
-require 'ERB'
+require 'rubygems' # needed for Ruby 1.8
+require 'plist'
 
 $osgLibs = ['osgFX', 'osgParticle', 'osg', 'osgGA', 'osgText', 'osgUtil', 'osgSim', 'osgViewer', 'osgDB']
 $osgPlugins = ['ac', 'osg', 'freetype', 'imageio', 'rgb', 'txf', 'mdl', '3ds', 'dds']
@@ -20,19 +21,15 @@ puts "Code signing identity is #{$codeSignIdentity}"
 
 puts "osgVersion=#{osgVersion}, so-number=#{$osgSoVersion}"
 
-$svnLibs = ['svn_client', 'svn_wc', 'svn_delta', 'svn_diff', 'svn_ra', 
-  'svn_ra_local', 'svn_repos', 'svn_fs', 'svn_fs_fs', 'svn_fs_util',
-  'svn_ra_svn', 'svn_subr', 'svn_ra_neon']
-
 def fix_install_names(object)
-  #puts "fixing install names for #{object}"
-  
+  puts "fixing install names for #{object}"
+
   $osgLibs.each do |l|
     oldName = "lib#{l}.#{$osgSoVersion}.dylib"
     newName = "@executable_path/../Frameworks/#{oldName}"
     `install_name_tool -change #{oldName} #{newName} #{object}`
   end
-  
+
   oldName = "libOpenThreads.#{$openThreadsSoVersion}.dylib"
   newName= "@executable_path/../Frameworks/#{oldName}"
   `install_name_tool -change #{oldName} #{newName} #{object}`
@@ -46,6 +43,16 @@ puts "Erasing previous image dir"
 `rm -rf #{dmgDir}`
 
 bundle=dmgDir + "/FlightGear.app"
+
+# run macdeployt before we rename the bundle, otherwise it
+# can't find the bundle executable
+puts "Running macdeployqt on the bundle to copy Qt libraries"
+`macdeployqt #{$prefixDir}/fgfs.app`
+
+puts "Moving & renaming app bundle"
+`mkdir -p #{dmgDir}`
+`mv #{$prefixDir}/fgfs.app #{bundle}`
+
 contents=bundle + "/Contents"
 macosDir=contents + "/MacOS"
 $frameworksDir=contents +"/Frameworks"
@@ -53,25 +60,6 @@ resourcesDir=contents+"/Resources"
 osgPluginsDir=contents+"/PlugIns/osgPlugins-#{osgVersion}"
 volName="\"FlightGear Nightly Build\""
 
-def fix_svn_install_names(object)
-  $svnLibs.each do |l|
-    fileName = "lib#{l}-1.0.dylib"
-    newName = "@executable_path/../Frameworks/#{fileName}"
-    `install_name_tool -change #{fileName} #{newName} #{object}`
-  end
-end
-
-def copy_svn_libs()
-  puts "Copying Subversion client libraries"
-  $svnLibs.each do |l|
-    libFile = "lib#{l}-1.0.dylib"
-    path = "#{$frameworksDir}/#{libFile}"
-    `cp #{$prefixDir}/lib/#{libFile} #{$frameworksDir}`
-    fix_svn_install_names(path)
-   # `install_name_tool -id #{libFile}  #{path}`    
-  end
-end
-
 def code_sign(path)
   puts "Signing #{path}"
   `codesign -s "#{$codeSignIdentity}" #{path}`
@@ -82,22 +70,23 @@ fgVersion = File.read("#{srcDir}/version").strip
 dmgPath = Dir.pwd + "/fg_mac_nightly_#{fgVersion}.dmg"
 
 puts "Creating directory structure"
-`mkdir -p #{macosDir}`
 `mkdir -p #{$frameworksDir}`
 `mkdir -p #{resourcesDir}`
 `mkdir -p #{osgPluginsDir}`
 
-puts "Copying binaries"
-bins = ['fgfs', 'fgjs', 'fgcom']
+# fix install names on the primary executable
+fix_install_names("#{macosDir}/fgfs")
+
+puts "Copying auxilliary binaries"
+bins = ['fgjs', 'fgcom']
 bins.each do |b|
   if !File.exist?("#{$prefixDir}/bin/#{b}")
     next
   end
-  
+
   outPath = "#{macosDir}/#{b}"
   `cp #{$prefixDir}/bin/#{b} #{outPath}`
   fix_install_names(outPath)
-  fix_svn_install_names(outPath)
 end
 
 puts "copying libraries"
@@ -117,35 +106,16 @@ $osgPlugins.each do |p|
   fix_install_names("#{osgPluginsDir}/#{pluginFile}")
 end
 
-copy_svn_libs()
-
-# Info.plist
-template = File.read("#{srcDir}/package/mac/nightly.plist.in")
-output = ERB.new(template).result(binding)
-
-File.open("#{contents}/Info.plist", 'w') { |f|
-  f.write(output)
-}
-
 `cp #{srcDir}/package/mac/nightly-readme.rtf #{dmgDir}/ReadMe.rtf`
 `cp #{srcDir}/package/mac/FlightGear.icns #{resourcesDir}/FlightGear.icns`
 `cp #{srcDir}/COPYING #{dmgDir}`
 
-# Macflightgear launcher
-if File.exist?("FlightGearOSX")
-  puts "Copying Macflightgear launcher files"
-  Dir.chdir "FlightGearOSX" do
-    `cp FlightGear #{macosDir}`
-    `rsync -a *.rb *.lproj *.sh *.tiff #{resourcesDir}`
-  end
-end
-
 if File.exist?("#{$prefixDir}/share/flightgear")
   puts "Copying FGCom data files"
   `ditto #{$prefixDir}/share/flightgear #{resourcesDir}`
 end
 
-# code sign all executables in MacOS dir. Do this last since reource
+# code sign all executables in MacOS dir. Do this last since resource
 # changes will invalidate the signature!
 Dir.foreach(macosDir) do |b|
     if b == '.' or b == '..' then
@@ -158,5 +128,5 @@ puts "Creating DMG"
 
 createArgs = "-format UDBZ -imagekey bzip2-level=9 -quiet -volname #{volName}"
 
-`rm #{dmgPath}`
+`rm -f #{dmgPath}`
 `hdiutil create -srcfolder #{dmgDir} #{createArgs} #{dmgPath}`
