@@ -62,7 +62,9 @@ public:
     FGAIModelData(SGPropertyNode *root = NULL)
         : _nasal( new FGNasalModelDataProxy(root) ),
         _ready(false),
-        _initialized(false)
+        _initialized(false),
+        _hasInteriorPath(false),
+        _interiorLoaded(false)
     {
     }
 
@@ -80,6 +82,11 @@ public:
         if (_ready)
             return;
         
+        if(prop->hasChild("interior-path")){
+            _interiorPath = prop->getStringValue("interior-path");
+            _hasInteriorPath = true;
+        }
+
         _fxpath = prop->getStringValue("sound/path");
         _nasal->modelLoaded(path, prop, n);
         
@@ -94,12 +101,21 @@ public:
     bool needInitilization(void) { return _ready && !_initialized;}
     bool isInitialized(void) { return _initialized;}
     inline std::string& get_sound_path() { return _fxpath;}
+
+    void setInteriorLoaded(const bool state) { _interiorLoaded = state;}
+    bool getInteriorLoaded(void) { return _interiorLoaded;}
+    bool hasInteriorPath(void) { return _hasInteriorPath;}
+    inline std::string& getInteriorPath() { return _interiorPath; }
     
 private:
     std::auto_ptr<FGNasalModelDataProxy> _nasal;
     std::string _fxpath;
     bool _ready;
     bool _initialized;
+
+    std::string _interiorPath;
+    bool _hasInteriorPath;
+    bool _interiorLoaded;
 };
 
 FGAIBase::FGAIBase(object_type ot, bool enableHot) :
@@ -207,7 +223,7 @@ FGAIBase::removeModel()
     if (pSceneryManager)
     {
         osg::ref_ptr<osg::Object> temp = _model.get();
-        pSceneryManager->get_scene_graph()->removeChild(aip.getSceneGraph());
+        pSceneryManager->get_models_branch()->removeChild(aip.getSceneGraph());
         // withdraw from SGModelPlacement and drop own reference (unref)
         aip.clear();
         _modeldata = 0;
@@ -293,13 +309,36 @@ void FGAIBase::update(double dt) {
             }
         }
     }
+
+    updateInterior();
+}
+
+void FGAIBase::updateInterior()
+{
+    if(!_modeldata || !_modeldata->hasInteriorPath())
+        return;
+
+    if(!_modeldata->getInteriorLoaded()){ // interior is not yet load
+        double d2 = dist(SGVec3d::fromGeod(pos), globals->get_aircraft_position_cart());
+        if(d2 <= _maxRangeInterior){ // if the AI is in-range we load the interior
+            _interior = SGModelLib::loadPagedModel(_modeldata->getInteriorPath(), props, _modeldata);
+            if(_interior.valid()){
+                _interior->setRange(0, 0.0, _maxRangeInterior);
+                aip.add(_interior.get());
+                _modeldata->setInteriorLoaded(true);
+                SG_LOG(SG_AI, SG_INFO, "AIBase: Loaded interior model " << _interior->getName());
+            }
+        }
+    }
 }
 
 /** update LOD properties of the model */
 void FGAIBase::updateLOD()
 {
     double maxRangeDetail = fgGetDouble("/sim/rendering/static-lod/ai-detailed", 10000.0);
-    double maxRangeBare   = fgGetDouble("/sim/rendering/static-lod/ai-bare", 20000.0);
+//    double maxRangeBare   = fgGetDouble("/sim/rendering/static-lod/ai-bare", 20000.0);
+
+    _maxRangeInterior     = fgGetDouble("/sim/rendering/static-lod/ai-interior", 50.0);
     if (_model.valid())
     {
         if( maxRangeDetail == 0.0 )
@@ -310,8 +349,14 @@ void FGAIBase::updateLOD()
         }
         else
         {
-            _model->setRange(0, 0.0, maxRangeDetail);
-            _model->setRange(1, maxRangeDetail,maxRangeBare);
+            if( fgGetBool("/sim/rendering/static-lod/ai-range-mode-pixel", false ) ) 
+            {
+                _model->setRangeMode( osg::LOD::PIXEL_SIZE_ON_SCREEN );
+                _model->setRange(0, maxRangeDetail, 100000 );
+            } else {
+                _model->setRangeMode( osg::LOD:: DISTANCE_FROM_EYE_POINT);
+                _model->setRange(0, 0.0, maxRangeDetail);
+            }
         }
     }
 }
@@ -364,27 +409,27 @@ bool FGAIBase::init(bool search_in_AI_path)
     else
         _installed = true;
 
+    props->addChild("type")->setStringValue("AI");
     _modeldata = new FGAIModelData(props);
-    osg::Node * mdl = SGModelLib::loadDeferredModel(f, props, _modeldata);
+    _model= SGModelLib::loadPagedModel(f, props, _modeldata);
 
-    _model = new osg::LOD;
     _model->setName("AI-model range animation node");
 
-    _model->addChild( mdl, 0, FLT_MAX );
-    _model->setCenterMode(osg::LOD::USE_BOUNDING_SPHERE_CENTER);
-    _model->setRangeMode(osg::LOD::DISTANCE_FROM_EYE_POINT);
+  //  _model->setCenterMode(osg::LOD::USE_BOUNDING_SPHERE_CENTER);
+  //  _model->setRangeMode(osg::LOD::DISTANCE_FROM_EYE_POINT);
+  
 //    We really need low-resolution versions of AI/MP aircraft.
 //    Or at least dummy "stubs" with some default silhouette.
 //        _model->addChild( SGModelLib::loadPagedModel(fgGetString("/sim/multiplay/default-model", default_model),
 //                                                    props, new FGNasalModelData(props)), FLT_MAX, FLT_MAX);
     updateLOD();
-
-    initModel(mdl);
+    initModel();
+  
     if (_model.valid() && _initialized == false) {
         aip.init( _model.get() );
         aip.setVisible(true);
         invisible = false;
-        globals->get_scenery()->get_scene_graph()->addChild(aip.getSceneGraph());
+        globals->get_scenery()->get_models_branch()->addChild(aip.getSceneGraph());
         _initialized = true;
 
         SG_LOG(SG_AI, SG_DEBUG, "AIBase: Loaded model " << model_path);
@@ -399,7 +444,7 @@ bool FGAIBase::init(bool search_in_AI_path)
     return true;
 }
 
-void FGAIBase::initModel(osg::Node *node)
+void FGAIBase::initModel()
 {
     if (_model.valid()) { 
 
