@@ -1409,9 +1409,9 @@ void FGStartupController::render(bool visible)
                     //osg::Node *custom_obj;
                     SGMaterial *mat;
                     if (segment->hasBlock(now)) {
-                        mat = matlib->find("UnidirectionalTaperRed");
+                        mat = matlib->find("UnidirectionalTaperRed", center);
                     } else {
-                        mat = matlib->find("UnidirectionalTaperGreen");
+                        mat = matlib->find("UnidirectionalTaperGreen", center);
                     }
                     if (mat)
                         geode->setEffect(mat->get_effect());
@@ -1487,9 +1487,9 @@ void FGStartupController::render(bool visible)
                         //osg::Node *custom_obj;
                         SGMaterial *mat;
                         if (segment->hasBlock(now)) {
-                            mat = matlib->find("UnidirectionalTaperRed");
+                            mat = matlib->find("UnidirectionalTaperRed", segCenter);
                         } else {
-                            mat = matlib->find("UnidirectionalTaperGreen");
+                            mat = matlib->find("UnidirectionalTaperGreen", segCenter);
                         }
                         if (mat)
                             geode->setEffect(mat->get_effect());
