@@ -33,16 +33,18 @@ void FGTaxiNode::setElevation(double val)
 
 double FGTaxiNode::getElevationFt()
 {
-  if (mPosition.getElevationFt() == 0.0) {
-    SGGeod center2 = mPosition;
+  const SGGeod& pos = geod();
+  if( pos.getElevationFt() == 0.0)
+  {
+    SGGeod center2 = pos;
     FGScenery* local_scenery = globals->get_scenery();
     center2.setElevationM(SG_MAX_ELEVATION_M);
     double elevationEnd = -100;
-    if (local_scenery->get_elevation_m( center2, elevationEnd, NULL )) {
-      
-      SGGeod newPos = mPosition;
+    if (local_scenery->get_elevation_m( center2, elevationEnd, NULL ))
+    {
+      SGGeod newPos = pos;
       newPos.setElevationM(elevationEnd);
-    // this will call modifyPosition to update mPosition
+      // this will call modifyPosition to update mPosition
       NavDataCache* cache = NavDataCache::instance();
       NavDataCache::Transaction txn(cache);
       cache->updatePosition(guid(), newPos);
@@ -50,7 +52,7 @@ double FGTaxiNode::getElevationFt()
     }
   }
   
-  return mPosition.getElevationFt();
+  return pos.getElevationFt();
 }
 
 double FGTaxiNode::getElevationM()
