@@ -26,34 +26,31 @@
 //
 
 #include "digitalfilter.hxx"
-#include "functor.hxx"
 #include <deque>
 
-using std::map;
-using std::string;
-using std::endl;
-using std::cout;
-
-namespace FGXMLAutopilot {
+namespace FGXMLAutopilot
+{
 
 /**
  *
  *
  */
-class DigitalFilterImplementation : public SGReferenced {
-protected:
-  virtual bool configure( const std::string & nodeName, SGPropertyNode_ptr configNode) = 0;
-public:
-  virtual ~DigitalFilterImplementation() {}
-  DigitalFilterImplementation();
-  virtual void   initialize( double initvalue ) {}
-  virtual double compute( double dt, double input ) = 0;
-  bool configure( SGPropertyNode_ptr configNode );
+class DigitalFilterImplementation:
+  public SGReferenced
+{
+  public:
+    virtual ~DigitalFilterImplementation() {}
+    DigitalFilterImplementation();
+    virtual void   initialize( double initvalue ) {}
+    virtual double compute( double dt, double input ) = 0;
+    virtual bool configure( SGPropertyNode& cfg_node,
+                            const std::string& cfg_name,
+                            SGPropertyNode& prop_root ) = 0;
 
-  void setDigitalFilter( DigitalFilter * digitalFilter ) { _digitalFilter = digitalFilter; }
+    void setDigitalFilter( DigitalFilter * digitalFilter ) { _digitalFilter = digitalFilter; }
 
-protected:
-  DigitalFilter * _digitalFilter;
+  protected:
+    DigitalFilter * _digitalFilter;
 };
 
 /* --------------------------------------------------------------------------------- */
@@ -61,7 +58,9 @@ protected:
 class GainFilterImplementation : public DigitalFilterImplementation {
 protected:
   InputValueList _gainInput;
-  bool configure( const std::string & nodeName, SGPropertyNode_ptr configNode );
+  bool configure( SGPropertyNode& cfg_node,
+                  const std::string& cfg_name,
+                  SGPropertyNode& prop_root );
 public:
   GainFilterImplementation() : _gainInput(1.0) {}
   double compute(  double dt, double input );
@@ -75,7 +74,9 @@ public:
 class DerivativeFilterImplementation : public GainFilterImplementation {
   InputValueList _TfInput;
   double _input_1;
-  bool configure( const std::string & nodeName, SGPropertyNode_ptr configNode );
+  bool configure( SGPropertyNode& cfg_node,
+                  const std::string& cfg_name,
+                  SGPropertyNode& prop_root );
 public:
   DerivativeFilterImplementation();
   double compute(  double dt, double input );
@@ -85,7 +86,9 @@ public:
 class ExponentialFilterImplementation : public GainFilterImplementation {
 protected:
   InputValueList _TfInput;
-  bool configure( const std::string & nodeName, SGPropertyNode_ptr configNode );
+  bool configure( SGPropertyNode& cfg_node,
+                  const std::string& cfg_name,
+                  SGPropertyNode& prop_root );
   bool _isSecondOrder;
   double _output_1, _output_2;
 public:
@@ -99,7 +102,9 @@ protected:
   InputValueList _samplesInput;
   double _output_1;
   std::deque <double> _inputQueue;
-  bool configure( const std::string & nodeName, SGPropertyNode_ptr configNode );
+  bool configure( SGPropertyNode& cfg_node,
+                  const std::string& cfg_name,
+                  SGPropertyNode& prop_root );
 public:
   MovingAverageFilterImplementation();
   double compute(  double dt, double input );
@@ -110,7 +115,9 @@ class NoiseSpikeFilterImplementation : public DigitalFilterImplementation {
 protected:
   double _output_1;
   InputValueList _rateOfChangeInput;
-  bool configure( const std::string & nodeName, SGPropertyNode_ptr configNode );
+  bool configure( SGPropertyNode& cfg_node,
+                  const std::string& cfg_name,
+                  SGPropertyNode& prop_root );
 public:
   NoiseSpikeFilterImplementation();
   double compute(  double dt, double input );
@@ -122,7 +129,9 @@ protected:
   double _output_1;
   InputValueList _rateOfChangeMax;
   InputValueList _rateOfChangeMin ;
-  bool configure( const std::string & nodeName, SGPropertyNode_ptr configNode );
+  bool configure( SGPropertyNode& cfg_node,
+                  const std::string& cfg_name,
+                  SGPropertyNode& prop_root );
 public:
   RateLimitFilterImplementation();
   double compute(  double dt, double input );
@@ -136,7 +145,9 @@ protected:
   InputValueList _maxInput;
   double _input_1;
   double _output_1;
-  bool configure( const std::string & nodeName, SGPropertyNode_ptr configNode );
+  bool configure( SGPropertyNode& cfg_node,
+                  const std::string& cfg_name,
+                  SGPropertyNode& prop_root );
 public:
   IntegratorFilterImplementation();
   double compute(  double dt, double input );
@@ -148,7 +159,9 @@ protected:
   InputValueList _TfInput;
   double _input_1;
   double _output_1;
-  bool configure( const std::string & nodeName, SGPropertyNode_ptr configNode );
+  bool configure( SGPropertyNode& cfg_node,
+                  const std::string& cfg_name,
+                  SGPropertyNode& prop_root );
 public:
   HighPassFilterImplementation();
   double compute(  double dt, double input );
@@ -160,7 +173,9 @@ protected:
   InputValueList _TfbInput;
   double _input_1;
   double _output_1;
-  bool configure( const std::string & nodeName, SGPropertyNode_ptr configNode );
+  bool configure( SGPropertyNode& cfg_node,
+                  const std::string& cfg_name,
+                  SGPropertyNode& prop_root );
 public:
   LeadLagFilterImplementation();
   double compute(  double dt, double input );
@@ -173,41 +188,25 @@ public:
 
 using namespace FGXMLAutopilot;
 
-/* --------------------------------------------------------------------------------- */
-/* --------------------------------------------------------------------------------- */
+//------------------------------------------------------------------------------
 DigitalFilterImplementation::DigitalFilterImplementation() :
   _digitalFilter(NULL)
 {
+
 }
 
-bool DigitalFilterImplementation::configure( SGPropertyNode_ptr configNode )
-{
-  for (int i = 0; i < configNode->nChildren(); ++i ) {
-    SGPropertyNode_ptr prop;
-
-    SGPropertyNode_ptr child = configNode->getChild(i);
-    string cname(child->getName());
-
-    if( configure( cname, child ) )
-      continue;
-
-  } // for configNode->nChildren()
-
-  return true;
-}
-
-/* --------------------------------------------------------------------------------- */
-/* --------------------------------------------------------------------------------- */
-
+//------------------------------------------------------------------------------
 double GainFilterImplementation::compute(  double dt, double input )
 {
   return _gainInput.get_value() * input;
 }
 
-bool GainFilterImplementation::configure( const std::string & nodeName, SGPropertyNode_ptr configNode )
+bool GainFilterImplementation::configure( SGPropertyNode& cfg_node,
+                                          const std::string& cfg_name,
+                                          SGPropertyNode& prop_root )
 {
-  if (nodeName == "gain" ) {
-    _gainInput.push_back( new InputValue( configNode, 1 ) );
+  if (cfg_name == "gain" ) {
+    _gainInput.push_back( new InputValue(prop_root, cfg_node, 1) );
     return true;
   }
 
@@ -239,14 +238,16 @@ void DerivativeFilterImplementation::initialize( double initvalue )
   _input_1 = initvalue;
 }
 
-
-bool DerivativeFilterImplementation::configure( const std::string & nodeName, SGPropertyNode_ptr configNode )
+//------------------------------------------------------------------------------
+bool DerivativeFilterImplementation::configure( SGPropertyNode& cfg_node,
+                                                const std::string& cfg_name,
+                                                SGPropertyNode& prop_root )
 {
-  if( GainFilterImplementation::configure( nodeName, configNode ) )
+  if( GainFilterImplementation::configure(cfg_node, cfg_name, prop_root) )
     return true;
 
-  if (nodeName == "filter-time" ) {
-    _TfInput.push_back( new InputValue( configNode, 1 ) );
+  if (cfg_name == "filter-time" ) {
+    _TfInput.push_back( new InputValue(prop_root, cfg_node, 1) );
     return true;
   }
 
@@ -299,10 +300,12 @@ double MovingAverageFilterImplementation::compute(  double dt, double input )
   return output_0;
 }
 
-bool MovingAverageFilterImplementation::configure( const std::string & nodeName, SGPropertyNode_ptr configNode )
+bool MovingAverageFilterImplementation::configure( SGPropertyNode& cfg_node,
+                                                   const std::string& cfg_name,
+                                                   SGPropertyNode& prop_root )
 {
-  if (nodeName == "samples" ) {
-    _samplesInput.push_back( new InputValue( configNode, 1 ) );
+  if (cfg_name == "samples" ) {
+    _samplesInput.push_back( new InputValue(prop_root, cfg_node, 1) );
     return true;
   }
 
@@ -337,10 +340,13 @@ double NoiseSpikeFilterImplementation::compute(  double dt, double input )
     return (_output_1 = _output_1 + copysign( maxChange, delta ));
 }
 
-bool NoiseSpikeFilterImplementation::configure( const std::string & nodeName, SGPropertyNode_ptr configNode )
+//------------------------------------------------------------------------------
+bool NoiseSpikeFilterImplementation::configure( SGPropertyNode& cfg_node,
+                                                const std::string& cfg_name,
+                                                SGPropertyNode& prop_root )
 {
-  if (nodeName == "max-rate-of-change" ) {
-    _rateOfChangeInput.push_back( new InputValue( configNode, 1 ) );
+  if (cfg_name == "max-rate-of-change" ) {
+    _rateOfChangeInput.push_back( new InputValue(prop_root, cfg_node, 1) );
     return true;
   }
 
@@ -379,14 +385,17 @@ double RateLimitFilterImplementation::compute(  double dt, double input )
   return (output);
 }
 
-bool RateLimitFilterImplementation::configure( const std::string & nodeName, SGPropertyNode_ptr configNode )
+bool RateLimitFilterImplementation::configure( SGPropertyNode& cfg_node,
+                                               const std::string& cfg_name,
+                                               SGPropertyNode& prop_root )
 {
-  if (nodeName == "max-rate-of-change" ) {
-    _rateOfChangeMax.push_back( new InputValue( configNode, 1 ) );
+  std::cout << "RateLimitFilterImplementation " << cfg_name << std::endl;
+  if (cfg_name == "max-rate-of-change" ) {
+    _rateOfChangeMax.push_back( new InputValue(prop_root, cfg_node, 1) );
     return true;
   }
-  if (nodeName == "min-rate-of-change" ) {
-    _rateOfChangeMin.push_back( new InputValue( configNode, 1 ) );
+  if (cfg_name == "min-rate-of-change" ) {
+    _rateOfChangeMin.push_back( new InputValue(prop_root, cfg_node, 1) );
     return true;
   }
 
@@ -431,18 +440,21 @@ double ExponentialFilterImplementation::compute(  double dt, double input )
   return (_output_1 = output_0);
 }
 
-bool ExponentialFilterImplementation::configure( const std::string & nodeName, SGPropertyNode_ptr configNode )
+//------------------------------------------------------------------------------
+bool ExponentialFilterImplementation::configure( SGPropertyNode& cfg_node,
+                                                 const std::string& cfg_name,
+                                                 SGPropertyNode& prop_root )
 {
-  if( GainFilterImplementation::configure( nodeName, configNode ) )
+  if( GainFilterImplementation::configure(cfg_node, cfg_name, prop_root) )
     return true;
 
-  if (nodeName == "filter-time" ) {
-    _TfInput.push_back( new InputValue( configNode, 1 ) );
+  if (cfg_name == "filter-time" ) {
+    _TfInput.push_back( new InputValue(prop_root, cfg_node, 1) );
     return true;
   }
 
-  if (nodeName == "type" ) {
-    string type(configNode->getStringValue());
+  if (cfg_name == "type" ) {
+    std::string type(cfg_node.getStringValue());
     _isSecondOrder = type == "double-exponential";
   }
 
@@ -462,17 +474,20 @@ void IntegratorFilterImplementation::initialize( double initvalue )
   _input_1 = _output_1 = initvalue;
 }
 
-
-bool IntegratorFilterImplementation::configure( const std::string & nodeName, SGPropertyNode_ptr configNode )
+//------------------------------------------------------------------------------
+bool IntegratorFilterImplementation::configure( SGPropertyNode& cfg_node,
+                                                const std::string& cfg_name,
+                                                SGPropertyNode& prop_root )
 {
-  if( GainFilterImplementation::configure( nodeName, configNode ) )
+  if( GainFilterImplementation::configure(cfg_node, cfg_name, prop_root) )
     return true;
-  if (nodeName == "u_min" ) {
-    _minInput.push_back( new InputValue( configNode, 1 ) );
+
+  if (cfg_name == "u_min" ) {
+    _minInput.push_back( new InputValue(prop_root, cfg_node, 1) );
     return true;
   }
-  if (nodeName == "u_max" ) {
-    _maxInput.push_back( new InputValue( configNode, 1 ) );
+  if (cfg_name == "u_max" ) {
+    _maxInput.push_back( new InputValue(prop_root, cfg_node, 1) );
     return true;
   }
   return false;
@@ -523,13 +538,16 @@ double HighPassFilterImplementation::compute(  double dt, double input )
   return output;
 }
 
-bool HighPassFilterImplementation::configure( const std::string & nodeName, SGPropertyNode_ptr configNode )
+//------------------------------------------------------------------------------
+bool HighPassFilterImplementation::configure( SGPropertyNode& cfg_node,
+                                              const std::string& cfg_name,
+                                              SGPropertyNode& prop_root )
 {
-  if( GainFilterImplementation::configure( nodeName, configNode ) )
+  if( GainFilterImplementation::configure(cfg_node, cfg_name, prop_root) )
     return true;
 
-  if (nodeName == "filter-time" ) {
-    _TfInput.push_back( new InputValue( configNode, 1 ) );
+  if (cfg_name == "filter-time" ) {
+    _TfInput.push_back( new InputValue(prop_root, cfg_node, 1) );
     return true;
   }
  
@@ -570,24 +588,27 @@ double LeadLagFilterImplementation::compute(  double dt, double input )
   return output;
 }
 
-bool LeadLagFilterImplementation::configure( const std::string & nodeName, SGPropertyNode_ptr configNode )
+//------------------------------------------------------------------------------
+bool LeadLagFilterImplementation::configure( SGPropertyNode& cfg_node,
+                                             const std::string& cfg_name,
+                                             SGPropertyNode& prop_root )
 {
-  if( GainFilterImplementation::configure( nodeName, configNode ) )
+  if( GainFilterImplementation::configure(cfg_node, cfg_name, prop_root) )
     return true;
 
-  if (nodeName == "filter-time-a" ) {
-    _TfaInput.push_back( new InputValue( configNode, 1 ) );
+  if (cfg_name == "filter-time-a" ) {
+    _TfaInput.push_back( new InputValue(prop_root, cfg_node, 1) );
     return true;
   }
-  if (nodeName == "filter-time-b" ) {
-    _TfbInput.push_back( new InputValue( configNode, 1 ) );
+  if (cfg_name == "filter-time-b" ) {
+    _TfbInput.push_back( new InputValue(prop_root, cfg_node, 1) );
     return true;
   }
   return false;
 }
-/* --------------------------------------------------------------------------------- */
-/* Digital Filter Component Implementation                                           */
-/* --------------------------------------------------------------------------------- */
+/* -------------------------------------------------------------------------- */
+/* Digital Filter Component Implementation                                    */
+/* -------------------------------------------------------------------------- */
 
 DigitalFilter::DigitalFilter() :
     AnalogComponent(),
@@ -599,58 +620,96 @@ DigitalFilter::~DigitalFilter()
 {
 }
 
-
-static map<string,FunctorBase<DigitalFilterImplementation> *> componentForge;
-
-bool DigitalFilter::configure(const string& nodeName, SGPropertyNode_ptr configNode)
+//------------------------------------------------------------------------------
+template<class DigitalFilterType>
+DigitalFilterImplementation* digitalFilterFactory()
 {
-  if( componentForge.empty() ) {
-    componentForge["gain"] = new CreateAndConfigureFunctor<GainFilterImplementation,DigitalFilterImplementation>();
-    componentForge["exponential"] = new CreateAndConfigureFunctor<ExponentialFilterImplementation,DigitalFilterImplementation>();
-    componentForge["double-exponential"] = new CreateAndConfigureFunctor<ExponentialFilterImplementation,DigitalFilterImplementation>();
-    componentForge["moving-average"] = new CreateAndConfigureFunctor<MovingAverageFilterImplementation,DigitalFilterImplementation>();
-    componentForge["noise-spike"] = new CreateAndConfigureFunctor<NoiseSpikeFilterImplementation,DigitalFilterImplementation>();
-    componentForge["rate-limit"] = new CreateAndConfigureFunctor<RateLimitFilterImplementation,DigitalFilterImplementation>();
-    componentForge["reciprocal"] = new CreateAndConfigureFunctor<ReciprocalFilterImplementation,DigitalFilterImplementation>();
-    componentForge["derivative"] = new CreateAndConfigureFunctor<DerivativeFilterImplementation,DigitalFilterImplementation>();
-    componentForge["high-pass"] = new CreateAndConfigureFunctor<HighPassFilterImplementation,DigitalFilterImplementation>();
-    componentForge["lead-lag"] = new CreateAndConfigureFunctor<LeadLagFilterImplementation,DigitalFilterImplementation>();
-    componentForge["integrator"] = new CreateAndConfigureFunctor<IntegratorFilterImplementation,DigitalFilterImplementation>();
-  }
-
-  SG_LOG( SG_AUTOPILOT, SG_BULK, "DigitalFilter::configure(" << nodeName << ")" << endl );
-  if( AnalogComponent::configure( nodeName, configNode ) )
-    return true;
-
-  if (nodeName == "type" ) {
-    string type( configNode->getStringValue() );
-    if( componentForge.count(type) == 0 ) {
-      SG_LOG( SG_AUTOPILOT, SG_BULK, "unhandled filter type <" << type << ">" << endl );
-      return true;
-    }
-    _implementation = (*componentForge[type])( configNode->getParent() );
-    _implementation->setDigitalFilter( this );
-    return true;
-  }
-
-  if( nodeName == "initialize-to" ) {
-    string s( configNode->getStringValue() );
-    if( s == "input" ) {
-      _initializeTo = INITIALIZE_INPUT;
-    } else if( s == "output" ) {
-      _initializeTo = INITIALIZE_OUTPUT;
-    } else if( s == "none" ) {
-      _initializeTo = INITIALIZE_NONE;
-    } else {
-      SG_LOG( SG_AUTOPILOT, SG_WARN, "unhandled initialize-to value '" << s << "' ignored" );
-    }
-    return true;
-  }
-
-  SG_LOG( SG_AUTOPILOT, SG_BULK, "DigitalFilter::configure(" << nodeName << ") [unhandled]" << endl );
-  return false; // not handled by us, let the base class try
+  return new DigitalFilterType();
 }
 
+typedef std::map<std::string, DigitalFilterImplementation*(*)()>
+DigitalFilterMap;
+static DigitalFilterMap componentForge;
+
+//------------------------------------------------------------------------------
+bool DigitalFilter::configure( SGPropertyNode& prop_root,
+                               SGPropertyNode& cfg )
+{
+  if( componentForge.empty() )
+  {
+    componentForge["gain"               ] = digitalFilterFactory<GainFilterImplementation>;
+    componentForge["exponential"        ] = digitalFilterFactory<ExponentialFilterImplementation>;
+    componentForge["double-exponential" ] = digitalFilterFactory<ExponentialFilterImplementation>;
+    componentForge["moving-average"     ] = digitalFilterFactory<MovingAverageFilterImplementation>;
+    componentForge["noise-spike"        ] = digitalFilterFactory<NoiseSpikeFilterImplementation>;
+    componentForge["rate-limit"         ] = digitalFilterFactory<RateLimitFilterImplementation>;
+    componentForge["reciprocal"         ] = digitalFilterFactory<ReciprocalFilterImplementation>;
+    componentForge["derivative"         ] = digitalFilterFactory<DerivativeFilterImplementation>;
+    componentForge["high-pass"          ] = digitalFilterFactory<HighPassFilterImplementation>;
+    componentForge["lead-lag"           ] = digitalFilterFactory<LeadLagFilterImplementation>;
+    componentForge["integrator"         ] = digitalFilterFactory<IntegratorFilterImplementation>;
+  }
+
+  const std::string type = cfg.getStringValue("type");
+  DigitalFilterMap::iterator component_factory = componentForge.find(type);
+  if( component_factory == componentForge.end() )
+  {
+    SG_LOG(SG_AUTOPILOT, SG_WARN, "unhandled filter type '" << type << "'");
+    return false;
+  }
+
+  _implementation = (*component_factory->second)();
+  _implementation->setDigitalFilter( this );
+
+  for( int i = 0; i < cfg.nChildren(); ++i )
+  {
+    SGPropertyNode_ptr child = cfg.getChild(i);
+    std::string cname(child->getName());
+
+    if(    !_implementation->configure(*child, cname, prop_root)
+        && !configure(*child, cname, prop_root)
+        && cname != "type"
+        && cname != "params" ) // 'params' is usually used to specify parameters
+                               // in PropertList files.
+      SG_LOG
+      (
+        SG_AUTOPILOT,
+        SG_WARN,
+        "DigitalFilter: unknown config node: " << cname
+      );
+  }
+
+  return true;
+}
+
+//------------------------------------------------------------------------------
+bool DigitalFilter::configure( SGPropertyNode& cfg_node,
+                               const std::string& cfg_name,
+                               SGPropertyNode& prop_root )
+{
+  if( cfg_name == "initialize-to" )
+  {
+    std::string s( cfg_node.getStringValue() );
+    if( s == "input" )
+      _initializeTo = INITIALIZE_INPUT;
+    else if( s == "output" )
+      _initializeTo = INITIALIZE_OUTPUT;
+    else if( s == "none" )
+      _initializeTo = INITIALIZE_NONE;
+    else
+      SG_LOG
+      (
+        SG_AUTOPILOT,
+        SG_WARN, "DigitalFilter: initialize-to (" << s << ") ignored"
+      );
+
+    return true;
+  }
+
+  return AnalogComponent::configure(cfg_node, cfg_name, prop_root);
+}
+
+//------------------------------------------------------------------------------
 void DigitalFilter::update( bool firstTime, double dt)
 {
   if( _implementation == NULL ) return;
@@ -680,7 +739,7 @@ void DigitalFilter::update( bool firstTime, double dt)
   set_output_value( output );
 
   if(_debug) {
-    cout << "input:" << input
-         << "\toutput:" << output << endl;
+    std::cout << "input:" << input
+              << "\toutput:" << output << std::endl;
   }
 }
