@@ -20,6 +20,7 @@
 
 #include <Main/globals.hxx>
 #include <Main/util.hxx>
+#include <Network/HTTPClient.hxx>
 #include <Viewer/renderer.hxx>
 
 #include <osgDB/ReadFile>
@@ -98,4 +99,26 @@ namespace canvas
     return 0;
   }
 
+  //----------------------------------------------------------------------------
+  SGSubsystem*
+  FGCanvasSystemAdapter::getSubsystem(const std::string& name) const
+  {
+    return globals->get_subsystem(name.c_str());
+  }
+
+  //----------------------------------------------------------------------------
+  simgear::HTTP::Client* FGCanvasSystemAdapter::getHTTPClient() const
+  {
+    FGHTTPClient* http =
+      static_cast<FGHTTPClient*>(globals->get_subsystem("http"));
+
+    if( http )
+      return http->client();
+
+    SG_LOG( SG_IO,
+            SG_ALERT,
+            "FGCanvasSystemAdapter: Failed to get HTTP subsystem" );
+    return 0;
+  }
+
 }
