@@ -17,7 +17,6 @@
 // Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
 #include "gui_mgr.hxx"
-#include <Canvas/window.hxx>
 
 #include <Main/fg_os.hxx>
 #include <Main/fg_props.hxx>
@@ -27,6 +26,8 @@
 
 #include <simgear/canvas/Canvas.hxx>
 #include <simgear/canvas/CanvasPlacement.hxx>
+#include <simgear/canvas/CanvasWindow.hxx>
+#include <simgear/canvas/events/KeyboardEvent.hxx>
 #include <simgear/scene/util/OsgMath.hxx>
 
 #include <osg/BlendFunc>
@@ -37,8 +38,10 @@
 #include <boost/lexical_cast.hpp>
 
 class DesktopGroup;
-typedef boost::shared_ptr<DesktopGroup> DesktopPtr;
-typedef boost::weak_ptr<DesktopGroup> DesktopWeakPtr;
+typedef SGSharedPtr<DesktopGroup> DesktopPtr;
+typedef SGWeakPtr<DesktopGroup> DesktopWeakPtr;
+
+namespace sc = simgear::canvas;
 
 /**
  * Event handler
@@ -62,12 +65,12 @@ class GUIEventHandler:
  * Track a canvas placement on a window
  */
 class WindowPlacement:
-  public simgear::canvas::Placement
+  public sc::Placement
 {
   public:
     WindowPlacement( SGPropertyNode* node,
-                     canvas::WindowPtr window,
-                     simgear::canvas::CanvasPtr canvas ):
+                     sc::WindowPtr window,
+                     sc::CanvasPtr canvas ):
       Placement(node),
       _window(window),
       _canvas(canvas)
@@ -78,26 +81,32 @@ class WindowPlacement:
      */
     virtual ~WindowPlacement()
     {
-      canvas::WindowPtr window = _window.lock();
-      simgear::canvas::CanvasPtr canvas = _canvas.lock();
+      sc::WindowPtr window = _window.lock();
+      sc::CanvasPtr canvas = _canvas.lock();
 
       if( window && canvas && canvas == window->getCanvasContent().lock() )
-        window->setCanvasContent( simgear::canvas::CanvasPtr() );
+        window->setCanvasContent( sc::CanvasPtr() );
     }
 
   private:
-    canvas::WindowWeakPtr _window;
-    simgear::canvas::CanvasWeakPtr _canvas;
+    sc::WindowWeakPtr _window;
+    sc::CanvasWeakPtr _canvas;
 };
 
 /**
  * Desktop root group
  */
 class DesktopGroup:
-  public simgear::canvas::Group
+  public sc::Group
 {
   public:
     DesktopGroup();
+
+    void setFocusWindow(const sc::WindowPtr& window);
+
+    bool grabPointer(const sc::WindowPtr& window);
+    void ungrabPointer(const sc::WindowPtr& window);
+
     bool handleEvent(const osgGA::GUIEventAdapter& ea);
 
   protected:
@@ -110,9 +119,12 @@ class DesktopGroup:
     simgear::PropertyObject<int>        _width,
                                         _height;
 
-    canvas::WindowWeakPtr _last_push,
-                          _last_mouse_over,
-                          _resize_window;
+    sc::WindowWeakPtr _last_push,
+                      _last_mouse_over,
+                      _resize_window,
+                      _focus_window,
+                      _pointer_grab_window;
+
     uint8_t _resize;
     int     _last_cursor;
 
@@ -121,18 +133,26 @@ class DesktopGroup:
           _last_y;
     double _last_scroll_time;
 
+    uint32_t _last_key_down_no_mod; // Key repeat for non modifier keys
+
     bool handleMouse(const osgGA::GUIEventAdapter& ea);
+    bool handleKeyboard(const osgGA::GUIEventAdapter& ea);
+
+    bool handleEvent( const sc::EventPtr& event,
+                      const sc::WindowPtr& active_window );
+    bool handleRootEvent(const sc::EventPtr& event);
+
     void handleResize(int x, int y, int width, int height);
     void handleMouseMode(SGPropertyNode* node);
 
     /**
      *
      */
-    simgear::canvas::ElementFactory
+    sc::ElementFactory
     getChildFactory(const std::string& type) const
     {
       if( type == "window" )
-        return &Element::create<canvas::Window>;
+        return &Element::create<sc::Window>;
 
       return Group::getChildFactory(type);
     }
@@ -160,18 +180,19 @@ bool GUIEventHandler::handle( const osgGA::GUIEventAdapter& ea,
 
 //------------------------------------------------------------------------------
 DesktopGroup::DesktopGroup():
-  Group(simgear::canvas::CanvasPtr(), fgGetNode("/sim/gui/canvas", true)),
+  Group(sc::CanvasPtr(), fgGetNode("/sim/gui/canvas", true)),
   _cb_mouse_mode( this,
                   &DesktopGroup::handleMouseMode,
                   fgGetNode("/devices/status/mice/mouse[0]/mode") ),
   _handle_events(true),
   _width(_node, "size[0]"),
   _height(_node, "size[1]"),
-  _resize(canvas::Window::NONE),
+  _resize(sc::Window::NONE),
   _last_cursor(MOUSE_CURSOR_NONE),
   _last_x(-1),
   _last_y(-1),
-  _last_scroll_time(0)
+  _last_scroll_time(0),
+  _last_key_down_no_mod(-1)
 {
   osg::Camera* camera =
     flightgear::getGUICamera( flightgear::CameraGroup::getDefault() );
@@ -194,14 +215,35 @@ DesktopGroup::DesktopGroup():
   stateSet->setMode(GL_DEPTH_TEST, osg::StateAttribute::OFF);
 
   _width = _height = -1;
+}
 
-  // Do not change values on reinit
-  _width.node()->setAttribute(SGPropertyNode::PRESERVE, true);
-  _height.node()->setAttribute(SGPropertyNode::PRESERVE, true);
+//------------------------------------------------------------------------------
+void DesktopGroup::setFocusWindow(const sc::WindowPtr& window)
+{
+  _focus_window = window;
+}
 
-  // Do not restore windows on reinit (all windows will need to be recreated,
-  // but hey it's a reset ;-))
-  _node->setAttribute(SGPropertyNode::PRESERVE, true);
+//------------------------------------------------------------------------------
+bool DesktopGroup::grabPointer(const sc::WindowPtr& window)
+{
+  sc::WindowPtr resize = _resize_window.lock();
+  if( (resize && resize != window) || !_pointer_grab_window.expired() )
+    // Already grabbed (resize -> implicit grab)
+    return false;
+
+  _pointer_grab_window = window;
+  return true;
+}
+
+//------------------------------------------------------------------------------
+void DesktopGroup::ungrabPointer(const sc::WindowPtr& window)
+{
+  if( _pointer_grab_window.expired() )
+    SG_LOG(SG_GUI, SG_WARN, "ungrabPointer: no active grab.");
+  else if( window != _pointer_grab_window.lock() )
+    SG_LOG(SG_GUI, SG_WARN, "ungrabPointer: window is not owner of the grab.");
+  else
+    _pointer_grab_window.reset();
 }
 
 //------------------------------------------------------------------------------
@@ -217,6 +259,9 @@ bool DesktopGroup::handleEvent(const osgGA::GUIEventAdapter& ea)
     case osgGA::GUIEventAdapter::MOVE:
     case osgGA::GUIEventAdapter::SCROLL:
       return handleMouse(ea);
+    case osgGA::GUIEventAdapter::KEYDOWN:
+    case osgGA::GUIEventAdapter::KEYUP:
+      return handleKeyboard(ea);
     case osgGA::GUIEventAdapter::RESIZE:
       handleResize( ea.getWindowX(),
                     ea.getWindowY(),
@@ -253,7 +298,6 @@ bool DesktopGroup::handleMouse(const osgGA::GUIEventAdapter& ea)
   if( !_transform->getNumChildren() || !_handle_events )
     return false;
 
-  namespace sc = simgear::canvas;
   sc::MouseEventPtr event(new sc::MouseEvent(ea));
 
   event->screen_pos.x() = 0.5 * (ea.getXnormalized() + 1) * _width + 0.5;
@@ -275,7 +319,7 @@ bool DesktopGroup::handleMouse(const osgGA::GUIEventAdapter& ea)
     switch( ea.getEventType() )
     {
       case osgGA::GUIEventAdapter::RELEASE:
-        _resize_window.lock()->handleResize(canvas::Window::NONE);
+        _resize_window.lock()->handleResize(sc::Window::NONE);
         _resize_window.reset();
         break;
       case osgGA::GUIEventAdapter::DRAG:
@@ -287,30 +331,35 @@ bool DesktopGroup::handleMouse(const osgGA::GUIEventAdapter& ea)
     }
   }
 
-  canvas::WindowPtr window_at_cursor;
-  for( int i = _transform->getNumChildren() - 1; i >= 0; --i )
+  sc::WindowPtr window_at_cursor = _pointer_grab_window.lock();
+  if( !window_at_cursor )
   {
-    osg::Group *element = _transform->getChild(i)->asGroup();
-
-    assert(element);
-    assert(element->getUserData());
-
-    canvas::WindowPtr window =
-      boost::dynamic_pointer_cast<canvas::Window>
-      (
-        static_cast<sc::Element::OSGUserData*>(element->getUserData())->element
-      );
-
-    if( !window || !window->isCapturingEvents() || !window->isVisible() )
-      continue;
-
-    float margin = window->isResizable() ? resize_margin_pos : 0;
-    if( window->getScreenRegion().contains( event->getScreenX(),
-                                            event->getScreenY(),
-                                            margin ) )
+    for( int i = _transform->getNumChildren() - 1; i >= 0; --i )
     {
-      window_at_cursor = window;
-      break;
+      osg::Group *element = _transform->getChild(i)->asGroup();
+
+      assert(element);
+      assert(element->getUserData());
+
+      sc::WindowPtr window =
+        dynamic_cast<sc::Window*>
+        (
+          static_cast<sc::Element::OSGUserData*>(
+            element->getUserData()
+          )->element.get()
+        );
+
+      if( !window || !window->isCapturingEvents() || !window->isVisible() )
+        continue;
+
+      float margin = window->isResizable() ? resize_margin_pos : 0;
+      if( window->getScreenRegion().contains( event->getScreenX(),
+                                              event->getScreenY(),
+                                              margin ) )
+      {
+        window_at_cursor = window;
+        break;
+      }
     }
   }
 
@@ -333,14 +382,14 @@ bool DesktopGroup::handleMouse(const osgGA::GUIEventAdapter& ea)
       _resize = 0;
 
       if( event->getScreenX() <= reg.l() + resize_corner )
-        _resize |= canvas::Window::LEFT;
+        _resize |= sc::Window::LEFT;
       else if( event->getScreenX() >= reg.r() - resize_corner )
-        _resize |= canvas::Window::RIGHT;
+        _resize |= sc::Window::RIGHT;
 
       if( event->getScreenY() <= reg.t() + resize_corner )
-        _resize |= canvas::Window::TOP;
+        _resize |= sc::Window::TOP;
       else if( event->getScreenY() >= reg.b() - resize_corner )
-        _resize |= canvas::Window::BOTTOM;
+        _resize |= sc::Window::BOTTOM;
 
       static const int cursor_mapping[] =
       {
@@ -360,7 +409,7 @@ bool DesktopGroup::handleMouse(const osgGA::GUIEventAdapter& ea)
         _drag_start = event->screen_pos;
 
         window_at_cursor->raise();
-        window_at_cursor->handleResize(_resize | canvas::Window::INIT);
+        window_at_cursor->handleResize(_resize | sc::Window::INIT);
       }
 
       return true;
@@ -374,7 +423,7 @@ bool DesktopGroup::handleMouse(const osgGA::GUIEventAdapter& ea)
     return true;
   }
 
-  canvas::WindowPtr target_window = window_at_cursor;
+  sc::WindowPtr target_window = window_at_cursor;
   switch( ea.getEventType() )
   {
     case osgGA::GUIEventAdapter::PUSH:
@@ -405,7 +454,7 @@ bool DesktopGroup::handleMouse(const osgGA::GUIEventAdapter& ea)
       break;
     case osgGA::GUIEventAdapter::MOVE:
     {
-      canvas::WindowPtr last_mouse_over = _last_mouse_over.lock();
+      sc::WindowPtr last_mouse_over = _last_mouse_over.lock();
       if( last_mouse_over != window_at_cursor && last_mouse_over )
       {
         sc::MouseEventPtr move_event( new sc::MouseEvent(*event) );
@@ -423,7 +472,7 @@ bool DesktopGroup::handleMouse(const osgGA::GUIEventAdapter& ea)
     {
       event->type = sc::Event::MOUSE_UP;
 
-      canvas::WindowPtr last_push = _last_push.lock();
+      sc::WindowPtr last_push = _last_push.lock();
       _last_push.reset();
 
       if( last_push && last_push != target_window )
@@ -454,7 +503,66 @@ bool DesktopGroup::handleMouse(const osgGA::GUIEventAdapter& ea)
     return target_window->handleEvent(event);
   }
   else
+    return handleRootEvent(event);
+}
+
+//------------------------------------------------------------------------------
+bool DesktopGroup::handleKeyboard(const osgGA::GUIEventAdapter& ea)
+{
+  if( !_transform->getNumChildren() || !_handle_events )
     return false;
+
+  sc::KeyboardEventPtr event(new sc::KeyboardEvent(ea));
+
+  // Detect key repeat (of non modifier keys)
+  if( !event->isModifier() )
+  {
+    if( event->getType() == sc::Event::KEY_DOWN )
+    {
+      if( event->keyCode() == _last_key_down_no_mod )
+        event->setRepeat(true);
+      _last_key_down_no_mod = event->keyCode();
+    }
+    else
+    {
+      if( event->keyCode() == _last_key_down_no_mod )
+      _last_key_down_no_mod = -1;
+    }
+  }
+
+  sc::WindowPtr active_window = _focus_window.lock();
+  bool handled = handleEvent(event, active_window);
+
+  if(    event->getType() == sc::Event::KEY_DOWN
+      && !event->defaultPrevented()
+      && event->isPrint() )
+  {
+    sc::KeyboardEventPtr keypress( new sc::KeyboardEvent(*event) );
+    keypress->type = sc::Event::KEY_PRESS;
+
+    handled |= handleEvent(keypress, active_window);
+  }
+
+  return handled;
+}
+
+//------------------------------------------------------------------------------
+bool DesktopGroup::handleEvent( const sc::EventPtr& event,
+                                const sc::WindowPtr& active_window )
+{
+  return active_window
+       ? active_window->handleEvent(event)
+       : handleRootEvent(event);
+}
+
+//------------------------------------------------------------------------------
+bool DesktopGroup::handleRootEvent(const sc::EventPtr& event)
+{
+  sc::Element::handleEvent(event);
+
+  // stopPropagation() on DesktopGroup stops propagation to internal event
+  // handling.
+  return event->propagation_stopped;
 }
 
 //------------------------------------------------------------------------------
@@ -490,9 +598,9 @@ GUIMgr::GUIMgr()
 }
 
 //------------------------------------------------------------------------------
-canvas::WindowPtr GUIMgr::createWindow(const std::string& name)
+sc::WindowPtr GUIMgr::createWindow(const std::string& name)
 {
-  canvas::WindowPtr window = _desktop->createChild<canvas::Window>(name);
+  sc::WindowPtr window = _desktop->createChild<sc::Window>(name);
   if( name.empty() )
     window->set<std::string>
     (
@@ -505,6 +613,12 @@ canvas::WindowPtr GUIMgr::createWindow(const std::string& name)
 //------------------------------------------------------------------------------
 void GUIMgr::init()
 {
+  if( _desktop && _event_handler )
+  {
+    SG_LOG(SG_GUI, SG_WARN, "GUIMgr::init() already initialized.");
+    return;
+  }
+
   DesktopPtr desktop( new DesktopGroup );
   desktop->handleResize
   (
@@ -522,7 +636,7 @@ void GUIMgr::init()
          // GUI is on top of everything so lets install as first event handler
          .push_front( _event_handler );
 
-  simgear::canvas::Canvas::addPlacementFactory
+  sc::Canvas::addPlacementFactory
   (
     "window",
     boost::bind(&GUIMgr::addWindowPlacement, this, _1, _2)
@@ -534,14 +648,27 @@ void GUIMgr::init()
 //------------------------------------------------------------------------------
 void GUIMgr::shutdown()
 {
-  _desktop->destroy();
-  _desktop.reset();
-  simgear::canvas::Canvas::removePlacementFactory("window");
+  if( !_desktop && !_event_handler )
+  {
+    SG_LOG(SG_GUI, SG_WARN, "GUIMgr::shutdown() not running.");
+    return;
+  }
 
-  globals->get_renderer()
-         ->getViewer()
-         ->removeEventHandler( _event_handler );
-  _event_handler = 0;
+  sc::Canvas::removePlacementFactory("window");
+
+  if( _desktop )
+  {
+    _desktop->destroy();
+    _desktop.reset();
+  }
+
+  if( _event_handler )
+  {
+    globals->get_renderer()
+           ->getViewer()
+           ->removeEventHandler( _event_handler );
+    _event_handler = 0;
+  }
 }
 
 //------------------------------------------------------------------------------
@@ -551,25 +678,43 @@ void GUIMgr::update(double dt)
 }
 
 //------------------------------------------------------------------------------
-simgear::canvas::GroupPtr GUIMgr::getDesktop()
+sc::GroupPtr GUIMgr::getDesktop()
 {
   return _desktop;
 }
 
 //------------------------------------------------------------------------------
-simgear::canvas::Placements
+void GUIMgr::setInputFocus(const simgear::canvas::WindowPtr& window)
+{
+  static_cast<DesktopGroup*>(_desktop.get())->setFocusWindow(window);
+}
+
+//------------------------------------------------------------------------------
+bool GUIMgr::grabPointer(const sc::WindowPtr& window)
+{
+  return static_cast<DesktopGroup*>(_desktop.get())->grabPointer(window);
+}
+
+//------------------------------------------------------------------------------
+void GUIMgr::ungrabPointer(const sc::WindowPtr& window)
+{
+  static_cast<DesktopGroup*>(_desktop.get())->ungrabPointer(window);
+}
+
+//------------------------------------------------------------------------------
+sc::Placements
 GUIMgr::addWindowPlacement( SGPropertyNode* placement,
-                            simgear::canvas::CanvasPtr canvas )
+                            sc::CanvasPtr canvas )
 {
   const std::string& id = placement->getStringValue("id");
 
-  simgear::canvas::Placements placements;
-  canvas::WindowPtr window = _desktop->getChild<canvas::Window>(id);
+  sc::Placements placements;
+  sc::WindowPtr window = _desktop->getChild<sc::Window>(id);
   if( window )
   {
     window->setCanvasContent(canvas);
     placements.push_back(
-      simgear::canvas::PlacementPtr(
+      sc::PlacementPtr(
         new WindowPlacement(placement, window, canvas)
     ));
   }
