@@ -46,6 +46,7 @@
 #include <simgear/misc/strutils.hxx>
 #include <simgear/math/sg_geodesy.hxx>
 
+#include <cstdio>
 #include <sstream>
 #include <iomanip>
 #include <iostream>             // for cout, endl
@@ -69,7 +70,7 @@ using std::string;
 #include <Navaids/navrecord.hxx>
 #include <Navaids/navlist.hxx>
 #include <Navaids/fix.hxx>
-#include <Airports/simple.hxx>
+#include <Airports/airport.hxx>
 #include <Airports/runways.hxx>
 #include "od_gauge.hxx"
 
