@@ -118,7 +118,6 @@ wxRadarBg::wxRadarBg(SGPropertyNode *node) :
 wxRadarBg::~wxRadarBg ()
 {
     _font_node->removeChangeListener(this);
-    delete _odg;
 }
 
 
@@ -249,6 +248,11 @@ wxRadarBg::init ()
     _time = 0.0;
 }
 
+void wxRadarBg::shutdown()
+{
+    delete _odg;
+    _odg = NULL;
+}
 
 // Local coordinates for each echo
 const osg::Vec3f echoCoords[4] = {
@@ -1078,13 +1082,9 @@ wxRadarBg::updateFont()
     } else {
         tpath = path;
     }
-
-#if (FG_OSG_VERSION >= 21000)
+    
     osg::ref_ptr<osgDB::ReaderWriter::Options> fontOptions = new osgDB::ReaderWriter::Options("monochrome");
     osg::ref_ptr<osgText::Font> font = osgText::readFontFile(tpath.c_str(), fontOptions.get());
-#else
-    osg::ref_ptr<osgText::Font> font = osgText::readFontFile(tpath.c_str());
-#endif
 
     if (font != 0) {
         _font = font;
