@@ -64,6 +64,7 @@ INCLUDES
 #include "models/FGInput.h"
 #include "models/FGOutput.h"
 #include "initialization/FGInitialCondition.h"
+#include "initialization/FGTrim.h"
 #include "initialization/FGSimplexTrim.h"
 #include "initialization/FGLinearization.h"
 #include "input_output/FGPropertyManager.h"
@@ -75,8 +76,8 @@ using namespace std;
 
 namespace JSBSim {
 
-static const char *IdSrc = "$Id: FGFDMExec.cpp,v 1.150 2013/11/24 11:40:55 bcoconni Exp $";
-static const char *IdHdr = ID_FDMEXEC;
+IDENT(IdSrc,"$Id: FGFDMExec.cpp,v 1.170 2015/02/07 17:52:36 bcoconni Exp $");
+IDENT(IdHdr,ID_FDMEXEC);
 
 /*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 CLASS IMPLEMENTATION
@@ -89,10 +90,10 @@ FGFDMExec::FGFDMExec(FGPropertyManager* root, unsigned int* fdmctr) : Root(root)
 {
   Frame           = 0;
   Error           = 0;
-  SetGroundCallback(new FGDefaultGroundCallback());
   IC              = 0;
   Trim            = 0;
   Script          = 0;
+  disperse        = 0;
 
   RootDir = "";
 
@@ -101,6 +102,7 @@ FGFDMExec::FGFDMExec(FGPropertyManager* root, unsigned int* fdmctr) : Root(root)
   holding = false;
   Terminate = false;
   StandAlone = false;
+  ResetMode = 0;
 
   IncrementThenHolding = false;  // increment then hold is off by default
   TimeStepsUntilHold = -1;
@@ -138,6 +140,17 @@ FGFDMExec::FGFDMExec(FGPropertyManager* root, unsigned int* fdmctr) : Root(root)
 
   FGPropertyNode* instanceRoot = Root->GetNode("/fdm/jsbsim",IdFDM,true);
   instance = new FGPropertyManager(instanceRoot);
+
+  try {
+    char* num = getenv("JSBSIM_DISPERSE");
+    if (num) {
+      if (atoi(num) != 0) disperse = 1;  // set dispersions on
+    }
+  } catch (...) {                        // if error set to false
+    disperse = 0;
+    std::cerr << "Could not process JSBSIM_DISPERSIONS environment variable: Assumed NO dispersions." << endl;
+  }
+
   Debug(0);
   // this is to catch errors in binding member functions to the property tree.
   try {
@@ -152,13 +165,12 @@ FGFDMExec::FGFDMExec(FGPropertyManager* root, unsigned int* fdmctr) : Root(root)
 
   Constructing = true;
   typedef int (FGFDMExec::*iPMF)(void) const;
-  typedef double (FGFDMExec::*dPMF)(void) const;
-//  typedef unsigned int (FGFDMExec::*uiPMF)(void) const;
 //  instance->Tie("simulation/do_trim_analysis", this, (iPMF)0, &FGFDMExec::DoTrimAnalysis, false);
   instance->Tie("simulation/do_simple_trim", this, (iPMF)0, &FGFDMExec::DoTrim, false);
   instance->Tie("simulation/do_simplex_trim", this, (iPMF)0, &FGFDMExec::DoSimplexTrim);
   instance->Tie("simulation/do_linearization", this, (iPMF)0, &FGFDMExec::DoLinearization);
   instance->Tie("simulation/reset", this, (iPMF)0, &FGFDMExec::ResetToInitialConditions, false);
+  instance->Tie("simulation/disperse", this, &FGFDMExec::GetDisperse);
   instance->Tie("simulation/randomseed", this, (iPMF)0, &FGFDMExec::SRand, false);
   instance->Tie("simulation/terminate", (int *)&Terminate);
   instance->Tie("simulation/sim-time-sec", this, &FGFDMExec::GetSimTime);
@@ -220,6 +232,7 @@ FGFDMExec::~FGFDMExec()
     DeAllocate();
 
     delete instance;
+    SetGroundCallback(0);
 
     if (IdFDM == 0) { // Meaning this is no child FDM
       if(Root != 0) {
@@ -254,22 +267,28 @@ bool FGFDMExec::Allocate(void)
 
   Models.resize(eNumStandardModels);
 
-  // See the eModels enum specification in the header file. The order of the enums
-  // specifies the order of execution. The Models[] vector is the primary
+  // First build the inertial model since some other models are relying on
+  // the inertial model and the ground callback to build themselves.
+  // Note that this does not affect the order in which the models will be
+  // executed later.
+  Models[eInertial]          = new FGInertial(this);
+  SetGroundCallback(new FGDefaultGroundCallback(static_cast<FGInertial*>(Models[eInertial])->GetRefRadius()));
+
+  // See the eModels enum specification in the header file. The order of the
+  // enums specifies the order of execution. The Models[] vector is the primary
   // storage array for the list of models.
   Models[ePropagate]         = new FGPropagate(this);
   Models[eInput]             = new FGInput(this);
-  Models[eInertial]          = new FGInertial(this);
   Models[eAtmosphere]        = new FGStandardAtmosphere(this);
   Models[eWinds]             = new FGWinds(this);
-  Models[eAuxiliary]         = new FGAuxiliary(this);
   Models[eSystems]           = new FGFCS(this);
+  Models[eMassBalance]       = new FGMassBalance(this);
+  Models[eAuxiliary]         = new FGAuxiliary(this);
   Models[ePropulsion]        = new FGPropulsion(this);
   Models[eAerodynamics]      = new FGAerodynamics (this);
   Models[eGroundReactions]   = new FGGroundReactions(this);
   Models[eExternalReactions] = new FGExternalReactions(this);
   Models[eBuoyantForces]     = new FGBuoyantForces(this);
-  Models[eMassBalance]       = new FGMassBalance(this);
   Models[eAircraft]          = new FGAircraft(this);
   Models[eAccelerations]     = new FGAccelerations(this);
   Models[eOutput]            = new FGOutput(this);
@@ -279,21 +298,20 @@ bool FGFDMExec::Allocate(void)
   Inertial = (FGInertial*)Models[eInertial];
   Atmosphere = (FGAtmosphere*)Models[eAtmosphere];
   Winds = (FGWinds*)Models[eWinds];
-  Auxiliary = (FGAuxiliary*)Models[eAuxiliary];
   FCS = (FGFCS*)Models[eSystems];
+  MassBalance = (FGMassBalance*)Models[eMassBalance];
+  Auxiliary = (FGAuxiliary*)Models[eAuxiliary];
   Propulsion = (FGPropulsion*)Models[ePropulsion];
   Aerodynamics = (FGAerodynamics*)Models[eAerodynamics];
   GroundReactions = (FGGroundReactions*)Models[eGroundReactions];
   ExternalReactions = (FGExternalReactions*)Models[eExternalReactions];
   BuoyantForces = (FGBuoyantForces*)Models[eBuoyantForces];
-  MassBalance = (FGMassBalance*)Models[eMassBalance];
   Aircraft = (FGAircraft*)Models[eAircraft];
   Accelerations = (FGAccelerations*)Models[eAccelerations];
   Output = (FGOutput*)Models[eOutput];
 
   // Initialize planet (environment) constants
   LoadPlanetConstants();
-  GetGroundCallback()->SetSeaLevelRadius(Inertial->GetRefRadius());
 
   // Initialize models
   for (unsigned int i = 0; i < Models.size(); i++) {
@@ -305,6 +323,7 @@ bool FGFDMExec::Allocate(void)
   }
 
   IC = new FGInitialCondition(this);
+  IC->bind(instance);
 
   modelLoaded = false;
 
@@ -331,14 +350,6 @@ bool FGFDMExec::DeAllocate(void)
 
 //%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 
-void FGFDMExec::Schedule(FGModel* model, int rate)
-{
-  model->SetRate(rate);
-  Models.push_back(model);
-}
-
-//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-
 bool FGFDMExec::Run(void)
 {
   bool success=true;
@@ -360,9 +371,16 @@ bool FGFDMExec::Run(void)
     Models[i]->Run(holding);
   }
 
+  if (ResetMode) {
+    unsigned int mode = ResetMode;
+
+    ResetMode = 0;
+    ResetToInitialConditions(mode);
+  }
+
   if (Terminate) success = false;
 
-  return (success);
+  return success;
 }
 
 //%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -590,8 +608,16 @@ bool FGFDMExec::RunIC(void)
   Run();
   ResumeIntegration(); // Restores the integration rate to what it was.
 
-  for (unsigned int i=0; i<IC->GetNumEnginesRunning(); i++)
-    propulsion->InitRunning(IC->GetEngineRunning(i));
+  for (unsigned int n=0; n < propulsion->GetNumEngines(); ++n) {
+    if (IC->IsEngineRunning(n)) {
+      try {
+        propulsion->InitRunning(n);
+      } catch (string str) {
+        cerr << str << endl;
+        return false;
+      }
+    }
+  }
 
   return true;
 }
@@ -603,34 +629,25 @@ void FGFDMExec::Initialize(FGInitialCondition *FGIC)
   Setsim_time(0.0);
 
   Propagate->SetInitialState( FGIC );
+  LoadInputs(eInertial);
+  Inertial->Run(false);
   LoadInputs(eAccelerations);
   Accelerations->Run(false);
   LoadInputs(ePropagate);
   Propagate->InitializeDerivatives();
-  LoadInputs(eAtmosphere);
-  Atmosphere->Run(false);
   Winds->SetWindNED(FGIC->GetWindNEDFpsIC());
-  Auxiliary->Run(false);
+  LoadInputs(eMassBalance);
+  MassBalance->Run(false);
 }
 
 //%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-//
-// A private, internal function call for Tie-ing to a property, so it needs an
-// argument.
 
 void FGFDMExec::ResetToInitialConditions(int mode)
-{
-  if (mode == 1) Output->SetStartNewOutput();
-
-  ResetToInitialConditions();
-}
-
-//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-
-void FGFDMExec::ResetToInitialConditions(void)
 {
   if (Constructing) return;
 
+  if (mode == 1) Output->SetStartNewOutput();
+
   for (unsigned int i = 0; i < Models.size(); i++) {
     // The Output model will be initialized during the RunIC() execution
     if (i == eOutput) continue;
@@ -639,9 +656,9 @@ void FGFDMExec::ResetToInitialConditions(void)
     Models[i]->InitModel();
   }
 
-  RunIC();
-
   if (Script) Script->ResetEvents();
+
+  RunIC();
 }
 
 //%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -858,22 +875,13 @@ bool FGFDMExec::LoadModel(const string& model, bool addModelToPath)
       }
     }
 
-    // Process the output element[s]. This element is OPTIONAL, and there may be more than one.
+    // Process the output element[s]. This element is OPTIONAL, and there may be
+    // more than one.
     element = document->FindElement("output");
     while (element) {
-      string output_file_name = aircraftCfgFileName;
+      if (!static_cast<FGOutput*>(Models[eOutput])->Load(element))
+        return false;
 
-      if (!element->GetAttributeValue("file").empty()) {
-        output_file_name = RootDir + element->GetAttributeValue("file");
-        result = ((FGOutput*)Models[eOutput])->SetDirectivesFile(output_file_name);
-      }
-      else
-        result = ((FGOutput*)Models[eOutput])->Load(element);
-
-      if (!result) {
-        cerr << endl << "Aircraft output element has problems in file " << output_file_name << endl;
-        return result;
-      }
       element = document->FindNextElement("output");
     }
 
@@ -900,7 +908,7 @@ bool FGFDMExec::LoadModel(const string& model, bool addModelToPath)
       Models[ePropulsion]->Run(false);  // Update propulsion properties for the report.
       LoadInputs(eMassBalance); // Update all (one more time) input mass properties for the report.
       Models[eMassBalance]->Run(false);  // Update all (one more time) mass properties for the report.
-      ((FGMassBalance*)Models[eMassBalance])->GetMassPropertiesReport();
+      ((FGMassBalance*)Models[eMassBalance])->GetMassPropertiesReport(0);
 
       cout << endl << fgblue << highint
            << "End of vehicle configuration loading." << endl
@@ -990,6 +998,17 @@ void FGFDMExec::PrintPropertyCatalog(void)
 
 //%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 
+void FGFDMExec::PrintSimulationConfiguration(void) const
+{
+  cout << endl << "Simulation Configuration" << endl << "------------------------" << endl;
+  cout << MassBalance->Name << endl;
+  cout << GroundReactions->Name << endl;
+  cout << Aerodynamics->Name << endl;
+  cout << Propulsion->Name << endl;
+}
+
+//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+
 bool FGFDMExec::ReadFileHeader(Element* el)
 {
   bool result = true; // true for success
@@ -1178,7 +1197,7 @@ void FGFDMExec::DoTrim(int mode)
   FGTrim trim(this, (JSBSim::TrimMode)mode);
   if ( !trim.DoTrim() ) cerr << endl << "Trim Failed" << endl << endl;
   trim.Report();
-  sim_time = saved_time;
+  Setsim_time(saved_time);
 }
 
 //%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -1193,7 +1212,6 @@ void FGFDMExec::DoSimplexTrim(int mode)
   }
   saved_time = sim_time;
   FGSimplexTrim trim(this, (JSBSim::TrimMode)mode);
-  sim_time = saved_time;
   Setsim_time(saved_time);
   std::cout << "dT: " << dT << std::endl;
 }
@@ -1206,7 +1224,6 @@ void FGFDMExec::DoLinearization(int mode)
   if (Constructing) return;
   saved_time = sim_time;
   FGLinearization lin(this,mode);
-  sim_time = saved_time;
   Setsim_time(saved_time);
 }
 
@@ -1214,6 +1231,7 @@ void FGFDMExec::DoLinearization(int mode)
 
 void FGFDMExec::SRand(int sr)
 {
+  gaussian_random_number_phase = 0;
   srand(sr);
 }
 
@@ -1246,6 +1264,7 @@ void FGFDMExec::Debug(int from)
            << "JSBSim Flight Dynamics Model v" << JSBSim_version << endl;
       cout << "            [JSBSim-ML v" << needed_cfg_version << "]\n\n";
       cout << "JSBSim startup beginning ...\n\n";
+      if (disperse == 1) cout << "Dispersions are ON." << endl << endl;
     } else if (from == 3) {
       cout << "\n\nJSBSim startup complete\n\n";
     }
