@@ -44,7 +44,6 @@ INCLUDES
 #include <vector>
 #include <string>
 
-#include "initialization/FGTrim.h"
 #include "FGJSBBase.h"
 #include "input_output/FGPropertyManager.h"
 #include "models/FGPropagate.h"
@@ -55,7 +54,7 @@ INCLUDES
 DEFINITIONS
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%*/
 
-#define ID_FDMEXEC "$Id: FGFDMExec.h,v 1.85 2013/11/24 11:40:55 bcoconni Exp $"
+#define ID_FDMEXEC "$Id: FGFDMExec.h,v 1.95 2015/02/07 17:52:36 bcoconni Exp $"
 
 /*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 FORWARD DECLARATIONS
@@ -79,6 +78,7 @@ class FGInertial;
 class FGInput;
 class FGPropulsion;
 class FGMassBalance;
+class FGTrim;
 
 /*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 CLASS DOCUMENTATION
@@ -178,7 +178,7 @@ CLASS DOCUMENTATION
                                 property actually maps toa function call of DoTrim().
 
     @author Jon S. Berndt
-    @version $Revision: 1.85 $
+    @version $Revision: 1.95 $
 */
 
 /*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -221,21 +221,28 @@ public:
   /// Default destructor
   ~FGFDMExec();
 
-  // This list of enums is very important! The order in which models are listed here
-  // determines the order of execution of the models.
+  // This list of enums is very important! The order in which models are listed
+  // here determines the order of execution of the models.
+  //
+  // There are some conditions that need to be met :
+  // 1. FCS can request mass geometry changes via the inertia/pointmass-*
+  //    properties so it must be executed before MassBalance
+  // 2. MassBalance must be executed before Propulsion, Aerodynamics,
+  //    GroundReactions, ExternalReactions and BuoyantForces to ensure that
+  //    their moments are computed with the updated CG position.
   enum eModels { ePropagate=0,
                  eInput,
                  eInertial,
                  eAtmosphere,
                  eWinds,
-                 eAuxiliary,
                  eSystems,
+                 eMassBalance,
+                 eAuxiliary,
                  ePropulsion,
                  eAerodynamics,
                  eGroundReactions,
                  eExternalReactions,
                  eBuoyantForces,
-                 eMassBalance,
                  eAircraft,
                  eAccelerations,
                  eOutput,
@@ -244,19 +251,6 @@ public:
   /** Unbind all tied JSBSim properties. */
   void Unbind(void) {instance->Unbind();}
 
-  /** This routine places a model into the runlist at the specified rate. The
-      "rate" is not really a clock rate. It represents how many calls to the
-      FGFDMExec::Run() method must be made before the model is executed. A
-      value of 1 means that the model will be executed for each call to the
-      exec's Run() method. A value of 5 means that the model will only be
-      executed every 5th call to the exec's Run() method. Use of a rate other than
-      one is at this time not recommended.
-      @param model A pointer to the model being scheduled.
-      @param rate The rate at which to execute the model as described above.
-                  Default is every frame (rate=1).
-      @return Currently returns 0 always. */
-  void Schedule(FGModel* model, int rate=1);
-
   /** This function executes each scheduled model in succession.
       @return true if successful, false if sim should be ended  */
   bool Run(void);
@@ -405,13 +399,7 @@ public:
 
   /// Returns the model name.
   const std::string& GetModelName(void) const { return modelName; }
-/*
-  /// Returns the current time.
-  double GetSimTime(void);
 
-  /// Returns the current frame time (delta T).
-  double GetDeltaT(void);
-*/  
   /// Returns a pointer to the property manager object.
   FGPropertyManager* GetPropertyManager(void);
   /// Returns a vector of strings representing the names of all loaded models (future)
@@ -448,6 +436,7 @@ public:
   void SetLoggingRate(double rate) { Output->SetRate(rate); }
 
   /** Sets (or overrides) the output filename
+      @param n index of file
       @param fname the name of the file to output data to
       @return true if successful, false if there is no output specified for the flight model */
   bool SetOutputFileName(const int n, const std::string& fname) { return Output->SetOutputName(n, fname); }
@@ -489,8 +478,12 @@ public:
   void Resume(void) {holding = false;}
   /// Returns true if the simulation is Holding (i.e. simulation time is not moving).
   bool Holding(void) {return holding;}
-  /// Resets the initial conditions object and prepares the simulation to run again.
-  void ResetToInitialConditions(void);
+  /** Resets the initial conditions object and prepares the simulation to run
+      again. If mode is set to 1 the output instances will take special actions
+      such as closing the current output file and open a new one with a
+      different name.
+      @param mode Sets the reset mode.*/
+  void ResetToInitialConditions(int mode);
   /// Sets the debug level.
   void SetDebugLevel(int level) {debug_lvl = level;}
 
@@ -518,6 +511,9 @@ public:
   // Print the contents of the property catalog for the loaded aircraft.
   void PrintPropertyCatalog(void);
 
+  // Print the simulation configuration
+  void PrintSimulationConfiguration(void) const;
+
   std::vector<std::string>& GetPropertyCatalog(void) {return PropertyCatalog;}
 
   void SetTrimStatus(bool status){ trim_status = status; }
@@ -548,6 +544,7 @@ public:
       @return the current simulation time.      */
   double Setsim_time(double cur_time) {
     sim_time = cur_time;
+    GetGroundCallback()->SetTime(sim_time);
     return sim_time;
   }
 
@@ -568,6 +565,7 @@ public:
       @return the new simulation time.     */
   double IncrTime(void) {
     if (!holding) sim_time += dT;
+    GetGroundCallback()->SetTime(sim_time);
     Frame++;
     return sim_time;
   }
@@ -583,6 +581,7 @@ private:
   int Error;
   unsigned int Frame;
   unsigned int IdFDM;
+  int disperse;
   unsigned short Terminate;
   double dT;
   double saved_dT;
@@ -621,6 +620,7 @@ private:
 
   bool trim_status;
   int ta_mode;
+  unsigned int ResetMode;
 
   FGScript*           Script;
   FGInitialCondition* IC;
@@ -640,13 +640,13 @@ private:
   bool ReadFileHeader(Element*);
   bool ReadChild(Element*);
   bool ReadPrologue(Element*);
-  void ResetToInitialConditions(int mode);
   void SRand(int sr);
   void LoadInputs(unsigned int idx);
   void LoadPlanetConstants(void);
   void LoadModelConstants(void);
   bool Allocate(void);
   bool DeAllocate(void);
+  int GetDisperse(void) const {return disperse;}
 
   void Debug(int from);
 };
