@@ -18,7 +18,7 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301, USA.
 //
-// $Id: JSBSim.cxx,v 1.64 2010/10/31 04:49:25 jberndt Exp $
+// $Id: FlightGear.cxx,v 1.15 2014/01/28 09:42:20 ehofman Exp $
 
 
 #ifdef HAVE_CONFIG_H
@@ -28,7 +28,7 @@
 #include <simgear/compiler.h>
 #include <simgear/sg_inlines.h>
 
-#include <stdio.h>    //    size_t
+#include <cstdlib>    //    size_t
 #include <string>
 
 #include <simgear/constants.h>
@@ -36,6 +36,7 @@
 #include <simgear/math/sg_geodesy.hxx>
 #include <simgear/misc/sg_path.hxx>
 #include <simgear/structure/commands.hxx>
+#include <simgear/bvh/BVHMaterial.hxx>
 
 #include <FDM/flight.hxx>
 
@@ -171,7 +172,6 @@ FGJSBsim::FGJSBsim( double dt )
     // FIXME: this will not respond to
     // runtime changes
 
-                                // if flight is excluded, don't bother
     if ((sglog().get_log_classes() & SG_FLIGHT) != 0) {
 
                                 // do a rough-and-ready mapping to
@@ -188,6 +188,9 @@ FGJSBsim::FGJSBsim( double dt )
             FGJSBBase::debug_lvl = 0x00;
             break;
         }
+    } else {
+                                // if flight is excluded, don't bother
+            FGJSBBase::debug_lvl = 0x00;
     }
 
     PropertyManager = new FGPropertyManager( (FGPropertyNode*)globals->get_props() );
@@ -214,11 +217,11 @@ FGJSBsim::FGJSBsim( double dt )
 
     SGPath aircraft_path( fgGetString("/sim/aircraft-dir") );
 
-    SGPath engine_path( fgGetString("/sim/aircraft-dir") );
-    engine_path.append( "Engine" );
+    SGPath engine_path( fgGetString("/sim/fg-root") );
+    engine_path.append( "Aircraft/Generic/JSBSim/Engines" );
 
-    SGPath systems_path( fgGetString("/sim/aircraft-dir") );
-    systems_path.append( "Systems" );
+    SGPath systems_path( fgGetString("/sim/fg-root") );
+    systems_path.append( "Aircraft/Generic/JSBSim/Systems" );
 
 // deprecate sim-time-sec for simulation/sim-time-sec
 // remove alias with increased configuration file version number (2.1 or later)
@@ -388,9 +391,7 @@ void FGJSBsim::init()
       Winds->SetProbabilityOfExceedence(0.0);
     }
 
-    fgic->SetWindNEDFpsIC( -wind_from_north->getDoubleValue(),
-                           -wind_from_east->getDoubleValue(),
-                           -wind_from_down->getDoubleValue() );
+    fgic->SetWindNEDFpsIC(0.0, 0.0, 0.0);
 
     SG_LOG(SG_FLIGHT,SG_INFO,"T,p,rho: " << Atmosphere->GetTemperature()
      << ", " << Atmosphere->GetPressure()
@@ -413,18 +414,17 @@ void FGJSBsim::init()
     }
 
     if ( needTrim ) {
-      FGLocation cart(fgic->GetLongitudeRadIC(), fgic->GetLatitudeRadIC(),
-                      get_Sea_level_radius() + fgic->GetAltitudeASLFtIC());
+      const FGLocation& cart = fgic->GetPosition();
       double cart_pos[3], contact[3], d[3], vel[3], agl;
       update_ground_cache(cart, cart_pos, 0.01);
 
       get_agl_ft(fdmex->GetSimTime(), cart_pos, SG_METER_TO_FEET*2, contact,
                  d, vel, d, &agl);
       double terrain_alt = sqrt(contact[0]*contact[0] + contact[1]*contact[1]
-           + contact[2]*contact[2]) - get_Sea_level_radius();
+                                + contact[2]*contact[2]) - cart.GetSeaLevelRadius();
 
       SG_LOG(SG_FLIGHT, SG_INFO, "Ready to trim, terrain elevation is: "
-                                 << terrain_alt * SG_METER_TO_FEET );
+                                 << terrain_alt );
 
       if (fgGetBool("/sim/presets/onground")) {
         FGColumnVector3 gndVelNED = cart.GetTec2l()
@@ -433,7 +433,6 @@ void FGJSBsim::init()
         fgic->SetVEastFpsIC(gndVelNED(2));
         fgic->SetVDownFpsIC(gndVelNED(3));
       }
-      fgic->SetTerrainElevationFtIC( terrain_alt );
       do_trim();
       needTrim = false;
     }
@@ -1021,10 +1020,8 @@ void FGJSBsim::set_Latitude(double lat)
   double sea_level_radius_ft = sea_level_radius_meters * SG_METER_TO_FEET;
   _set_Sea_level_radius( sea_level_radius_ft );
 
-  if (needTrim) {
-    fgic->SetSeaLevelRadiusFtIC( sea_level_radius_ft );
+  if (needTrim)
     fgic->SetLatitudeRadIC( lat_geoc );
-  }
   else
     Propagate->SetLatitude(lat_geoc);
 
@@ -1049,8 +1046,13 @@ void FGJSBsim::set_Altitude(double alt)
 {
   SG_LOG(SG_FLIGHT,SG_INFO, "FGJSBsim::set_Altitude: " << alt );
 
-  if (needTrim)
-    fgic->SetAltitudeASLFtIC(alt);
+  if (needTrim) {
+    FGLocation position = fgic->GetPosition();
+
+    position.SetPositionGeodetic(0.0, position.GetGeodLatitudeRad(), alt);
+    fgic->SetAltitudeASLFtIC(position.GetAltitudeASL());
+    fgic->SetLatitudeRadIC(position.GetLatitude());
+  }
   else
     Propagate->SetAltitudeASL(alt);
 
@@ -1283,7 +1285,8 @@ void FGJSBsim::do_trim(void)
   SG_LOG( SG_FLIGHT, SG_INFO, "  Trim complete" );
 }
 
-bool FGJSBsim::update_ground_cache(FGLocation cart, double* cart_pos, double dt)
+bool FGJSBsim::update_ground_cache(const FGLocation& cart, double* cart_pos,
+                                   double dt)
 {
   // Compute the radius of the aircraft. That is the radius of a ball
   // where all gear units are in. At the moment it is at least 10ft ...
@@ -1330,15 +1333,49 @@ FGJSBsim::get_agl_ft(double t, const double pt[3], double alt_off,
                      double contact[3], double normal[3], double vel[3],
                      double angularVel[3], double *agl)
 {
-   const simgear::BVHMaterial* material;
-   simgear::BVHNode::Id id;
-   if (!FGInterface::get_agl_ft(t, pt, alt_off, contact, normal, vel,
-                                angularVel, material, id))
-       return false;
-   SGGeod geodPt = SGGeod::fromCart(SG_FEET_TO_METER*SGVec3d(pt));
-   SGQuatd hlToEc = SGQuatd::fromLonLat(geodPt);
-   *agl = dot(hlToEc.rotate(SGVec3d(0, 0, 1)), SGVec3d(contact) - SGVec3d(pt));
-   return true;
+  const simgear::BVHMaterial* material;
+  simgear::BVHNode::Id id;
+
+  // don't check the return value and continue above scenery discontinuity
+  // see http://osdir.com/ml/flightgear-sim/2014-04/msg00145.html
+  FGInterface::get_agl_ft(t, pt, alt_off, contact, normal, vel,
+                               angularVel, material, id);
+
+  SGGeod geodPt = SGGeod::fromCart(SG_FEET_TO_METER*SGVec3d(pt));
+  SGQuatd hlToEc = SGQuatd::fromLonLat(geodPt);
+  *agl = dot(hlToEc.rotate(SGVec3d(0, 0, 1)), SGVec3d(contact) - SGVec3d(pt));
+
+  static SGPropertyNode_ptr terrain = fgGetNode("/sim/fdm/surface", true);
+
+#ifdef JSBSIM_USE_GROUNDREACTIONS
+  bool terrain_active = (terrain->getIntValue("override-level", -1) > 0) ? false : true;
+  terrain->setBoolValue("active", terrain_active);
+  terrain->setBoolValue("valid", (material && terrain_active) ? true : false);
+  if (terrain_active)
+  {
+    static bool material_valid = false;
+    if (material) {
+      GroundReactions->SetStaticFFactor((*material).get_friction_factor());
+      GroundReactions->SetRollingFFactor((*material).get_rolling_friction()/0.02);
+      // 1 Pascal = 0.00014503773800721815 lbs/in^2
+      double pressure = (*material).get_load_resistance(); // N/m^2 (or Pascal)
+      GroundReactions->SetMaximumForce(pressure*0.00014503773800721815);
+
+      GroundReactions->SetBumpiness((*material).get_bumpiness());
+      GroundReactions->SetSolid((*material).get_solid());
+      GroundReactions->SetPosition(pt);
+      material_valid = true;
+    } else {
+       if (material_valid) {
+         GroundReactions->resetValues();
+         material_valid = false;
+      }
+    }
+  }
+#else
+  terrain->setBoolValue("valid", false);
+#endif
+  return true;
 }
 
 inline static double sqr(double x)
