@@ -54,7 +54,7 @@ INCLUDES
 DEFINITIONS
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%*/
 
-#define ID_INITIALCONDITION "$Id: FGInitialCondition.h,v 1.39 2013/11/24 11:40:55 bcoconni Exp $"
+#define ID_INITIALCONDITION "$Id: FGInitialCondition.h,v 1.41 2014/05/01 18:32:54 bcoconni Exp $"
 
 /*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 FORWARD DECLARATIONS
@@ -217,7 +217,7 @@ CLASS DOCUMENTATION
    @property ic/r-rad_sec (read/write) Yaw rate initial condition in radians/second
 
    @author Tony Peden
-   @version "$Id: FGInitialCondition.h,v 1.39 2013/11/24 11:40:55 bcoconni Exp $"
+   @version "$Id: FGInitialCondition.h,v 1.41 2014/05/01 18:32:54 bcoconni Exp $"
 */
 
 /*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -653,15 +653,12 @@ public:
       @return true if successful */
   bool Load(std::string rstname, bool useStoredPath = true );
 
-  /** Get the number of engines running
-   */
-  unsigned int GetNumEnginesRunning(void) const
-  { return (unsigned int)enginesRunning.size(); }
+  /** Is an engine running ?
+      @param index of the engine to be checked
+      @return true if the engine is running. */
+  bool IsEngineRunning(unsigned int n) const { return (enginesRunning & (1 << n)); }
 
-  /** Gets the running engine identification
-      @param engine index of running engine instance
-      @return the identification of running engine instance requested */
-  int GetEngineRunning(unsigned int engine) const { return enginesRunning[engine]; }
+  void bind(FGPropertyManager* pm);
 
 private:
   FGColumnVector3 vUVW_NED;
@@ -677,10 +674,9 @@ private:
 
   speedset lastSpeedSet;
   altitudeset lastAltitudeSet;
-  std::vector<int> enginesRunning;
+  unsigned int enginesRunning;
 
   FGFDMExec *fdmex;
-  FGPropertyManager *PropertyManager;
   FGAtmosphere* Atmosphere;
 
   bool Load_v1(Element* document);
@@ -695,7 +691,6 @@ private:
   double GetBodyVelFpsIC(int idx) const;
   void calcAeroAngles(const FGColumnVector3& _vt_BODY);
   void calcThetaBeta(double alfa, const FGColumnVector3& _vt_NED);
-  void bind(void);
   void Debug(int from);
 };
 }
