@@ -46,17 +46,20 @@ INCLUDES
 #include <iomanip>
 
 #include "FGScript.h"
+#include "FGFDMExec.h"
 #include "input_output/FGXMLElement.h"
 #include "input_output/FGXMLFileRead.h"
-#include "initialization/FGTrim.h"
+#include "initialization/FGInitialCondition.h"
 #include "models/FGInput.h"
+#include "math/FGCondition.h"
+#include "math/FGFunction.h"
 
 using namespace std;
 
 namespace JSBSim {
 
-static const char *IdSrc = "$Id: FGScript.cpp,v 1.53 2013/11/24 11:40:55 bcoconni Exp $";
-static const char *IdHdr = ID_FGSCRIPT;
+IDENT(IdSrc,"$Id: FGScript.cpp,v 1.60 2014/06/08 12:50:05 bcoconni Exp $");
+IDENT(IdHdr,ID_FGSCRIPT);
 
 /*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 GLOBAL DECLARATIONS
@@ -81,12 +84,6 @@ FGScript::~FGScript()
 {
   unsigned int i, j;
 
-  for (i=0; i<local_properties.size(); i++) {
-    delete local_properties[i]->value;
-    delete local_properties[i];
-  }
-  local_properties.clear();
-
   for (i=0; i<Events.size(); i++) {
     delete Events[i].Condition;
     for (j=0; j<Events[i].Functions.size(); j++)
@@ -106,7 +103,6 @@ bool FGScript::LoadScript(string script, double deltaT, const string initfile)
   Element *element=0, *run_element=0, *event_element=0;
   Element *condition_element=0, *set_element=0, *delay_element=0;
   Element *notify_element = 0L, *notify_property_element = 0L;
-  Element *property_element = 0L;
   Element *output_element = 0L;
   Element *input_element = 0L;
   bool result = false;
@@ -145,9 +141,15 @@ bool FGScript::LoadScript(string script, double deltaT, const string initfile)
 
   // Set sim timing
 
-  StartTime = run_element->GetAttributeValueAsNumber("start");
+  if (run_element->HasAttribute("start")) StartTime = run_element->GetAttributeValueAsNumber("start");
   FDMExec->Setsim_time(StartTime);
-  EndTime   = run_element->GetAttributeValueAsNumber("end");
+  if (run_element->HasAttribute("end")) {
+    EndTime   = run_element->GetAttributeValueAsNumber("end");
+  } else {
+    cerr << "An end time (duration) for the script must be specified in the script <run> element." << endl;
+    return false;
+  }
+
   // Make sure that the desired time is reached and executed.
   EndTime += 0.99*FDMExec->GetDeltaT();
 
@@ -174,11 +176,11 @@ bool FGScript::LoadScript(string script, double deltaT, const string initfile)
       return false;
     }
 
-    initialize = element->GetAttributeValue("initialize");
     if (initfile.empty()) {
-    if (initialize.empty()) {
-      cerr << "Initialization file must be specified in use element." << endl;
-      return false;
+      initialize = element->GetAttributeValue("initialize");
+      if (initialize.empty()) {
+        cerr << "Initialization file must be specified in use element." << endl;
+        return false;
       }
     } else {
       cout << endl << "The initialization file specified in the script file (" << initialize
@@ -191,6 +193,12 @@ bool FGScript::LoadScript(string script, double deltaT, const string initfile)
     return false;
   }
 
+  FGInitialCondition *IC=FDMExec->GetIC();
+  if ( ! IC->Load( initialize )) {
+    cerr << "Initialization unsuccessful" << endl;
+    exit(-1);
+  }
+
   // Now, read input spec if given.
   if (input_element > 0) {
     FDMExec->GetInput()->Load(input_element);
@@ -207,26 +215,10 @@ bool FGScript::LoadScript(string script, double deltaT, const string initfile)
   }
 
   // Read local property/value declarations
-  property_element = run_element->FindElement("property");
-  while (property_element) {
-
-    double value=0.0;
-    string title="";
-
-    title = property_element->GetDataLine();
-    if ( ! property_element->GetAttributeValue("value").empty())
-      value = property_element->GetAttributeValueAsNumber("value");
-
-    LocalProps *localProp = new LocalProps(value);
-    localProp->title = title;
-    local_properties.push_back(localProp);
-    if (PropertyManager->HasNode(title)) {
-      PropertyManager->GetNode(title)->setDoubleValue(value);
-    } else {
-      PropertyManager->Tie(localProp->title, localProp->value);
-    }
-    property_element = run_element->FindNextElement("property");
-  }
+  int saved_debug_lvl = debug_lvl;
+  debug_lvl = 0; // Disable messages
+  LocalProperties.Load(run_element, PropertyManager, true);
+  debug_lvl = saved_debug_lvl;
 
   // Read "events" from script
 
@@ -354,17 +346,21 @@ bool FGScript::LoadScript(string script, double deltaT, const string initfile)
 
   Debug(4);
 
-  FGInitialCondition *IC=FDMExec->GetIC();
-  if ( ! IC->Load( initialize )) {
-    cerr << "Initialization unsuccessful" << endl;
-    exit(-1);
-  }
-
   return true;
 }
 
 //%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 
+void FGScript::ResetEvents(void)
+{
+  //LocalProperties.ResetToIC();
+
+  for (unsigned int i=0; i<Events.size(); i++)
+    Events[i].reset();
+}
+
+//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+
 bool FGScript::RunScript(void)
 {
   unsigned i, j;
@@ -557,13 +553,15 @@ void FGScript::Debug(int from)
         ceil(1.0/FDMExec->GetDeltaT()) << " Hz)" << endl;
       cout << endl;
 
-      for (unsigned int i=0; i<local_properties.size(); i++) {
-        cout << "Local property: " << local_properties[i]->title 
-             << " = " << PropertyManager->GetNode(local_properties[i]->title)->getDoubleValue()
+      FGPropertyReader::const_iterator it;
+      for (it = LocalProperties.begin(); it != LocalProperties.end(); ++it) {
+        FGPropertyNode* node = *it;
+        cout << "Local property: " << node->GetName()
+             << " = " << node->getDoubleValue()
              << endl;
       }
       
-      if (local_properties.size() > 0) cout << endl;
+      if (LocalProperties.empty()) cout << endl;
 
       for (unsigned i=0; i<Events.size(); i++) {
         cout << "Event " << i;
