@@ -40,15 +40,17 @@ INCLUDES
 #include <iostream>
 #include <sstream>
 #include <string>
+
 #include "FGModelFunctions.h"
+#include "FGFunction.h"
 #include "input_output/FGXMLElement.h"
 
 using namespace std;
 
 namespace JSBSim {
 
-static const char *IdSrc = "$Id: FGModelFunctions.cpp,v 1.7 2013/11/24 11:40:55 bcoconni Exp $";
-static const char *IdHdr = ID_MODELFUNCTIONS;
+IDENT(IdSrc,"$Id: FGModelFunctions.cpp,v 1.14 2014/05/30 17:26:42 bcoconni Exp $");
+IDENT(IdHdr,ID_MODELFUNCTIONS);
 
 /*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 CLASS IMPLEMENTATION
@@ -56,9 +58,6 @@ CLASS IMPLEMENTATION
 
 FGModelFunctions::~FGModelFunctions()
 {
-  for (unsigned int i=0; i<interface_properties.size(); i++) delete interface_properties[i];
-  interface_properties.clear();
-
   for (unsigned int i=0; i<PreFunctions.size(); i++) delete PreFunctions[i];
   for (unsigned int i=0; i<PostFunctions.size(); i++) delete PostFunctions[i];
 
@@ -67,34 +66,18 @@ FGModelFunctions::~FGModelFunctions()
 
 //%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 
+bool FGModelFunctions::InitModel(void)
+{
+  LocalProperties.ResetToIC();
+
+  return true;
+}
+
+//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+
 bool FGModelFunctions::Load(Element* el, FGPropertyManager* PM, string prefix)
 {
-  // Interface properties are all stored in the interface properties array.
-  string interface_property_string = "";
-
-  Element *property_element = el->FindElement("property");
-  if (property_element && debug_lvl > 0) cout << endl << "    Declared properties" 
-                                              << endl << endl;
-  while (property_element) {
-    interface_property_string = property_element->GetDataLine();
-    if (PM->HasNode(interface_property_string)) {
-      cerr << "      Property " << interface_property_string 
-           << " is already defined." << endl;
-    } else {
-      double value=0.0;
-      if ( ! property_element->GetAttributeValue("value").empty())
-        value = property_element->GetAttributeValueAsNumber("value");
-      interface_properties.push_back(new double(value));
-      PM->Tie(interface_property_string, interface_properties.back());
-      if (debug_lvl > 0)
-        cout << "      " << interface_property_string << " (initial value: " 
-             << value << ")" << endl << endl;
-    }
-    property_element = el->FindNextElement("property");
-  }
-  
-  // End of interface property loading logic
-
+  LocalProperties.Load(el, PM, false);
   PreLoad(el, PM, prefix);
 
   return true; // TODO: Need to make this value mean something.
@@ -109,18 +92,10 @@ void FGModelFunctions::PreLoad(Element* el, FGPropertyManager* PM, string prefix
   Element *function = el->FindElement("function");
 
   while (function) {
-    if (function->GetAttributeValue("type") == "pre") {
+    string fType = function->GetAttributeValue("type");
+    if (fType.empty() || fType == "pre")
       PreFunctions.push_back(new FGFunction(PM, function, prefix));
-    } else if (function->GetAttributeValue("type").empty()) { // Assume pre-function
-      string funcname = function->GetAttributeValue("name");
-      if (funcname.find("IdleThrust") == string::npos && // Do not process functions that are
-          funcname.find("MilThrust") == string::npos  && // already pre-defined turbine engine
-          funcname.find("AugThrust") == string::npos  && // functions. These are loaded within
-          funcname.find("Injection") == string::npos )   // the Turbine::Load() method.
-      {
-        PreFunctions.push_back(new FGFunction(PM, function, prefix));
-      }
-    }
+
     function = el->FindNextElement("function");
   }
 }
@@ -170,6 +145,22 @@ void FGModelFunctions::RunPostFunctions(void)
 
 //%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 
+FGFunction* FGModelFunctions::GetPreFunction(const std::string& name)
+{
+  FGFunction* result;
+  vector<FGFunction*>::iterator it = PreFunctions.begin();
+
+  for (; it != PreFunctions.end(); ++it) {
+    result = *it;
+    if (result->GetName() == name)
+      return result;
+  }
+
+  return 0;
+}
+
+//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+
 string FGModelFunctions::GetFunctionStrings(const string& delimeter) const
 {
   string FunctionStrings = "";
