@@ -40,18 +40,18 @@ INCLUDES
 #include <sstream>
 #include <iomanip>
 #include <cstdlib>
+
 #include "FGFDMExec.h"
 #include "FGAerodynamics.h"
 #include "input_output/FGPropertyManager.h"
-#include "input_output/FGXMLFileRead.h"
 #include "input_output/FGXMLElement.h"
 
 using namespace std;
 
 namespace JSBSim {
 
-static const char *IdSrc = "$Id: FGAerodynamics.cpp,v 1.49 2013/11/24 11:40:55 bcoconni Exp $";
-static const char *IdHdr = ID_AERODYNAMICS;
+IDENT(IdSrc,"$Id: FGAerodynamics.cpp,v 1.55 2014/09/03 17:26:28 bcoconni Exp $");
+IDENT(IdHdr,ID_AERODYNAMICS);
 
 /*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 CLASS IMPLEMENTATION
@@ -83,6 +83,7 @@ FGAerodynamics::FGAerodynamics(FGFDMExec* FDMExec) : FGModel(FDMExec)
 
   impending_stall = stall_hyst = 0.0;
   alphaclmin = alphaclmax = 0.0;
+  alphaclmin0 = alphaclmax0 = 0.0;
   alphahystmin = alphahystmax = 0.0;
   clsq = lod = 0.0;
   alphaw = 0.0;
@@ -123,14 +124,16 @@ bool FGAerodynamics::InitModel(void)
   if (!FGModel::InitModel()) return false;
 
   impending_stall = stall_hyst = 0.0;
-  alphaclmin = alphaclmax = 0.0;
+  alphaclmin = alphaclmin0;
+  alphaclmax = alphaclmax0;
   alphahystmin = alphahystmax = 0.0;
   clsq = lod = 0.0;
   alphaw = 0.0;
   bi2vel = ci2vel = 0.0;
   AeroRPShift = 0;
   vDeltaRP.InitMatrix();
-
+  vForces.InitMatrix();
+  vMoments.InitMatrix();
   return true;
 }
 //%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -278,37 +281,29 @@ bool FGAerodynamics::Run(bool Holding)
 
 //%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 
-bool FGAerodynamics::Load(Element *element)
+bool FGAerodynamics::Load(Element *document)
 {
   string parameter, axis, scratch;
   string scratch_unit="";
-  string fname="", file="";
   Element *temp_element, *axis_element, *function_element;
 
-  string separator = "/";
-  FGXMLFileRead XMLFileRead;
-  Element* document;
+  Name = "Aerodynamics Model: " + document->GetAttributeValue("name");
 
-  fname = element->GetAttributeValue("file");
-  if (!fname.empty()) {
-    file = FDMExec->GetFullAircraftPath() + separator + fname;
-    document = XMLFileRead.LoadXMLDocument(file);
-    if (document == 0L) return false;
-  } else {
-    document = element;
-  }
+  // Perform base class Pre-Load
+  if (!FGModel::Load(document))
+    return false;
 
-  FGModel::Load(document); // Perform base class Pre-Load
-
-  DetermineAxisSystem(document); // Detemine if Lift/Side/Drag, etc. is used.
+  DetermineAxisSystem(document); // Determine if Lift/Side/Drag, etc. is used.
 
   Debug(2);
 
   if ((temp_element = document->FindElement("alphalimits"))) {
     scratch_unit = temp_element->GetAttributeValue("unit");
     if (scratch_unit.empty()) scratch_unit = "RAD";
-    alphaclmin = temp_element->FindElementValueAsNumberConvertFromTo("min", scratch_unit, "RAD");
-    alphaclmax = temp_element->FindElementValueAsNumberConvertFromTo("max", scratch_unit, "RAD");
+    alphaclmin0 = temp_element->FindElementValueAsNumberConvertFromTo("min", scratch_unit, "RAD");
+    alphaclmax0 = temp_element->FindElementValueAsNumberConvertFromTo("max", scratch_unit, "RAD");
+    alphaclmin = alphaclmin0;
+    alphaclmax = alphaclmax0;
   }
 
   if ((temp_element = document->FindElement("hysteresis_limits"))) {
@@ -481,47 +476,25 @@ void FGAerodynamics::bind(void)
 {
   typedef double (FGAerodynamics::*PMF)(int) const;
 
-  PropertyManager->Tie("forces/fbx-aero-lbs", this,1,
-                       (PMF)&FGAerodynamics::GetForces);
-  PropertyManager->Tie("forces/fby-aero-lbs", this,2,
-                       (PMF)&FGAerodynamics::GetForces);
-  PropertyManager->Tie("forces/fbz-aero-lbs", this,3,
-                       (PMF)&FGAerodynamics::GetForces);
-  PropertyManager->Tie("moments/l-aero-lbsft", this,1,
-                       (PMF)&FGAerodynamics::GetMoments);
-  PropertyManager->Tie("moments/m-aero-lbsft", this,2,
-                       (PMF)&FGAerodynamics::GetMoments);
-  PropertyManager->Tie("moments/n-aero-lbsft", this,3,
-                       (PMF)&FGAerodynamics::GetMoments);
-  PropertyManager->Tie("forces/fwx-aero-lbs", this,1,
-                       (PMF)&FGAerodynamics::GetvFw);
-  PropertyManager->Tie("forces/fwy-aero-lbs", this,2,
-                       (PMF)&FGAerodynamics::GetvFw);
-  PropertyManager->Tie("forces/fwz-aero-lbs", this,3,
-                       (PMF)&FGAerodynamics::GetvFw);
-  PropertyManager->Tie("forces/lod-norm", this,
-                       &FGAerodynamics::GetLoD);
-  PropertyManager->Tie("aero/cl-squared", this,
-                       &FGAerodynamics::GetClSquared);
+  PropertyManager->Tie("forces/fbx-aero-lbs",  this, 1, (PMF)&FGAerodynamics::GetForces);
+  PropertyManager->Tie("forces/fby-aero-lbs",  this, 2, (PMF)&FGAerodynamics::GetForces);
+  PropertyManager->Tie("forces/fbz-aero-lbs",  this, 3, (PMF)&FGAerodynamics::GetForces);
+  PropertyManager->Tie("moments/l-aero-lbsft", this, 1, (PMF)&FGAerodynamics::GetMoments);
+  PropertyManager->Tie("moments/m-aero-lbsft", this, 2, (PMF)&FGAerodynamics::GetMoments);
+  PropertyManager->Tie("moments/n-aero-lbsft", this, 3, (PMF)&FGAerodynamics::GetMoments);
+  PropertyManager->Tie("forces/fwx-aero-lbs",  this, 1, (PMF)&FGAerodynamics::GetvFw);
+  PropertyManager->Tie("forces/fwy-aero-lbs",  this, 2, (PMF)&FGAerodynamics::GetvFw);
+  PropertyManager->Tie("forces/fwz-aero-lbs",  this, 3, (PMF)&FGAerodynamics::GetvFw);
+  PropertyManager->Tie("forces/lod-norm",      this, &FGAerodynamics::GetLoD);
+  PropertyManager->Tie("aero/cl-squared",      this, &FGAerodynamics::GetClSquared);
   PropertyManager->Tie("aero/qbar-area", &qbar_area);
-  PropertyManager->Tie("aero/alpha-max-rad", this,
-                       &FGAerodynamics::GetAlphaCLMax,
-                       &FGAerodynamics::SetAlphaCLMax,
-                       true);
-  PropertyManager->Tie("aero/alpha-min-rad", this,
-                       &FGAerodynamics::GetAlphaCLMin,
-                       &FGAerodynamics::SetAlphaCLMin,
-                       true);
-  PropertyManager->Tie("aero/bi2vel", this,
-                       &FGAerodynamics::GetBI2Vel);
-  PropertyManager->Tie("aero/ci2vel", this,
-                       &FGAerodynamics::GetCI2Vel);
-  PropertyManager->Tie("aero/alpha-wing-rad", this,
-                       &FGAerodynamics::GetAlphaW);
-  PropertyManager->Tie("systems/stall-warn-norm", this,
-                        &FGAerodynamics::GetStallWarn);
-  PropertyManager->Tie("aero/stall-hyst-norm", this,
-                        &FGAerodynamics::GetHysteresisParm);
+  PropertyManager->Tie("aero/alpha-max-rad",   this, &FGAerodynamics::GetAlphaCLMax, &FGAerodynamics::SetAlphaCLMax, true);
+  PropertyManager->Tie("aero/alpha-min-rad",   this, &FGAerodynamics::GetAlphaCLMin, &FGAerodynamics::SetAlphaCLMin, true);
+  PropertyManager->Tie("aero/bi2vel",          this, &FGAerodynamics::GetBI2Vel);
+  PropertyManager->Tie("aero/ci2vel",          this, &FGAerodynamics::GetCI2Vel);
+  PropertyManager->Tie("aero/alpha-wing-rad",  this, &FGAerodynamics::GetAlphaW);
+  PropertyManager->Tie("systems/stall-warn-norm", this, &FGAerodynamics::GetStallWarn);
+  PropertyManager->Tie("aero/stall-hyst-norm", this, &FGAerodynamics::GetHysteresisParm);
 }
 
 //%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
