@@ -50,8 +50,8 @@ INCLUDES
 
 namespace JSBSim {
 
-static const char *IdSrc = "$Id: FGAtmosphere.cpp,v 1.55 2013/01/26 17:06:49 bcoconni Exp $";
-static const char *IdHdr = ID_ATMOSPHERE;
+IDENT(IdSrc,"$Id: FGAtmosphere.cpp,v 1.59 2014/05/07 19:51:43 bcoconni Exp $");
+IDENT(IdHdr,ID_ATMOSPHERE);
 
 /*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 CLASS IMPLEMENTATION
@@ -80,6 +80,8 @@ FGAtmosphere::~FGAtmosphere()
 
 bool FGAtmosphere::InitModel(void)
 {
+  if (!FGModel::InitModel()) return false;
+
   Calculate(0.0);
   SLtemperature = Temperature = 518.67;
   SLpressure = Pressure = 2116.22;
@@ -242,8 +244,8 @@ double FGAtmosphere::ConvertFromPSF(double p, ePressure unit) const
 
 void FGAtmosphere::bind(void)
 {
-  typedef double (FGAtmosphere::*PMFi)(int) const;
-  typedef void (FGAtmosphere::*PMF)(int, double);
+//  typedef double (FGAtmosphere::*PMFi)(int) const;
+//  typedef void (FGAtmosphere::*PMF)(int, double);
   PropertyManager->Tie("atmosphere/T-R", this, &FGAtmosphere::GetTemperature);
   PropertyManager->Tie("atmosphere/rho-slugs_ft3", this, &FGAtmosphere::GetDensity);
   PropertyManager->Tie("atmosphere/P-psf", this, &FGAtmosphere::GetPressure);
