@@ -43,6 +43,7 @@ INCLUDES
 #include <iostream>
 
 #include "FGAuxiliary.h"
+#include "initialization/FGInitialCondition.h"
 #include "FGFDMExec.h"
 #include "input_output/FGPropertyManager.h"
 
@@ -50,8 +51,8 @@ using namespace std;
 
 namespace JSBSim {
 
-static const char *IdSrc = "$Id: FGAuxiliary.cpp,v 1.62 2013/09/11 12:43:20 jberndt Exp $";
-static const char *IdHdr = ID_AUXILIARY;
+IDENT(IdSrc,"$Id: FGAuxiliary.cpp,v 1.67 2014/05/17 15:28:51 jberndt Exp $");
+IDENT(IdHdr,ID_AUXILIARY);
 
 /*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 CLASS IMPLEMENTATION
@@ -96,6 +97,8 @@ FGAuxiliary::FGAuxiliary(FGFDMExec* fdmex) : FGModel(fdmex)
 
 bool FGAuxiliary::InitModel(void)
 {
+  if (!FGModel::InitModel()) return false;
+
   pt = in.Pressure;
   tat = in.Temperature;
   tatc = RankineToCelsius(tat);
@@ -163,7 +166,7 @@ bool FGAuxiliary::Run(bool Holding)
 
   double Vt2 = Vt*Vt;
 
-  if ( Vt > 1.0 ) {
+  if ( Vt > 0.001 ) {
     if (vAeroUVW(eW) != 0.0)
       alpha = AeroU2 > 0.0 ? atan2(vAeroUVW(eW), vAeroUVW(eU)) : 0.0;
     if (vAeroUVW(eV) != 0.0)
@@ -172,7 +175,7 @@ bool FGAuxiliary::Run(bool Holding)
     //double signU=1;
     //if (vAeroUVW(eU) < 0.0) signU=-1;
 
-    if ( mUW >= 1.0 ) {
+    if ( mUW >= 0.001 ) {
       adot = (vAeroUVW(eU)*in.vUVWdot(eW) - vAeroUVW(eW)*in.vUVWdot(eU))/mUW;
       // bdot = (signU*mUW*in.vUVWdot(eV)
       //        - vAeroUVW(eV)*(vAeroUVW(eU)*in.vUVWdot(eU) + vAeroUVW(eW)*in.vUVWdot(eW)))/(Vt2*sqrt(mUW));
@@ -219,7 +222,7 @@ bool FGAuxiliary::Run(bool Holding)
   if (abs(MachU) > 0.0) {
     vcas = sqrt(7 * in.PressureSL / in.DensitySL * (A-1));
     veas = sqrt(2 * qbar / in.DensitySL);
-    vtrue = 1116.43559 * MachU * sqrt(in.Temperature / 518.67);
+    vtrue = 1116.43559 * Mach * sqrt(in.Temperature / 518.67);
   } else {
     vcas = veas = vtrue = 0.0;
   }
