@@ -45,8 +45,8 @@ INCLUDES
 #include "FGFDMExec.h"
 #include "FGGroundReactions.h"
 #include "input_output/FGPropertyManager.h"
-#include "input_output/FGXMLFileRead.h"
 #include "input_output/FGXMLElement.h"
+#include "input_output/FGModelLoader.h"
 
 #include "models/flight_control/FGFilter.h"
 #include "models/flight_control/FGDeadBand.h"
@@ -71,8 +71,8 @@ using namespace std;
 
 namespace JSBSim {
 
-static const char *IdSrc = "$Id: FGFCS.cpp,v 1.83 2013/11/24 11:40:56 bcoconni Exp $";
-static const char *IdHdr = ID_FCS;
+IDENT(IdSrc,"$Id: FGFCS.cpp,v 1.90 2014/06/09 11:52:07 bcoconni Exp $");
+IDENT(IdHdr,ID_FCS);
 
 /*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 CLASS IMPLEMENTATION
@@ -124,6 +124,8 @@ FGFCS::~FGFCS()
 
 bool FGFCS::InitModel(void)
 {
+  if (!FGModel::InitModel()) return false;
+
   unsigned int i;
 
   for (i=0; i<ThrottlePos.size(); i++) ThrottlePos[i] = 0.0;
@@ -486,40 +488,21 @@ void FGFCS::SetPropFeather(int engineNum, bool setting)
 
 //%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 
-bool FGFCS::Load(Element* el, SystemType systype)
+bool FGFCS::Load(Element* document, SystemType type)
 {
-  string name, file, fname="", interface_property_string, parent_name;
+  string name, parent_name;
   Element *component_element;
   Element *channel_element;
-  FGXMLFileRead XMLFileRead;
-  Element* document;
   
-// ToDo: The handling of name and file attributes could be improved, here,
-//       considering that a name can be in the external file, as well.
+  systype = type;
 
-  name = el->GetAttributeValue("name");
+  // Load interface properties from document
+  if (!FGModel::Load(document))
+    return false;
 
-  if (name.empty() || !el->GetAttributeValue("file").empty()) {
-    fname = el->GetAttributeValue("file");
-    if (systype == stSystem) {
-      file = FindSystemFullPathname(fname);
-    } else { 
-      file = FDMExec->GetFullAircraftPath() + "/" + fname + ".xml";
-    }
-    if (fname.empty()) {
-      cerr << "FCS, Autopilot, or system does not appear to be defined inline nor in a file" << endl;
-      return false;
-    } else {
-      document = XMLFileRead.LoadXMLDocument(file);
-      if (!document) {
-        cerr << "Error loading file " << file << endl;
-        return false;
-      }
-      name = document->GetAttributeValue("name");
-    }
-  } else {
-    document = el;
-  }
+  name = document->GetAttributeValue("name");
+
+  Name = "Flight Control Systems Model: " + document->GetAttributeValue("name");
 
   if (document->GetName() == "autopilot") {
     Name = "Autopilot: " + document->GetAttributeValue("name");
@@ -532,41 +515,6 @@ bool FGFCS::Load(Element* el, SystemType systype)
 
   if (document->GetName() == "flight_control") bindModel();
 
-  FGModel::Load(document); // Load interface properties from document
-
-  // After reading interface properties in a file, read properties in the local
-  // flight_control, autopilot, or system element. This allows general-purpose
-  // systems to be defined in a file, with overrides or initial loaded constants
-  // supplied in the relevant element of the aircraft configuration file.
-
-  Element* property_element = 0;
-
-  if (!fname.empty()) {
-    property_element = el->FindElement("property");
-    if (property_element && debug_lvl > 0) cout << endl << "    Overriding properties" << endl << endl;
-    while (property_element) {
-      double value=0.0;
-      if ( ! property_element->GetAttributeValue("value").empty())
-        value = property_element->GetAttributeValueAsNumber("value");
-
-      interface_property_string = property_element->GetDataLine();
-      if (PropertyManager->HasNode(interface_property_string)) {
-        FGPropertyNode* node = PropertyManager->GetNode(interface_property_string);
-        if (debug_lvl > 0)
-          cout << "      " << "Overriding value for property " << interface_property_string
-               << " (old value: " << node->getDoubleValue() << "  new value: " << value << ")" << endl;
-        node->setDoubleValue(value);
-      } else {
-        interface_properties.push_back(new double(value));
-        PropertyManager->Tie(interface_property_string, interface_properties.back());
-        if (debug_lvl > 0)
-          cout << "      " << interface_property_string << " (initial value: " << value << ")" << endl;
-      }
-      
-      property_element = el->FindNextElement("property");
-    }
-  }
-
   channel_element = document->FindElement("channel");
   
   while (channel_element) {
@@ -669,68 +617,16 @@ double FGFCS::GetBrake(FGLGear::BrakeGroup bg)
 
 //%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 
-string FGFCS::FindSystemFullPathname(const string& sysfilename)
+string FGFCS::FindFullPathName(const string& sysfilename) const
 {
-  string fullpath, localpath;
-  string system_filename = sysfilename;
-  string systemPath = FDMExec->GetSystemsPath();
-  string aircraftPath = FDMExec->GetFullAircraftPath() + "/";
-  ifstream system_file;
+  string name = FGModel::FindFullPathName(sysfilename);
 
-  fullpath = systemPath + "/";
-  localpath = aircraftPath + "Systems/";
+  if (systype != stSystem || !name.empty()) return name;
 
-  if (system_filename.length() <=4 || system_filename.substr(system_filename.length()-4, 4) != ".xml") {
-    system_filename.append(".xml");
-  }
+  name = CheckFullPathName(FDMExec->GetFullAircraftPath() + "/Systems", sysfilename);
+  if (!name.empty()) return name;
 
-  system_file.open(string(aircraftPath + system_filename).c_str());
-  if ( !system_file.is_open()) {
-    system_file.open(string(localpath + system_filename).c_str());
-    if ( !system_file.is_open()) {
-      system_file.open(string(fullpath + system_filename).c_str());
-      if ( !system_file.is_open()) {
-        cerr << " Could not open system file: " << system_filename << " in path "
-             << fullpath << " or " << localpath << endl;
-        return string("");
-      } else {
-        return string(fullpath + system_filename);
-      }
-    } else {
-      return string(localpath + system_filename);
-    }
-  } else {
-    return string(aircraftPath + system_filename);
-  }
-  return string("");
-}
-
-//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-
-ifstream* FGFCS::FindSystemFile(const string& sysfilename)
-{
-  string fullpath, localpath;
-  string system_filename = sysfilename;
-  string systemPath = FDMExec->GetSystemsPath();
-  string aircraftPath = FDMExec->GetFullAircraftPath();
-  ifstream* system_file = new ifstream();
-
-  fullpath = systemPath + "/";
-  localpath = aircraftPath + "/Systems/";
-
-  if (system_filename.substr(system_filename.length()-4, 4) != ".xml") {
-    system_filename.append(".xml");
-  }
-
-  system_file->open(string(localpath + system_filename).c_str());
-  if ( !system_file->is_open()) {
-    system_file->open(string(fullpath + system_filename).c_str());
-      if ( !system_file->is_open()) {
-        cerr << " Could not open system file: " << system_filename << " in path "
-             << fullpath << " or " << localpath << endl;
-      }
-  }
-  return system_file;
+  return CheckFullPathName(FDMExec->GetSystemsPath(), sysfilename);
 }
 
 //%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
