@@ -42,21 +42,22 @@ INCLUDES
 #include "FGLGear.h"
 #include "FGAccelerations.h"
 #include "input_output/FGPropertyManager.h"
-#include "input_output/FGXMLFileRead.h"
 #include "input_output/FGXMLElement.h"
 
 using namespace std;
 
 namespace JSBSim {
 
-static const char *IdSrc = "$Id: FGGroundReactions.cpp,v 1.43 2013/11/24 11:40:56 bcoconni Exp $";
-static const char *IdHdr = ID_GROUNDREACTIONS;
+IDENT(IdSrc,"$Id: FGGroundReactions.cpp,v 1.51 2014/06/09 11:52:07 bcoconni Exp $");
+IDENT(IdHdr,ID_GROUNDREACTIONS);
 
 /*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 CLASS IMPLEMENTATION
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%*/
 
-FGGroundReactions::FGGroundReactions(FGFDMExec* fgex) : FGModel(fgex)
+FGGroundReactions::FGGroundReactions(FGFDMExec* fgex) :
+   FGModel(fgex),
+   FGSurface(fgex)
 {
   Name = "FGGroundReactions";
 
@@ -79,6 +80,16 @@ FGGroundReactions::~FGGroundReactions(void)
 
 bool FGGroundReactions::InitModel(void)
 {
+  if (!FGModel::InitModel()) return false;
+
+  vForces.InitMatrix();
+  vMoments.InitMatrix();
+
+  multipliers.clear();
+
+  for (unsigned int i=0; i<lGear.size(); i++)
+    lGear[i]->ResetToIC();
+
   return true;
 }
 
@@ -102,7 +113,7 @@ bool FGGroundReactions::Run(bool Holding)
   // Perhaps there is some commonality for things which only need to be
   // calculated once.
   for (unsigned int i=0; i<lGear.size(); i++) {
-    vForces  += lGear[i]->GetBodyForces();
+    vForces  += lGear[i]->GetBodyForces(this);
     vMoments += lGear[i]->GetMoments();
   }
 
@@ -127,25 +138,18 @@ bool FGGroundReactions::GetWOW(void) const
 
 //%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 
-bool FGGroundReactions::Load(Element* elem)
+bool FGGroundReactions::Load(Element* document)
 {
   int num=0;
-  string fname="", file="";
-  string separator = "/";
-  FGXMLFileRead XMLFileRead;
-  Element* document;
 
-  fname = elem->GetAttributeValue("file");
-  if (!fname.empty()) {
-    file = FDMExec->GetFullAircraftPath() + separator + fname;
-    document = XMLFileRead.LoadXMLDocument(file);
-    if (document == 0L) return false;
-  } else {
-    document = elem;
-  }
+  Name = "Ground Reactions Model: " + document->GetAttributeValue("name");
 
   Debug(2);
 
+  // Perform base class Pre-Load
+  if (!FGModel::Load(document))
+    return false;
+
   unsigned int numContacts = document->GetNumElements("contact");
   lGear.resize(numContacts);
   Element* contact_element = document->FindElement("contact");
@@ -154,8 +158,6 @@ bool FGGroundReactions::Load(Element* elem)
     contact_element = document->FindNextElement("contact");
   }
 
-  FGModel::Load(document); // Perform base class Load
-
   for (unsigned int i=0; i<lGear.size();i++) lGear[i]->bind();
 
   PostLoad(document, PropertyManager);
@@ -251,7 +253,9 @@ string FGGroundReactions::GetGroundReactionValues(string delimeter) const
 
 void FGGroundReactions::bind(void)
 {
-  typedef double (FGGroundReactions::*PMF)(int) const;
+  eSurfaceType = ctGROUND;
+  FGSurface::bind();
+
   PropertyManager->Tie("gear/num-units", this, &FGGroundReactions::GetNumGearUnits);
   PropertyManager->Tie("gear/wow", this, &FGGroundReactions::GetWOW);
 }
