@@ -41,18 +41,18 @@ INCLUDES
 #include <iostream>
 #include <iomanip>
 #include <cstdlib>
+
 #include "FGMassBalance.h"
 #include "FGFDMExec.h"
 #include "input_output/FGPropertyManager.h"
-#include "input_output/FGXMLFileRead.h"
 #include "input_output/FGXMLElement.h"
 
 using namespace std;
 
 namespace JSBSim {
 
-static const char *IdSrc = "$Id: FGMassBalance.cpp,v 1.43 2013/11/24 11:40:56 bcoconni Exp $";
-static const char *IdHdr = ID_MASSBALANCE;
+IDENT(IdSrc,"$Id: FGMassBalance.cpp,v 1.51 2014/11/29 13:47:19 bcoconni Exp $");
+IDENT(IdHdr,ID_MASSBALANCE);
 
 /*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 CLASS IMPLEMENTATION
@@ -92,6 +92,8 @@ FGMassBalance::~FGMassBalance()
 
 bool FGMassBalance::InitModel(void)
 {
+  if (!FGModel::InitModel()) return false;
+
   vLastXYZcg.InitMatrix(0.0);
   vDeltaXYZcg.InitMatrix(0.0);
 
@@ -100,25 +102,9 @@ bool FGMassBalance::InitModel(void)
 
 //%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 
-bool FGMassBalance::Load(Element* elem)
+static FGMatrix33 ReadInertiaMatrix(Element* document)
 {
-  string element_name = "";
   double bixx, biyy, bizz, bixy, bixz, biyz;
-  string fname="", file="";
-  string separator = "/";
-  FGXMLFileRead XMLFileRead;
-  Element* document;
-
-  fname = elem->GetAttributeValue("file");
-  if (!fname.empty()) {
-    file = FDMExec->GetFullAircraftPath() + separator + fname;
-    document = XMLFileRead.LoadXMLDocument(file);
-    if (document == 0L) return false;
-  } else {
-    document = elem;
-  }
-
-  FGModel::Load(document); // Perform base class Load.
 
   bixx = biyy = bizz = bixy = bixz = biyz = 0.0;
   if (document->FindElement("ixx"))
@@ -133,9 +119,25 @@ bool FGMassBalance::Load(Element* elem)
     bixz = document->FindElementValueAsNumberConvertTo("ixz", "SLUG*FT2");
   if (document->FindElement("iyz"))
     biyz = document->FindElementValueAsNumberConvertTo("iyz", "SLUG*FT2");
-  SetAircraftBaseInertias(FGMatrix33(  bixx,  -bixy,  bixz,
-                                      -bixy,  biyy,  -biyz,
-                                       bixz,  -biyz,  bizz ));
+
+  return FGMatrix33(  bixx,  -bixy,  bixz,
+                      -bixy,  biyy,  -biyz,
+                      bixz,  -biyz,  bizz );
+}
+
+//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+
+bool FGMassBalance::Load(Element* document)
+{
+  string element_name = "";
+
+  Name = "Mass Properties Model: " + document->GetAttributeValue("name");
+
+  // Perform base class Pre-Load
+  if (!FGModel::Load(document))
+    return false;
+
+  SetAircraftBaseInertias(ReadInertiaMatrix(document));
   if (document->FindElement("emptywt")) {
     EmptyWeight = document->FindElementValueAsNumberConvertTo("emptywt", "LBS");
   }
@@ -298,6 +300,10 @@ void FGMassBalance::AddPointMass(Element* el)
     } else {
     }
   }
+  else {
+    pm->SetPointMassShapeType(PointMass::esUnspecified);
+    pm->SetPointMassMoI(ReadInertiaMatrix(el));
+  }
 
   pm->bind(PropertyManager, PointMasses.size());
   PointMasses.push_back(pm);
@@ -396,6 +402,9 @@ void FGMassBalance::bind(void)
                        (PMF)&FGMassBalance::GetXYZcg);
   PropertyManager->Tie("inertia/cg-z-in", this,3,
                        (PMF)&FGMassBalance::GetXYZcg);
+  typedef int (FGMassBalance::*iOPV)() const;
+  PropertyManager->Tie("inertia/print-mass-properties", this, (iOPV)0,
+                       &FGMassBalance::GetMassPropertiesReport, false);
 }
 
 //%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -420,7 +429,7 @@ void FGMassBalance::PointMass::bind(FGPropertyManager* PropertyManager, int num)
 
 //%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 
-void FGMassBalance::GetMassPropertiesReport(void) const
+void FGMassBalance::GetMassPropertiesReport(int i)
 {
   cout << endl << fgblue << highint 
        << "  Mass Properties Report (English units: lbf, in, slug-ft^2)"
