@@ -38,16 +38,16 @@ HISTORY
 INCLUDES
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%*/
 
-#include <iostream>
 #include "FGModel.h"
 #include "FGFDMExec.h"
+#include "input_output/FGModelLoader.h"
 
 using namespace std;
 
 namespace JSBSim {
 
-static const char *IdSrc = "$Id: FGModel.cpp,v 1.21 2013/01/14 22:44:52 bcoconni Exp $";
-static const char *IdHdr = ID_MODEL;
+IDENT(IdSrc,"$Id: FGModel.cpp,v 1.25 2014/06/09 11:52:07 bcoconni Exp $");
+IDENT(IdHdr,ID_MODEL);
 
 /*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 GLOBAL DECLARATIONS
@@ -84,7 +84,7 @@ FGModel::~FGModel()
 bool FGModel::InitModel(void)
 {
   exe_ctr = 1;
-  return true;
+  return FGModelFunctions::InitModel();
 }
 
 //%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -101,6 +101,54 @@ bool FGModel::Run(bool Holding)
   else              return true;
 }
 
+//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+
+string FGModel::FindFullPathName(const string& fname) const
+{
+  return CheckFullPathName(FDMExec->GetFullAircraftPath(), fname);
+}
+
+//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+
+bool FGModel::Load(Element* el)
+{
+  FGModelLoader ModelLoader(this);
+  Element* document = ModelLoader.Open(el);
+
+  if (!document) return false;
+
+  if (document->GetName() != el->GetName()) {
+    cerr << el->ReadFrom()
+         << " Read model '" << document->GetName()
+         << "' while expecting model '" << el->GetName() << "'" << endl;
+    return false;
+  }
+
+  bool result = FGModelFunctions::Load(document, PropertyManager);
+
+  if (document != el) {
+    el->MergeAttributes(document);
+
+    // After reading interface properties in a file, read properties in the
+    // local model element. This allows general-purpose models to be defined in
+    // a file, with overrides or initial loaded constants supplied in the
+    // relevant element of the aircraft configuration file.
+
+    LocalProperties.Load(el, PropertyManager, true);
+
+    Element* element = document->FindElement();
+    while (element) {
+      el->AddChildElement(element);
+      element->SetParent(el);
+      element = document->FindNextElement();
+    }
+
+    document = el;
+  }
+
+  return result;
+}
+
 //%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 //    The bitmasked value choices are as follows:
 //    unset: In this case (the default) JSBSim would only print
