@@ -69,6 +69,7 @@ INCLUDES
 #include <iomanip>
 #include <fstream>
 
+#include "initialization/FGInitialCondition.h"
 #include "FGPropagate.h"
 #include "FGGroundReactions.h"
 #include "FGFDMExec.h"
@@ -78,8 +79,8 @@ using namespace std;
 
 namespace JSBSim {
 
-static const char *IdSrc = "$Id: FGPropagate.cpp,v 1.119 2013/11/24 11:40:56 bcoconni Exp $";
-static const char *IdHdr = ID_PROPAGATE;
+IDENT(IdSrc,"$Id: FGPropagate.cpp,v 1.126 2014/11/30 12:35:32 bcoconni Exp $");
+IDENT(IdHdr,ID_PROPAGATE);
 
 /*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 CLASS IMPLEMENTATION
@@ -100,10 +101,10 @@ FGPropagate::FGPropagate(FGFDMExec* fdmex)
   integrator_rotational_position = eRectEuler;
   integrator_translational_position = eAdamsBashforth3;
 
-  VState.dqPQRidot.resize(4, FGColumnVector3(0.0,0.0,0.0));
-  VState.dqUVWidot.resize(4, FGColumnVector3(0.0,0.0,0.0));
-  VState.dqInertialVelocity.resize(4, FGColumnVector3(0.0,0.0,0.0));
-  VState.dqQtrndot.resize(4, FGQuaternion(0.0,0.0,0.0));
+  VState.dqPQRidot.resize(5, FGColumnVector3(0.0,0.0,0.0));
+  VState.dqUVWidot.resize(5, FGColumnVector3(0.0,0.0,0.0));
+  VState.dqInertialVelocity.resize(5, FGColumnVector3(0.0,0.0,0.0));
+  VState.dqQtrndot.resize(5, FGQuaternion(0.0,0.0,0.0));
 
   bind();
   Debug(0);
@@ -120,14 +121,16 @@ FGPropagate::~FGPropagate(void)
 
 bool FGPropagate::InitModel(void)
 {
+  if (!FGModel::InitModel()) return false;
+
   // For initialization ONLY:
   VState.vLocation.SetEllipse(in.SemiMajor, in.SemiMinor);
-  VState.vLocation.SetAltitudeAGL(4.0, FDMExec->GetSimTime());
+  VState.vLocation.SetAltitudeAGL(4.0);
 
-  VState.dqPQRidot.resize(4, FGColumnVector3(0.0,0.0,0.0));
-  VState.dqUVWidot.resize(4, FGColumnVector3(0.0,0.0,0.0));
-  VState.dqInertialVelocity.resize(4, FGColumnVector3(0.0,0.0,0.0));
-  VState.dqQtrndot.resize(4, FGColumnVector3(0.0,0.0,0.0));
+  VState.dqPQRidot.resize(5, FGColumnVector3(0.0,0.0,0.0));
+  VState.dqUVWidot.resize(5, FGColumnVector3(0.0,0.0,0.0));
+  VState.dqInertialVelocity.resize(5, FGColumnVector3(0.0,0.0,0.0));
+  VState.dqQtrndot.resize(5, FGColumnVector3(0.0,0.0,0.0));
 
   integrator_rotational_rate = eRectEuler;
   integrator_translational_rate = eAdamsBashforth2;
@@ -185,7 +188,7 @@ void FGPropagate::SetInitialState(const FGInitialCondition *FGIC)
 
 void FGPropagate::InitializeDerivatives()
 {
-  for (int i=0; i<4; i++) {
+  for (int i=0; i<5; i++) {
     VState.dqPQRidot[i] = in.vPQRidot;
     VState.dqUVWidot[i] = in.vUVWidot;
     VState.dqInertialVelocity[i] = VState.vInertialVelocity;
@@ -310,8 +313,14 @@ void FGPropagate::Integrate( FGColumnVector3& Integrand,
     break;
   case eAdamsBashforth4: Integrand += (1/24.0)*dt*(55.0*ValDot[0] - 59.0*ValDot[1] + 37.0*ValDot[2] - 9.0*ValDot[3]);
     break;
+  case eAdamsBashforth5: Integrand += dt*((1901./720.)*ValDot[0] - (1387./360.)*ValDot[1] + (109./30.)*ValDot[2] - (637./360.)*ValDot[3] + (251./720.)*ValDot[4]);
+    break;
   case eNone: // do nothing, freeze translational rate
     break;
+  case eBuss1:
+  case eBuss2:
+  case eLocalLinearization:
+    throw("Can only use Buss (1 & 2) or local linearization integration methods in for rotational position!");
   default:
     break;
   }
@@ -339,6 +348,8 @@ void FGPropagate::Integrate( FGQuaternion& Integrand,
     break;
   case eAdamsBashforth4: Integrand += (1/24.0)*dt*(55.0*ValDot[0] - 59.0*ValDot[1] + 37.0*ValDot[2] - 9.0*ValDot[3]);
     break;
+  case eAdamsBashforth5: Integrand += dt*((1901./720.)*ValDot[0] - (1387./360.)*ValDot[1] + (109./30.)*ValDot[2] - (637./360.)*ValDot[3] + (251./720.)*ValDot[4]);
+    break;
   case eBuss1:
     {
       // This is the first order method as described in Samuel R. Buss paper[6].
@@ -474,8 +485,8 @@ void FGPropagate::RecomputeLocalTerrainVelocity()
 {
   FGLocation contact;
   FGColumnVector3 normal;
-  VState.vLocation.GetContactPoint(FDMExec->GetSimTime(), contact, normal,
-                                   LocalTerrainVelocity, LocalTerrainAngularVelocity);
+  VState.vLocation.GetContactPoint(contact, normal, LocalTerrainVelocity,
+                                   LocalTerrainAngularVelocity);
 }
 
 //%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -498,28 +509,28 @@ void FGPropagate::SetSeaLevelRadius(double tt)
 
 double FGPropagate::GetLocalTerrainRadius(void) const
 {
-  return VState.vLocation.GetTerrainRadius(FDMExec->GetSimTime());
+  return VState.vLocation.GetTerrainRadius();
 }
 
 //%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 
 double FGPropagate::GetDistanceAGL(void) const
 {
-  return VState.vLocation.GetAltitudeAGL(FDMExec->GetSimTime());
+  return VState.vLocation.GetAltitudeAGL();
 }
 
 //%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 
 double FGPropagate::GetDistanceAGLKm(void) const
 {
-  return VState.vLocation.GetAltitudeAGL(FDMExec->GetSimTime())*0.0003048;
+  return VState.vLocation.GetAltitudeAGL()*0.0003048;
 }
 
 //%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 
 void FGPropagate::SetDistanceAGL(double tt)
 {
-  VState.vLocation.SetAltitudeAGL(tt, FDMExec->GetSimTime());
+  VState.vLocation.SetAltitudeAGL(tt);
   UpdateVehicleState();
 }
 
@@ -527,7 +538,7 @@ void FGPropagate::SetDistanceAGL(double tt)
 
 void FGPropagate::SetDistanceAGLKm(double tt)
 {
-  VState.vLocation.SetAltitudeAGL(tt*3280.8399, FDMExec->GetSimTime());
+  VState.vLocation.SetAltitudeAGL(tt*3280.8399);
   UpdateVehicleState();
 }
 
@@ -719,6 +730,10 @@ void FGPropagate::bind(void)
   PropertyManager->Tie("velocities/qi-rad_sec", this, eQ, (PMF)&FGPropagate::GetPQRi);
   PropertyManager->Tie("velocities/ri-rad_sec", this, eR, (PMF)&FGPropagate::GetPQRi);
 
+  PropertyManager->Tie("velocities/eci-x-fps", this, eX, (PMF)&FGPropagate::GetInertialVelocity);
+  PropertyManager->Tie("velocities/eci-y-fps", this, eY, (PMF)&FGPropagate::GetInertialVelocity);
+  PropertyManager->Tie("velocities/eci-z-fps", this, eZ, (PMF)&FGPropagate::GetInertialVelocity);
+
   PropertyManager->Tie("velocities/eci-velocity-mag-fps", this, &FGPropagate::GetInertialVelocityMagnitude);
   PropertyManager->Tie("velocities/ned-velocity-mag-fps", this, &FGPropagate::GetNEDVelocityMagnitude);
 
@@ -739,6 +754,14 @@ void FGPropagate::bind(void)
                           &FGPropagate::GetTerrainElevation,
                           &FGPropagate::SetTerrainElevation, false);
 
+  PropertyManager->Tie("position/eci-x-ft", this, eX, (PMF)&FGPropagate::GetInertialPosition);
+  PropertyManager->Tie("position/eci-y-ft", this, eY, (PMF)&FGPropagate::GetInertialPosition);
+  PropertyManager->Tie("position/eci-z-ft", this, eZ, (PMF)&FGPropagate::GetInertialPosition);
+
+  PropertyManager->Tie("position/ecef-x-ft", this, eX, (PMF)&FGPropagate::GetLocation);
+  PropertyManager->Tie("position/ecef-y-ft", this, eY, (PMF)&FGPropagate::GetLocation);
+  PropertyManager->Tie("position/ecef-z-ft", this, eZ, (PMF)&FGPropagate::GetLocation);
+
   PropertyManager->Tie("position/epa-rad", this, &FGPropagate::GetEarthPositionAngle);
   PropertyManager->Tie("metrics/terrain-radius", this, &FGPropagate::GetLocalTerrainRadius);
 
