@@ -58,17 +58,15 @@ INCLUDES
 #include "models/propulsion/FGElectric.h"
 #include "models/propulsion/FGTurboProp.h"
 #include "models/propulsion/FGTank.h"
-#include "input_output/FGPropertyManager.h"
-#include "input_output/FGXMLFileRead.h"
-#include "input_output/FGXMLElement.h"
+#include "input_output/FGModelLoader.h"
 #include "math/FGColumnVector3.h"
 
 using namespace std;
 
 namespace JSBSim {
 
-static const char *IdSrc = "$Id: FGPropulsion.cpp,v 1.71 2013/11/24 11:40:56 bcoconni Exp $";
-static const char *IdHdr = ID_PROPULSION;
+IDENT(IdSrc,"$Id: FGPropulsion.cpp,v 1.80 2014/06/29 10:18:16 bcoconni Exp $");
+IDENT(IdHdr,ID_PROPULSION);
 
 extern short debug_lvl;
 
@@ -81,7 +79,6 @@ FGPropulsion::FGPropulsion(FGFDMExec* exec) : FGModel(exec)
 {
   Name = "FGPropulsion";
 
-  InitializedEngines = 0;
   numSelectedFuelTanks = numSelectedOxiTanks = 0;
   numTanks = numEngines = 0;
   numOxiTanks = numFuelTanks = 0;
@@ -97,7 +94,6 @@ FGPropulsion::FGPropulsion(FGFDMExec* exec) : FGModel(exec)
   HaveRocketEngine =
   HaveTurboPropEngine =
   HaveElectricEngine = false;
-  HasInitializedEngines = false;
 
   Debug(0);
 }
@@ -119,32 +115,15 @@ bool FGPropulsion::InitModel(void)
 {
   bool result = true;
 
+  if (!FGModel::InitModel()) return false;
+
+  vForces.InitMatrix();
+  vMoments.InitMatrix();
+
   for (unsigned int i=0; i<numTanks; i++) Tanks[i]->ResetToIC();
 
-  for (unsigned int i=0; i<numEngines; i++) {
-    switch (Engines[i]->GetType()) {
-      case FGEngine::etPiston:
-        ((FGPiston*)Engines[i])->ResetToIC();
-        try {
-          if (HasInitializedEngines && (InitializedEngines & i)) InitRunning(i);
-        } catch (string str) {
-          cerr << str << endl;
-          result = false;
-        }
-        break;
-      case FGEngine::etTurbine:
-        ((FGTurbine*)Engines[i])->ResetToIC();
-        try {
-          if (HasInitializedEngines && (InitializedEngines & i)) InitRunning(i);
-        } catch (string str) {
-          cerr << str << endl;
-          result = false;
-        }
-        break;
-      default:
-        break;
-    }
-  }
+  for (unsigned int i=0; i<numEngines; i++)
+    Engines[i]->ResetToIC();
 
   return result;
 }
@@ -284,7 +263,8 @@ void FGPropulsion::ConsumeFuel(FGEngine* engine)
 
   if (engine->GetType() == FGEngine::etRocket) {
     double OxidizerToBurn = engine->CalcOxidizerNeed();                // How much fuel does this engine need?
-    double OxidizerNeededPerTank = OxidizerToBurn / TanksWithOxidizer; // Determine fuel needed per tank.  
+    double OxidizerNeededPerTank = 0;
+    if (TanksWithOxidizer > 0) OxidizerNeededPerTank = OxidizerToBurn / TanksWithOxidizer; // Determine fuel needed per tank.  
     for (unsigned int i=0; i<FeedListOxi.size(); i++) {
       Tanks[FeedListOxi[i]]->Drain(OxidizerNeededPerTank); 
     }
@@ -353,9 +333,6 @@ void FGPropulsion::InitRunning(int n)
     GetEngine(n)->InitRunning();
     GetSteadyState();
 
-    InitializedEngines = 1 << n;
-    HasInitializedEngines = true;
-
   } else if (n < 0) { // -1 refers to "All Engines"
 
     for (unsigned int i=0; i<GetNumEngines(); i++) {
@@ -365,34 +342,23 @@ void FGPropulsion::InitRunning(int n)
     }
 
     GetSteadyState();
-    InitializedEngines = -1;
-    HasInitializedEngines = true;
   }
 }
 
 //%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 
-bool FGPropulsion::Load(Element* elem)
+bool FGPropulsion::Load(Element* el)
 {
-  string type, engine_filename;
-  string separator = "/";
-  Element *el=0;
-  FGXMLFileRead XMLFileRead;
-  FGXMLParse main_file_parser;
+  FGModelLoader ModelLoader(this);
 
   Debug(2);
+  ReadingEngine = false;
 
-  string fname="", file="";
-  fname = elem->GetAttributeValue("file");
-  if (!fname.empty()) {
-    file = FDMExec->GetFullAircraftPath() + separator + fname;
-    el = XMLFileRead.LoadXMLDocument(file, main_file_parser);
-    if (el == 0L) return false;
-  } else {
-    el = elem;
-  }
+  Name = "Propulsion Model: " + el->GetAttributeValue("name");
 
-  FGModel::Load(el); // Perform base class Load.
+  // Perform base class Pre-Load
+  if (!FGModel::Load(el))
+    return false;
 
   // Process tank definitions first to establish the number of fuel tanks
 
@@ -408,51 +374,47 @@ bool FGPropulsion::Load(Element* elem)
   numSelectedFuelTanks = numFuelTanks;
   numSelectedOxiTanks  = numOxiTanks;
 
+  ReadingEngine = true;
   Element* engine_element = el->FindElement("engine");
   while (engine_element) {
-    engine_filename = engine_element->GetAttributeValue("file");
+    if (!ModelLoader.Open(engine_element)) return false;
 
-    if (engine_filename.empty()) {
-      cerr << "Engine definition did not supply an engine file." << endl;
-      return false;
-    }
-
-    engine_filename = FindEngineFullPathname(engine_filename);
-    if (engine_filename.empty()) {
-      // error message already printed by FindEngineFullPathname()
-      return false;
-    }
-
-    Element* document = XMLFileRead.LoadXMLDocument(engine_filename);
-    document->SetParent(engine_element);
-
-    type = document->GetName();
     try {
-      if (type == "piston_engine") {
+      // Locate the thruster definition
+      Element* thruster_element = engine_element->FindElement("thruster");
+      if (!thruster_element || !ModelLoader.Open(thruster_element))
+        throw("No thruster definition supplied with engine definition.");
+
+      if (engine_element->FindElement("piston_engine")) {
         HavePistonEngine = true;
         if (!IsBound) bind();
-        Engines.push_back(new FGPiston(FDMExec, document, numEngines, in));
-      } else if (type == "turbine_engine") {
+        Element *element = engine_element->FindElement("piston_engine");
+        Engines.push_back(new FGPiston(FDMExec, element, numEngines, in));
+      } else if (engine_element->FindElement("turbine_engine")) {
         HaveTurbineEngine = true;
         if (!IsBound) bind();
-        Engines.push_back(new FGTurbine(FDMExec, document, numEngines, in));
-      } else if (type == "turboprop_engine") {
+        Element *element = engine_element->FindElement("turbine_engine");
+        Engines.push_back(new FGTurbine(FDMExec, element, numEngines, in));
+      } else if (engine_element->FindElement("turboprop_engine")) {
         HaveTurboPropEngine = true;
         if (!IsBound) bind();
-        Engines.push_back(new FGTurboProp(FDMExec, document, numEngines, in));
-      } else if (type == "rocket_engine") {
+        Element *element = engine_element->FindElement("turboprop_engine");
+        Engines.push_back(new FGTurboProp(FDMExec, element, numEngines, in));
+      } else if (engine_element->FindElement("rocket_engine")) {
         HaveRocketEngine = true;
         if (!IsBound) bind();
-        Engines.push_back(new FGRocket(FDMExec, document, numEngines, in));
-      } else if (type == "electric_engine") {
+        Element *element = engine_element->FindElement("rocket_engine");
+        Engines.push_back(new FGRocket(FDMExec, element, numEngines, in));
+      } else if (engine_element->FindElement("electric_engine")) {
         HaveElectricEngine = true;
         if (!IsBound) bind();
-        Engines.push_back(new FGElectric(FDMExec, document, numEngines, in));
+        Element *element = engine_element->FindElement("electric_engine");
+        Engines.push_back(new FGElectric(FDMExec, element, numEngines, in));
       } else {
-        cerr << "Unknown engine type: " << type << endl;
-        exit(-5);
+        cerr << engine_element->ReadFrom() << " Unknown engine type" << endl;
+        return false;
       }
-    } catch (std::string str) {
+    } catch (std::string& str) {
       cerr << endl << fgred << str << reset << endl;
       return false;
     }
@@ -460,7 +422,6 @@ bool FGPropulsion::Load(Element* elem)
     numEngines++;
 
     engine_element = el->FindNextElement("engine");
-    XMLFileRead.ResetParser();
   }
 
   CalculateTankInertias();
@@ -476,55 +437,14 @@ bool FGPropulsion::Load(Element* elem)
 
 //%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 
-string FGPropulsion::FindEngineFullPathname(const string& engine_filename)
+string FGPropulsion::FindFullPathName(const string& filename) const
 {
-  string fullpath, localpath;
-  string enginePath = FDMExec->GetEnginePath();
-  string aircraftPath = FDMExec->GetFullAircraftPath();
-  ifstream engine_file;
+  if (!ReadingEngine) return FGModel::FindFullPathName(filename);
 
-  string separator = "/";
+  string name = CheckFullPathName(FDMExec->GetFullAircraftPath() + "/Engines", filename);
+  if (!name.empty()) return name;
 
-  fullpath = enginePath + separator;
-  localpath = aircraftPath + separator + "Engines" + separator;
-
-  engine_file.open(string(localpath + engine_filename + ".xml").c_str());
-  if ( !engine_file.is_open()) {
-    engine_file.open(string(fullpath + engine_filename + ".xml").c_str());
-      if ( !engine_file.is_open()) {
-        cerr << " Could not open engine file: " << engine_filename << " in path "
-             << fullpath << " or " << localpath << endl;
-        return string("");
-      } else {
-        return string(fullpath + engine_filename + ".xml");
-      }
-  }
-  return string(localpath + engine_filename + ".xml");
-}
-
-//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-
-ifstream* FGPropulsion::FindEngineFile(const string& engine_filename)
-{
-  string fullpath, localpath;
-  string enginePath = FDMExec->GetEnginePath();
-  string aircraftPath = FDMExec->GetFullAircraftPath();
-  ifstream* engine_file = new ifstream();
-
-  string separator = "/";
-
-  fullpath = enginePath + separator;
-  localpath = aircraftPath + separator + "Engines" + separator;
-
-  engine_file->open(string(localpath + engine_filename + ".xml").c_str());
-  if ( !engine_file->is_open()) {
-    engine_file->open(string(fullpath + engine_filename + ".xml").c_str());
-      if ( !engine_file->is_open()) {
-        cerr << " Could not open engine file: " << engine_filename << " in path "
-             << localpath << " or " << fullpath << endl;
-      }
-  }
-  return engine_file;
+  return CheckFullPathName(FDMExec->GetEnginePath(), filename);
 }
 
 //%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -832,19 +752,12 @@ void FGPropulsion::bind(void)
                         &FGPropulsion::SetRefuel, true);
   PropertyManager->Tie("propulsion/fuel_dump", this, &FGPropulsion::GetFuelDump,
                         &FGPropulsion::SetFuelDump, true);
-  PropertyManager->Tie("forces/fbx-prop-lbs", this,1,
-                       (PMF)&FGPropulsion::GetForces);
-  PropertyManager->Tie("forces/fby-prop-lbs", this,2,
-                       (PMF)&FGPropulsion::GetForces);
-  PropertyManager->Tie("forces/fbz-prop-lbs", this,3,
-                       (PMF)&FGPropulsion::GetForces);
-  PropertyManager->Tie("moments/l-prop-lbsft", this,1,
-                       (PMF)&FGPropulsion::GetMoments);
-  PropertyManager->Tie("moments/m-prop-lbsft", this,2,
-                       (PMF)&FGPropulsion::GetMoments);
-  PropertyManager->Tie("moments/n-prop-lbsft", this,3,
-                       (PMF)&FGPropulsion::GetMoments);
-
+  PropertyManager->Tie("forces/fbx-prop-lbs", this, eX, (PMF)&FGPropulsion::GetForces);
+  PropertyManager->Tie("forces/fby-prop-lbs", this, eY, (PMF)&FGPropulsion::GetForces);
+  PropertyManager->Tie("forces/fbz-prop-lbs", this, eZ, (PMF)&FGPropulsion::GetForces);
+  PropertyManager->Tie("moments/l-prop-lbsft", this, eX, (PMF)&FGPropulsion::GetMoments);
+  PropertyManager->Tie("moments/m-prop-lbsft", this, eY, (PMF)&FGPropulsion::GetMoments);
+  PropertyManager->Tie("moments/n-prop-lbsft", this, eZ, (PMF)&FGPropulsion::GetMoments);
 }
 
 //%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
