@@ -66,8 +66,8 @@ using namespace std;
 
 namespace JSBSim {
 
-static const char *IdSrc = "$Id: FGMSIS.cpp,v 1.19 2011/12/11 17:03:05 bcoconni Exp $";
-static const char *IdHdr = ID_MSIS;
+IDENT(IdSrc,"$Id: FGMSIS.cpp,v 1.24 2014/01/13 10:46:07 ehofman Exp $");
+IDENT(IdHdr,ID_MSIS);
 
 /*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 EXTERNAL GLOBAL DATA
@@ -464,7 +464,7 @@ void MSIS::spline (double *x, double *y, int n, double yp1, double ypn, double *
   for (k=n-2;k>=0;k--)
     y2[k] = y2[k] * y2[k+1] + u[k];
 
-  delete u;
+  delete[] u;
 }
 
 //%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -739,9 +739,7 @@ double MSIS::globe7(double *p, struct nrlmsise_input *input,
  *       Upper Thermosphere Parameters */
   double t[15];
   int i,j;
-  int sw9=1;
   double apd;
-  double xlong;
   double tloc;
   double c, s, c2, c4, s2;
   double sr = 7.2722E-5;
@@ -749,7 +747,6 @@ double MSIS::globe7(double *p, struct nrlmsise_input *input,
   double dr = 1.72142E-2;
   double hr = 0.2618;
   double cd32, cd18, cd14, cd39;
-  double p32, p18, p14, p39;
   double df;
   double f1, f2;
   double tinf;
@@ -758,11 +755,6 @@ double MSIS::globe7(double *p, struct nrlmsise_input *input,
   tloc=input->lst;
   for (j=0;j<14;j++)
     t[j]=0;
-  if (flags->sw[9]>0)
-    sw9=1;
-  else if (flags->sw[9]<0)
-    sw9=-1;
-  xlong = input->g_long;
 
   /* calculate legendre polynomials */
   c = sin(input->g_lat * dgtr);
@@ -810,10 +802,6 @@ double MSIS::globe7(double *p, struct nrlmsise_input *input,
   cd18 = cos(2.0*dr*(input->doy-p[17]));
   cd14 = cos(dr*(input->doy-p[13]));
   cd39 = cos(2.0*dr*(input->doy-p[38]));
-  p32=p[31];
-  p18=p[17];
-  p14=p[13];
-  p39=p[38];
 
   /* F10.7 EFFECT */
   df = input->f107 - input->f107A;
@@ -971,7 +959,6 @@ double MSIS::glob7s(double *p, struct nrlmsise_input *input,
   double t[14] = {0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,};
   double tt=0.0;
   double cd32=0.0, cd18=0.0, cd14=0.0, cd39=0.0;
-  double p32=0.0, p18=0.0, p14=0.0, p39=0.0;
   int i=0,j=0;
   double dr=1.72142E-2;
   double dgtr=1.74533E-2;
@@ -988,10 +975,6 @@ double MSIS::glob7s(double *p, struct nrlmsise_input *input,
   cd18 = cos(2.0*dr*(input->doy-p[17]));
   cd14 = cos(dr*(input->doy-p[13]));
   cd39 = cos(2.0*dr*(input->doy-p[38]));
-  p32=p[31];
-  p18=p[17];
-  p14=p[13];
-  p39=p[38];
 
   /* F10.7 */
   t[0] = p[21]*dfa;
@@ -1295,14 +1278,14 @@ void MSIS::gts7(struct nrlmsise_input *input, struct nrlmsise_flags *flags,
  */
   double za=0.0;
   int i, j;
-  double ddum=0.0, z=0.0;
+  double z=0.0;
   double zn1[5] = {120.0, 110.0, 100.0, 90.0, 72.5};
   double tinf=0.0;
   int mn1 = 5;
   double g0=0.0;
   double tlb=0.0;
-  double s=0.0, z0=0.0, t0=0.0, tr12=0.0;
-  double db01=0.0, db04=0.0, db14=0.0, db16=0.0, db28=0.0, db32=0.0, db40=0.0, db48=0.0;
+  double s=0.0;
+  double db01=0.0, db04=0.0, db14=0.0, db16=0.0, db28=0.0, db32=0.0, db40=0.0;
   double zh28=0.0, zh04=0.0, zh16=0.0, zh32=0.0, zh40=0.0, zh01=0.0, zh14=0.0;
   double zhm28=0.0, zhm04=0.0, zhm16=0.0, zhm32=0.0, zhm40=0.0, zhm01=0.0, zhm14=0.0;
   double xmd=0.0;
@@ -1361,10 +1344,6 @@ void MSIS::gts7(struct nrlmsise_input *input, struct nrlmsise_flags *flags,
     meso_tgn1[1]=ptm[8]*pma[8][0]*meso_tn1[4]*meso_tn1[4]/(pow((ptm[4]*ptl[3][0]),2.0));
   }
 
-  z0 = zn1[3];
-  t0 = meso_tn1[3];
-  tr12 = 1.0;
-
   /* N2 variation factor at Zlb */
   g28=flags->sw[21]*globe7(pd[2], input, flags);
 
@@ -1601,13 +1580,12 @@ void MSIS::gts7(struct nrlmsise_input *input, struct nrlmsise_flags *flags,
 
   /* total mass density */
   output->d[5] = 1.66E-24*(4.0*output->d[0]+16.0*output->d[1]+28.0*output->d[2]+32.0*output->d[3]+40.0*output->d[4]+ output->d[6]+14.0*output->d[7]);
-  db48=1.66E-24*(4.0*db04+16.0*db16+28.0*db28+32.0*db32+40.0*db40+db01+14.0*db14);
 
 
 
   /* temperature */
   z = sqrt(input->alt*input->alt);
-  ddum = densu(z,1.0, tinf, tlb, 0.0, 0.0, &output->t[1], ptm[5], s, mn1, zn1, meso_tn1, meso_tgn1);
+  densu(z,1.0, tinf, tlb, 0.0, 0.0, &output->t[1], ptm[5], s, mn1, zn1, meso_tn1, meso_tgn1);
   if (flags->sw[0]) {
     for(i=0;i<9;i++)
       output->d[i]=output->d[i]*1.0E6;
