@@ -43,7 +43,7 @@ INCLUDES
 DEFINITIONS
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%*/
 
-#define ID_ACTUATOR "$Id: FGActuator.h,v 1.16 2013/11/24 11:40:56 bcoconni Exp $"
+#define ID_ACTUATOR "$Id: FGActuator.h,v 1.19 2014/08/28 13:44:28 bcoconni Exp $"
 
 /*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 FORWARD DECLARATIONS
@@ -119,7 +119,7 @@ Example:
 @endcode
 
 @author Jon S. Berndt
-@version $Revision: 1.16 $
+@version $Revision: 1.19 $
 */
 
 /*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -138,6 +138,7 @@ public:
       It calls private functions if needed to perform the hysteresis, lag,
       limiting, etc. functions. */
   bool Run (void);
+  void ResetPastStates(void);
 
   // these may need to have the bool argument replaced with a double
   /** This function fails the actuator to zero. The motion to zero
@@ -155,12 +156,8 @@ public:
 private:
   double span;
   double bias;
-  bool rate_limited;
-  double rate_limit;
-  double rate_limit_incr;
-  double rate_limit_decr;
-  FGPropertyNode_ptr rate_limit_incr_prop;
-  FGPropertyNode_ptr rate_limit_decr_prop;
+  FGParameter* rate_limit_incr;
+  FGParameter* rate_limit_decr;
   double hysteresis_width;
   double deadband_width;
   double lag;
