@@ -46,7 +46,6 @@ INCLUDES
 #include "FGPropeller.h"
 #include "FGNozzle.h"
 #include "FGRotor.h"
-#include "input_output/FGXMLFileRead.h"
 #include "input_output/FGXMLElement.h"
 #include "math/FGColumnVector3.h"
 
@@ -54,19 +53,16 @@ using namespace std;
 
 namespace JSBSim {
 
-static const char *IdSrc = "$Id: FGEngine.cpp,v 1.54 2013/11/24 11:40:57 bcoconni Exp $";
-static const char *IdHdr = ID_ENGINE;
+IDENT(IdSrc,"$Id: FGEngine.cpp,v 1.60 2014/06/09 11:52:07 bcoconni Exp $");
+IDENT(IdHdr,ID_ENGINE);
 
 /*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 CLASS IMPLEMENTATION
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%*/
 
-FGEngine::FGEngine(FGFDMExec* exec, Element* engine_element, int engine_number, struct Inputs& input)
+FGEngine::FGEngine(FGFDMExec* exec, int engine_number, struct Inputs& input)
                       : in(input), EngineNumber(engine_number)
 {
-  Element* local_element;
-  FGColumnVector3 location, orientation;
-
   Name = "";
   Type = etUnknown;
   X = Y = Z = 0.0;
@@ -76,66 +72,6 @@ FGEngine::FGEngine(FGFDMExec* exec, Element* engine_element, int engine_number,
   MaxThrottle = 1.0;
   MinThrottle = 0.0;
 
-  ResetToIC(); // initialize dynamic terms
-
-  FDMExec = exec;
-
-  PropertyManager = FDMExec->GetPropertyManager();
-
-  Name = engine_element->GetAttributeValue("name");
-
-  Load(engine_element, PropertyManager, to_string((int)EngineNumber)); // Call ModelFunctions loader
-
-// Find and set engine location
-
-  local_element = engine_element->GetParent()->FindElement("location");
-  if (local_element)  location = local_element->FindElementTripletConvertTo("IN");
-//  else      cerr << "No engine location found for this engine." << endl;
-// Jon: The engine location is not important - the nozzle location is.
-
-  local_element = engine_element->GetParent()->FindElement("orient");
-  if (local_element)  orientation = local_element->FindElementTripletConvertTo("RAD");
-//  else          cerr << "No engine orientation found for this engine." << endl;
-// Jon: The engine orientation has a default and is not normally used.
-
-  SetPlacement(location, orientation);
-
-  // Load thruster
-  local_element = engine_element->GetParent()->FindElement("thruster");
-  if (local_element) {
-    try {
-      if (!LoadThruster(local_element)) exit(-1);
-    } catch (std::string str) {
-      throw("Error loading engine " + Name + ". " + str);
-    }
-  } else {
-    cerr << "No thruster definition supplied with engine definition." << endl;
-  }
-
-  // Load feed tank[s] references
-  local_element = engine_element->GetParent()->FindElement("feed");
-  while (local_element) {
-    int tankID = (int)local_element->GetDataAsNumber();
-    SourceTanks.push_back(tankID);
-    local_element = engine_element->GetParent()->FindNextElement("feed");
-  }
-
-  string property_name, base_property_name;
-  base_property_name = CreateIndexedPropertyName("propulsion/engine", EngineNumber);
-
-  property_name = base_property_name + "/set-running";
-  PropertyManager->Tie( property_name.c_str(), this, &FGEngine::GetRunning, &FGEngine::SetRunning );
-  property_name = base_property_name + "/thrust-lbs";
-  PropertyManager->Tie( property_name.c_str(), Thruster, &FGThruster::GetThrust);
-  property_name = base_property_name + "/fuel-flow-rate-pps";
-  PropertyManager->Tie( property_name.c_str(), this, &FGEngine::GetFuelFlowRate);
-  property_name = base_property_name + "/fuel-flow-rate-gph";
-  PropertyManager->Tie( property_name.c_str(), this, &FGEngine::GetFuelFlowRateGPH);
-  property_name = base_property_name + "/fuel-used-lbs";
-  PropertyManager->Tie( property_name.c_str(), this, &FGEngine::GetFuelUsedLbs);
-
-  PostLoad(engine_element, PropertyManager, to_string((int)EngineNumber));
-
   Debug(0);
 }
 
@@ -160,6 +96,7 @@ void FGEngine::ResetToIC(void)
   FuelFlowRate = 0.0;
   FuelFreeze = false;
   FuelUsedLbs = 0.0;
+  Thruster->ResetToIC();
 }
 
 //%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -235,59 +172,100 @@ void FGEngine::LoadThrusterInputs()
 
 //%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 
-bool FGEngine::LoadThruster(Element *thruster_element)
+void FGEngine::LoadThruster(Element *thruster_element)
 {
-  string token, fullpath, localpath;
-  string thruster_filename, thruster_fullpathname, thrType;
-  string enginePath = FDMExec->GetEnginePath();
-  string aircraftPath = FDMExec->GetFullAircraftPath();
-  ifstream thruster_file;
-  FGColumnVector3 location, orientation;
-  string separator = "/";
-
-  fullpath = enginePath + separator;
-  localpath = aircraftPath + separator + "Engines" + separator;
-
-  thruster_filename = thruster_element->GetAttributeValue("file");
-  if ( !thruster_filename.empty()) {
-    thruster_fullpathname = localpath + thruster_filename + ".xml";
-    thruster_file.open(thruster_fullpathname.c_str());
-    if ( !thruster_file.is_open()) {
-      thruster_fullpathname = fullpath + thruster_filename + ".xml";
-      thruster_file.open(thruster_fullpathname.c_str());
-      if ( !thruster_file.is_open()) {
-        cerr << "Could not open thruster file: " << thruster_filename << ".xml" << endl;
-        return false;
-      } else {
-        thruster_file.close();
-      }
-    } else {
-      thruster_file.close();
-    }
-  } else {
-    cerr << "No thruster filename given." << endl;
-    return false;
-  }
-
-  FGXMLFileRead XMLFileRead;
-  Element *document = XMLFileRead.LoadXMLDocument(thruster_fullpathname);
-  document->SetParent(thruster_element);
-
-  thrType = document->GetName();
-
-  if (thrType == "propeller") {
+  if (thruster_element->FindElement("propeller")) {
+    Element *document = thruster_element->FindElement("propeller");
     Thruster = new FGPropeller(FDMExec, document, EngineNumber);
-  } else if (thrType == "nozzle") {
+  } else if (thruster_element->FindElement("nozzle")) {
+    Element *document = thruster_element->FindElement("nozzle");
     Thruster = new FGNozzle(FDMExec, document, EngineNumber);
-  } else if (thrType == "rotor") {
+  } else if (thruster_element->FindElement("rotor")) {
+    Element *document = thruster_element->FindElement("rotor");
     Thruster = new FGRotor(FDMExec, document, EngineNumber);
-  } else if (thrType == "direct") {
+  } else if (thruster_element->FindElement("direct")) {
+    Element *document = thruster_element->FindElement("direct");
     Thruster = new FGThruster( FDMExec, document, EngineNumber);
+  } else {
+    cerr << thruster_element->ReadFrom() << " Unknown thruster type" << endl;
+    throw("Failed to load the thruster");
   }
 
   Thruster->SetdeltaT(in.TotalDeltaT);
 
   Debug(2);
+}
+
+//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+
+bool FGEngine::Load(FGFDMExec *exec, Element *engine_element)
+{
+  Element* parent_element = engine_element->GetParent();
+  Element* local_element;
+  FGColumnVector3 location, orientation;
+
+  FDMExec = exec;
+
+  PropertyManager = FDMExec->GetPropertyManager();
+
+  Name = engine_element->GetAttributeValue("name");
+
+  FGModelFunctions::Load(engine_element, PropertyManager, to_string((int)EngineNumber)); // Call ModelFunctions loader
+
+// Find and set engine location
+
+  local_element = parent_element->FindElement("location");
+  if (local_element)  location = local_element->FindElementTripletConvertTo("IN");
+//  else      cerr << "No engine location found for this engine." << endl;
+// Jon: The engine location is not important - the nozzle location is.
+
+  local_element = parent_element->FindElement("orient");
+  if (local_element)  orientation = local_element->FindElementTripletConvertTo("RAD");
+//  else          cerr << "No engine orientation found for this engine." << endl;
+// Jon: The engine orientation has a default and is not normally used.
+
+  SetPlacement(location, orientation);
+
+  // Load thruster
+  local_element = parent_element->FindElement("thruster");
+  if (local_element) {
+    try {
+      LoadThruster(local_element);
+    } catch (std::string str) {
+      throw("Error loading engine " + Name + ". " + str);
+    }
+  } else {
+    cerr << "No thruster definition supplied with engine definition." << endl;
+  }
+
+  ResetToIC(); // initialize dynamic terms
+
+  // Load feed tank[s] references
+  local_element = parent_element->FindElement("feed");
+  while (local_element) {
+    int tankID = (int)local_element->GetDataAsNumber();
+    SourceTanks.push_back(tankID);
+    local_element = parent_element->FindNextElement("feed");
+  }
+
+  string property_name, base_property_name;
+  base_property_name = CreateIndexedPropertyName("propulsion/engine", EngineNumber);
+
+  property_name = base_property_name + "/set-running";
+  PropertyManager->Tie( property_name.c_str(), this, &FGEngine::GetRunning, &FGEngine::SetRunning );
+  property_name = base_property_name + "/thrust-lbs";
+  PropertyManager->Tie( property_name.c_str(), Thruster, &FGThruster::GetThrust);
+  property_name = base_property_name + "/fuel-flow-rate-pps";
+  PropertyManager->Tie( property_name.c_str(), this, &FGEngine::GetFuelFlowRate);
+  property_name = base_property_name + "/fuel-flow-rate-gph";
+  PropertyManager->Tie( property_name.c_str(), this, &FGEngine::GetFuelFlowRateGPH);
+  property_name = base_property_name + "/fuel-used-lbs";
+  PropertyManager->Tie( property_name.c_str(), this, &FGEngine::GetFuelUsedLbs);
+
+  PostLoad(engine_element, PropertyManager, to_string((int)EngineNumber));
+
+  Debug(0);
+
   return true;
 }
 
