@@ -53,7 +53,7 @@ INCLUDES
 DEFINITIONS
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%*/
 
-#define ID_ENGINE "$Id: FGEngine.h,v 1.38 2013/11/24 11:40:57 bcoconni Exp $"
+#define ID_ENGINE "$Id: FGEngine.h,v 1.42 2014/06/09 11:52:07 bcoconni Exp $"
 
 /*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 FORWARD DECLARATIONS
@@ -111,7 +111,7 @@ CLASS DOCUMENTATION
   documentation for engine and thruster classes.
 </pre>     
     @author Jon S. Berndt
-    @version $Id: FGEngine.h,v 1.38 2013/11/24 11:40:57 bcoconni Exp $
+    @version $Id: FGEngine.h,v 1.42 2014/06/09 11:52:07 bcoconni Exp $
 */
 
 /*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -150,7 +150,7 @@ public:
     double TotalDeltaT;
   };
 
-  FGEngine(FGFDMExec* exec, Element* el, int engine_number, struct Inputs& input);
+  FGEngine(FGFDMExec* exec, int engine_number, struct Inputs& input);
   virtual ~FGEngine();
 
   enum EngineType {etUnknown, etRocket, etPiston, etTurbine, etTurboprop, etElectric};
@@ -184,7 +184,7 @@ public:
   virtual int InitRunning(void){ return 1; }
 
   /** Resets the Engine parameters to the initial conditions */
-  void ResetToIC(void);
+  virtual void ResetToIC(void);
 
   /** Calculates the thrust of the engine, and other engine functions. */
   virtual void Calculate(void) = 0;
@@ -207,7 +207,7 @@ public:
   virtual const FGColumnVector3& GetBodyForces(void);
   virtual const FGColumnVector3& GetMoments(void);
 
-  bool LoadThruster(Element *el);
+  void LoadThruster(Element *el);
   FGThruster* GetThruster(void) const {return Thruster;}
 
   unsigned int GetSourceTank(unsigned int i) const;
@@ -256,6 +256,7 @@ protected:
 
   std::vector <int> SourceTanks;
 
+  virtual bool Load(FGFDMExec *exec, Element *el);
   void Debug(int from);
 };
 }
