@@ -49,16 +49,18 @@ using namespace std;
 
 namespace JSBSim {
 
-static const char *IdSrc = "$Id: FGRocket.cpp,v 1.31 2013/11/24 11:40:57 bcoconni Exp $";
-static const char *IdHdr = ID_ROCKET;
+IDENT(IdSrc,"$Id: FGRocket.cpp,v 1.37 2014/06/08 12:00:35 bcoconni Exp $");
+IDENT(IdHdr,ID_ROCKET);
 
 /*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 CLASS IMPLEMENTATION
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%*/
 
 FGRocket::FGRocket(FGFDMExec* exec, Element *el, int engine_number, struct Inputs& input)
-  : FGEngine(exec, el, engine_number, input), isp_function(0L)
+  : FGEngine(exec, engine_number, input), isp_function(0L)
 {
+  Load(exec, el);
+
   Type = etRocket;
   Element* thrust_table_element = 0;
   ThrustTable = 0L;
@@ -254,6 +256,12 @@ string FGRocket::GetEngineLabels(const string& delimiter)
 
   buf << Name << " Total Impulse (engine " << EngineNumber << " in lbf)" << delimiter
       << Name << " Total Vacuum Impulse (engine " << EngineNumber << " in lbf)" << delimiter
+      << Name << " Roll Moment (engine " << EngineNumber << " in ft-lbf)" << delimiter
+      << Name << " Pitch Moment (engine " << EngineNumber << " in ft-lbf)" << delimiter
+      << Name << " Yaw Moment (engine " << EngineNumber << " in ft-lbf)" << delimiter
+      << Name << " X Force (engine " << EngineNumber << " in lbf)" << delimiter
+      << Name << " Y Force (engine " << EngineNumber << " in lbf)" << delimiter
+      << Name << " Z Force (engine " << EngineNumber << " in lbf)" << delimiter
       << Thruster->GetThrusterLabels(EngineNumber, delimiter);
 
   return buf.str();
@@ -267,6 +275,8 @@ string FGRocket::GetEngineValues(const string& delimiter)
 
   buf << It << delimiter 
       << ItVac << delimiter 
+      << GetMoments().Dump(delimiter) << delimiter
+      << Thruster->GetBodyForces().Dump(delimiter) << delimiter
       << Thruster->GetThrusterValues(EngineNumber, delimiter);
 
   return buf.str();
@@ -283,6 +293,8 @@ void FGRocket::bindmodel()
 
   property_name = base_property_name + "/total-impulse";
   PropertyManager->Tie( property_name.c_str(), this, &FGRocket::GetTotalImpulse);
+  property_name = base_property_name + "/total-vac-impulse";
+  PropertyManager->Tie( property_name.c_str(), this, &FGRocket::GetVacTotalImpulse);
   property_name = base_property_name + "/vacuum-thrust_lbs";
   PropertyManager->Tie( property_name.c_str(), this, &FGRocket::GetVacThrust);
 
