@@ -48,7 +48,7 @@ INCLUDES
 DEFINITIONS
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%*/
 
-#define ID_ROTOR "$Id: FGRotor.h,v 1.14 2012/03/18 15:48:36 jentron Exp $"
+#define ID_ROTOR "$Id: FGRotor.h,v 1.15 2013/01/26 17:06:50 bcoconni Exp $"
 
 /*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 FORWARD DECLARATIONS
@@ -230,7 +230,7 @@ CLASS DOCUMENTATION
     </dl>
 
     @author Thomas Kreitler
-    @version $Id: FGRotor.h,v 1.14 2012/03/18 15:48:36 jentron Exp $
+    @version $Id: FGRotor.h,v 1.15 2013/01/26 17:06:50 bcoconni Exp $
   */
 
 
@@ -318,16 +318,16 @@ public:
   void SetLongitudinalCtrl(double c) { LongitudinalCtrl = c; }
 
   // Stubs. Only main rotor RPM is returned
-  string GetThrusterLabels(int id, const string& delimeter);
-  string GetThrusterValues(int id, const string& delimeter);
+  std::string GetThrusterLabels(int id, const std::string& delimeter);
+  std::string GetThrusterValues(int id, const std::string& delimeter);
 
 private:
 
   // assist in parameter retrieval
-  double ConfigValueConv( Element* e, const string& ename, double default_val=0.0, 
-                                      const string& unit = "", bool tell=false);
+  double ConfigValueConv( Element* e, const std::string& ename, double default_val=0.0, 
+                                      const std::string& unit = "", bool tell=false);
 
-  double ConfigValue( Element* e, const string& ename, double default_val=0.0,
+  double ConfigValue( Element* e, const std::string& ename, double default_val=0.0,
                                   bool tell=false);
 
   double Configure(Element* rotor_element);
@@ -369,7 +369,7 @@ private:
   double MaximalRPM;
   int    ExternalRPM;
   int    RPMdefinition;
-  FGPropertyManager* ExtRPMsource;
+  FGPropertyNode_ptr ExtRPMsource;
   double SourceGearRatio;
 
   // 'real' rotor parameters
