@@ -36,44 +36,46 @@ HISTORY
 INCLUDES
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%*/
 
+#include <cstdlib>
+#include <iostream>
 #include "FGTank.h"
 #include "FGFDMExec.h"
 #include "input_output/FGXMLElement.h"
 #include "input_output/FGPropertyManager.h"
-#include <iostream>
-#include <cstdlib>
+#include "input_output/string_utilities.h"
 
 using namespace std;
 
 namespace JSBSim {
 
-static const char *IdSrc = "$Id: FGTank.cpp,v 1.37 2013/06/10 02:04:12 jberndt Exp $";
-static const char *IdHdr = ID_TANK;
+IDENT(IdSrc,"$Id: FGTank.cpp,v 1.43 2015/02/02 20:49:11 bcoconni Exp $");
+IDENT(IdHdr,ID_TANK);
 
 /*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 CLASS IMPLEMENTATION
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%*/
 
 FGTank::FGTank(FGFDMExec* exec, Element* el, int tank_number)
-                  : TankNumber(tank_number), Exec(exec)
+                  : TankNumber(tank_number)
 {
   string token, strFuelName;
   Element* element;
   Element* element_Grain;
+  FGPropertyManager *PropertyManager = exec->GetPropertyManager();
   Area = 1.0;
   Density = 6.6;
   InitialTemperature = Temperature = -9999.0;
   Ixx = Iyy = Izz = 0.0;
   InertiaFactor = 1.0;
   Radius = Contents = Standpipe = Length = InnerRadius = 0.0;
-  PreviousUsed = 0.0;
   ExternalFlow = 0.0;
   InitialStandpipe = 0.0;
   Capacity = 0.00001;
   Priority = InitialPriority = 1;
-  PropertyManager = Exec->GetPropertyManager();
   vXYZ.InitMatrix();
   vXYZ_drain.InitMatrix();
+  ixx_unit = iyy_unit = izz_unit = 1.0;
+  grainType = gtUNKNOWN; // This is the default
 
   type = el->GetAttributeValue("type");
   if      (type == "FUEL")     Type = ttFUEL;
@@ -129,14 +131,44 @@ FGTank::FGTank(FGFDMExec* exec, Element* el, int tank_number)
 
   // Check whether this is a solid propellant "tank". Initialize it if true.
 
-  grainType = gtUNKNOWN; // This is the default
-  
   element_Grain = el->FindElement("grain_config");
   if (element_Grain) {
 
     strGType = element_Grain->GetAttributeValue("type");
     if (strGType == "CYLINDRICAL")     grainType = gtCYLINDRICAL;
     else if (strGType == "ENDBURNING") grainType = gtENDBURNING;
+    else if (strGType == "FUNCTION")   {
+      grainType = gtFUNCTION;
+      if (element_Grain->FindElement("ixx") != 0) {
+        Element* element_ixx = element_Grain->FindElement("ixx");
+        if (element_ixx->GetAttributeValue("unit") == "KG*M2") ixx_unit = 1.0/1.35594;
+        if (element_ixx->FindElement("function") != 0) {
+          function_ixx = new FGFunction(PropertyManager, element_ixx->FindElement("function"));
+        }
+      } else {
+        throw("For tank "+to_string(TankNumber)+" and when grain_config is specified an ixx must be specified when the FUNCTION grain type is specified.");
+      }
+
+      if (element_Grain->FindElement("iyy")) {
+        Element* element_iyy = element_Grain->FindElement("iyy");
+        if (element_iyy->GetAttributeValue("unit") == "KG*M2") iyy_unit = 1.0/1.35594;
+        if (element_iyy->FindElement("function") != 0) {
+          function_iyy = new FGFunction(PropertyManager, element_iyy->FindElement("function"));
+        }
+      } else {
+        throw("For tank "+to_string(TankNumber)+" and when grain_config is specified an iyy must be specified when the FUNCTION grain type is specified.");
+      }
+
+      if (element_Grain->FindElement("izz")) {
+        Element* element_izz = element_Grain->FindElement("izz");
+        if (element_izz->GetAttributeValue("unit") == "KG*M2") izz_unit = 1.0/1.35594;
+        if (element_izz->FindElement("function") != 0) {
+          function_izz = new FGFunction(PropertyManager, element_izz->FindElement("function"));
+        }
+      } else {
+        throw("For tank "+to_string(TankNumber)+" and when grain_config is specified an izz must be specified when the FUNCTION grain type is specified.");
+      }
+    }
     else                               cerr << "Unknown propellant grain type specified" << endl;
 
     if (element_Grain->FindElement("length"))
@@ -157,6 +189,9 @@ FGTank::FGTank(FGFDMExec* exec, Element* el, int tank_number)
       case gtENDBURNING:
         Volume = M_PI * Length * Radius * Radius; // cubic inches
         break;
+      case gtFUNCTION:
+        Volume = 1;  // Volume is irrelevant for the FUNCTION type, but it can't be zero!
+        break;
       case gtUNKNOWN:
         cerr << "Unknown grain type found in this rocket engine definition." << endl;
         exit(-1);
@@ -164,22 +199,7 @@ FGTank::FGTank(FGFDMExec* exec, Element* el, int tank_number)
     Density = (Contents*lbtoslug)/Volume; // slugs/in^3
   }
 
-    CalculateInertias();
-
-  string property_name, base_property_name;
-  base_property_name = CreateIndexedPropertyName("propulsion/tank", TankNumber);
-  property_name = base_property_name + "/contents-lbs";
-  PropertyManager->Tie( property_name.c_str(), (FGTank*)this, &FGTank::GetContents,
-                                       &FGTank::SetContents );
-  property_name = base_property_name + "/pct-full";
-  PropertyManager->Tie( property_name.c_str(), (FGTank*)this, &FGTank::GetPctFull);
-
-  property_name = base_property_name + "/priority";
-  PropertyManager->Tie( property_name.c_str(), (FGTank*)this, &FGTank::GetPriority,
-                                       &FGTank::SetPriority );
-  property_name = base_property_name + "/external-flow-rate-pps";
-  PropertyManager->Tie( property_name.c_str(), (FGTank*)this, &FGTank::GetExternalFlow,
-                                       &FGTank::SetExternalFlow );
+  CalculateInertias();
 
   if (Temperature != -9999.0)  InitialTemperature = Temperature = FahrenheitToCelsius(Temperature);
   Area = 40.0 * pow(Capacity/1975, 0.666666667);
@@ -187,6 +207,8 @@ FGTank::FGTank(FGFDMExec* exec, Element* el, int tank_number)
   // A named fuel type will override a previous density value
   if (!strFuelName.empty()) Density = ProcessFuelName(strFuelName); 
 
+  bind(PropertyManager);
+
   Debug(0);
 }
 
@@ -206,7 +228,7 @@ void FGTank::ResetToIC(void)
   SetContents ( InitialContents );
   PctFull = 100.0*Contents/Capacity;
   SetPriority( InitialPriority );
-  PreviousUsed = 0.0;
+  CalculateInertias();
 }
 
 //%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -227,7 +249,6 @@ double FGTank::GetXYZ(int idx) const
 
 double FGTank::Drain(double used)
 {
-//  double AmountToDrain = 2.0*used - PreviousUsed;
   double remaining = Contents - used;
 
   if (remaining >= 0) { // Reduce contents by amount used.
@@ -240,8 +261,8 @@ double FGTank::Drain(double used)
     Contents = 0.0;
     PctFull = 0.0;
   }
-//  PreviousUsed = AmountToDrain;
-  if (grainType != gtUNKNOWN) CalculateInertias();
+
+  CalculateInertias();
 
   return remaining;
 }
@@ -261,6 +282,9 @@ double FGTank::Fill(double amount)
   } else {
     PctFull = Contents/Capacity*100.0;
   }
+
+  CalculateInertias();
+
   return overage;
 }
 
@@ -275,6 +299,8 @@ void FGTank::SetContents(double amount)
   } else {
     PctFull = Contents/Capacity*100.0;
   }
+
+  CalculateInertias();
 }
 
 //%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -329,35 +355,41 @@ void FGTank::CalculateInertias(void)
 
   if (grainType != gtUNKNOWN) { // assume solid propellant
 
-  if (Density > 0.0) {
-    Volume = (Contents*lbtoslug)/Density; // in^3
-  } else if (Contents <= 0.0) {
-    Volume = 0;
-  } else {
-    cerr << endl << "  Solid propellant grain density is zero!" << endl << endl;
-    exit(-1);
-  }
+    if (Density > 0.0) {
+      Volume = (Contents*lbtoslug)/Density; // in^3
+    } else if (Contents <= 0.0) {
+      Volume = 0;
+    } else {
+      cerr << endl << "  Solid propellant grain density is zero!" << endl << endl;
+      exit(-1);
+    }
 
-  switch (grainType) {
+    switch (grainType) {
     case gtCYLINDRICAL:
       InnerRadius = sqrt(Rad2 - Volume/(M_PI * Length));
       RadSumSqr = (Rad2 + InnerRadius*InnerRadius)/144.0;
       Ixx = 0.5*Mass*RadSumSqr;
       Iyy = Mass*(3.0*RadSumSqr + Length*Length/144.0)/12.0;
+      Izz  = Iyy;
       break;
     case gtENDBURNING:
       Length = Volume/(M_PI*Rad2);
       Ixx = 0.5*Mass*Rad2/144.0;
       Iyy = Mass*(3.0*Rad2 + Length*Length)/(144.0*12.0);
+      Izz  = Iyy;
       break;
-    case gtUNKNOWN:
+    case gtFUNCTION:
+      Ixx = function_ixx->GetValue()*ixx_unit;
+      Iyy = function_iyy->GetValue()*iyy_unit;
+      Izz = function_izz->GetValue()*izz_unit;
+      break;
+    default:
       cerr << "Unknown grain type found." << endl;
       exit(-1);
       break;
-  }
-  Izz  = Iyy;
+    }
 
-  } else { // assume liquid propellant
+  } else { // assume liquid propellant: shrinking snowball
 
     if (Radius > 0.0) Ixx = Iyy = Izz = Mass * InertiaFactor * 0.4 * Radius * Radius / 144.0;
 
@@ -400,6 +432,31 @@ double FGTank::ProcessFuelName(const std::string& name)
    return 6.6;
 }
 
+//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+
+void FGTank::bind(FGPropertyManager* PropertyManager)
+{
+  string property_name, base_property_name;
+  base_property_name = CreateIndexedPropertyName("propulsion/tank", TankNumber);
+  property_name = base_property_name + "/contents-lbs";
+  PropertyManager->Tie( property_name.c_str(), (FGTank*)this, &FGTank::GetContents,
+                                       &FGTank::SetContents );
+  property_name = base_property_name + "/pct-full";
+  PropertyManager->Tie( property_name.c_str(), (FGTank*)this, &FGTank::GetPctFull);
+
+  property_name = base_property_name + "/priority";
+  PropertyManager->Tie( property_name.c_str(), (FGTank*)this, &FGTank::GetPriority,
+                                       &FGTank::SetPriority );
+  property_name = base_property_name + "/external-flow-rate-pps";
+  PropertyManager->Tie( property_name.c_str(), (FGTank*)this, &FGTank::GetExternalFlow,
+                                       &FGTank::SetExternalFlow );
+  property_name = base_property_name + "/local-ixx-slug_ft2";
+  PropertyManager->Tie( property_name.c_str(), (FGTank*)this, &FGTank::GetIxx);
+  property_name = base_property_name + "/local-iyy-slug_ft2";
+  PropertyManager->Tie( property_name.c_str(), (FGTank*)this, &FGTank::GetIyy);
+  property_name = base_property_name + "/local-izz-slug_ft2";
+  PropertyManager->Tie( property_name.c_str(), (FGTank*)this, &FGTank::GetIzz);
+}
 
 //%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 //    The bitmasked value choices are as follows:
