@@ -45,8 +45,8 @@ using namespace std;
 
 namespace JSBSim {
 
-static const char *IdSrc = "$Id: FGThruster.cpp,v 1.18 2013/01/12 21:11:59 jberndt Exp $";
-static const char *IdHdr = ID_THRUSTER;
+IDENT(IdSrc,"$Id: FGThruster.cpp,v 1.21 2014/01/13 10:46:10 ehofman Exp $");
+IDENT(IdHdr,ID_THRUSTER);
 
 /*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 CLASS IMPLEMENTATION
@@ -65,8 +65,6 @@ FGThruster::FGThruster(FGFDMExec *FDMExec, Element *el, int num ): FGForce(FDMEx
   Name = el->GetAttributeValue("name");
 
   GearRatio = 1.0;
-  ReverserAngle = 0.0;
-  Thrust = 0.0;
   EngineNum = num;
   PropertyManager = FDMExec->GetPropertyManager();
 
@@ -95,25 +93,26 @@ FGThruster::FGThruster(FGFDMExec *FDMExec, Element *el, int num ): FGForce(FDMEx
 
   } else {
 
-  element = thruster_element->FindElement("orient");
-  if (element)  orientation = element->FindElementTripletConvertTo("RAD");
+    element = thruster_element->FindElement("orient");
+    if (element)  orientation = element->FindElementTripletConvertTo("RAD");
 
-  SetAnglesToBody(orientation);
-  property_name = base_property_name + "/pitch-angle-rad";
-  PropertyManager->Tie( property_name.c_str(), (FGForce *)this, &FGForce::GetPitch, &FGForce::SetPitch);
-  property_name = base_property_name + "/yaw-angle-rad";
-  PropertyManager->Tie( property_name.c_str(), (FGForce *)this, &FGForce::GetYaw, &FGForce::SetYaw);
+    SetAnglesToBody(orientation);
+    property_name = base_property_name + "/pitch-angle-rad";
+    PropertyManager->Tie( property_name.c_str(), (FGForce *)this, &FGForce::GetPitch, &FGForce::SetPitch);
+    property_name = base_property_name + "/yaw-angle-rad";
+    PropertyManager->Tie( property_name.c_str(), (FGForce *)this, &FGForce::GetYaw, &FGForce::SetYaw);
 
-  if (el->GetName() == "direct") // this is a direct thruster. At this time
-                                 // only a direct thruster can be reversed.
-  {
-    property_name = base_property_name + "/reverser-angle-rad";
-    PropertyManager->Tie( property_name.c_str(), (FGThruster *)this, &FGThruster::GetReverserAngle,
-                                                          &FGThruster::SetReverserAngle);
-  }
+    if (el->GetName() == "direct") // this is a direct thruster. At this time
+                                   // only a direct thruster can be reversed.
+      {
+        property_name = base_property_name + "/reverser-angle-rad";
+        PropertyManager->Tie( property_name.c_str(), (FGThruster *)this, &FGThruster::GetReverserAngle,
+                              &FGThruster::SetReverserAngle);
+      }
 
   }
 
+  ResetToIC();
 
   Debug(0);
 }
@@ -127,6 +126,15 @@ FGThruster::~FGThruster()
 
 //%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 
+void FGThruster::ResetToIC(void)
+{
+  ReverserAngle = 0.0;
+  Thrust = 0.0;
+  SetActingLocation(vXYZn);
+}
+
+//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+
 string FGThruster::GetThrusterLabels(int id, const string& delimeter)
 {
   std::ostringstream buf;
