@@ -368,7 +368,7 @@ int Airplane::addWeight(float* pos, float size)
     WeightRec* wr = new WeightRec();
     wr->handle = _model.getBody()->addMass(0, pos);
 
-    wr->surf = new Surface();
+    wr->surf = new Surface(this);
     wr->surf->setPosition(pos);
     wr->surf->setTotalDrag(size*size);
     _model.addSurface(wr->surf);
@@ -530,8 +530,15 @@ float Airplane::compileFuselage(Fuselage* f)
         float scale = 1;
         if(frac < f->mid)
             scale = f->taper+(1-f->taper) * (frac / f->mid);
-        else
-            scale = f->taper+(1-f->taper) * (frac - f->mid) / (1 - f->mid);
+        else {
+	    if( isVersionOrNewer( YASIM_VERSION_32 ) ) {
+		// Correct calculation of width for fuselage taper.
+		scale = 1 - (1-f->taper) * (frac - f->mid) / (1 - f->mid);
+	    } else {
+		// Original, incorrect calculation of width for fuselage taper.
+		scale = f->taper+(1-f->taper) * (frac - f->mid) / (1 - f->mid);
+	    }
+	}
 
         // Where are we?
         float pos[3];
@@ -544,12 +551,43 @@ float Airplane::compileFuselage(Fuselage* f)
         wgt += mass;
 
         // Make a Surface too
-        Surface* s = new Surface();
+        Surface* s = new Surface(this);
         s->setPosition(pos);
+
+	// The following is the original YASim value for sideDrag.
+	// Originally YASim calculated the fuselage's lateral drag
+	// coefficient as (solver drag factor) * (len/wid).
+	// However, this greatly underestimates a fuselage's lateral drag.
 	float sideDrag = len/wid;
+
+	if ( isVersionOrNewer( YASIM_VERSION_32 ) ) {
+	    // New YASim assumes a fixed lateral drag coefficient of 0.5.
+	    // This will not be multiplied by the solver drag factor, because
+	    // that factor is tuned to match the drag in the direction of
+	    // flight, which is completely independent of lateral drag.
+	    // The value of 0.5 is only a ballpark estimate, roughly matching
+	    // the side-on drag for a long cylinder at the higher Reynolds
+	    // numbers typical for an aircraft's lateral drag.
+	    // This fits if the fuselage is long and has a round cross section.
+	    // For flat-sided fuselages, the value should be increased, up to
+	    // a limit of around 2 for a long rectangular prism.
+	    // For very short fuselages, in which the end effects are strong,
+	    // the value should be reduced.
+	    // Such adjustments can be made using the fuselage's "cy" and "cz"
+	    // XML parameters: "cy" for the sides, "cz" for top and bottom.
+	    sideDrag = 0.5;
+	}
+
+	if( isVersionOrNewer( YASIM_VERSION_32 ) ) {
+        	s->setXDrag(f->_cx);
+	}
         s->setYDrag(sideDrag*f->_cy);
         s->setZDrag(sideDrag*f->_cz);
-        s->setTotalDrag(scale*segWgt*f->_cx);
+	if( isVersionOrNewer( YASIM_VERSION_32 ) ) {
+        	s->setTotalDrag(scale*segWgt);
+	} else {
+		s->setTotalDrag(scale*segWgt*f->_cx);
+	}
         s->setInducedDrag(f->_idrag);
 
         // FIXME: fails for fuselages aligned along the Y axis
@@ -563,6 +601,7 @@ float Airplane::compileFuselage(Fuselage* f)
         s->setOrientation(o);
 
         _model.addSurface(s);
+        f->surfs.add(s);
         _surfs.add(s);
     }
     return wgt;
@@ -574,7 +613,7 @@ void Airplane::compileGear(GearRec* gr)
     Gear* g = gr->gear;
 
     // Make a Surface object for the aerodynamic behavior
-    Surface* s = new Surface();
+    Surface* s = new Surface(this);
     gr->surf = s;
 
     // Put the surface at the half-way point on the gear strut, give
@@ -900,9 +939,35 @@ void Airplane::applyDragFactor(float factor)
 	Wing* w = (Wing*)_vstabs.get(i);
 	w->setDragScale(w->getDragScale() * applied);
     }
-    for(i=0; i<_surfs.size(); i++) {
-	Surface* s = (Surface*)_surfs.get(i);
-	s->setTotalDrag(s->getTotalDrag() * applied);
+    for(i=0; i<_fuselages.size(); i++) {
+	Fuselage* f = (Fuselage*)_fuselages.get(i);
+	int j;
+	for(j=0; j<f->surfs.size(); j++) {
+	    Surface* s = (Surface*)f->surfs.get(j);
+	    if( isVersionOrNewer( YASIM_VERSION_32 ) ) {
+		// For new YASim, the solver drag factor is only applied to
+		// the X axis for Fuselage Surfaces.
+		// The solver is tuning the coefficient for longitudinal drag,
+		// along the direction of flight. A fuselage's lateral drag
+		// is completely independent and is normally much higher;
+		// it won't be affected by the streamlining done to reduce
+		// longitudinal drag. So the solver should only adjust the
+		// fuselage's longitudinal (X axis) drag coefficient.
+		s->setXDrag(s->getXDrag() * applied);
+	    } else {
+		// Originally YASim applied the drag factor to all axes
+		// for Fuselage Surfaces.
+		s->setTotalDrag(s->getTotalDrag() * applied);
+	    }
+	}
+    }
+    for(i=0; i<_weights.size(); i++) {
+	WeightRec* wr = (WeightRec*)_weights.get(i);
+	wr->surf->setTotalDrag(wr->surf->getTotalDrag() * applied);
+    }
+    for(i=0; i<_gears.size(); i++) {
+	GearRec* gr = (GearRec*)_gears.get(i);
+	gr->surf->setTotalDrag(gr->surf->getTotalDrag() * applied);
     }
 }
 
