@@ -33,6 +33,10 @@
 #include "FGCocoaMenuBar.hxx"
 #endif
 
+#if defined(SG_WINDOWS)
+#include "FGWindowsMenuBar.hxx"
+#endif
+
 #include "FGPUIDialog.hxx"
 #include "FGFontCache.hxx"
 #include "FGColor.hxx"
@@ -84,6 +88,12 @@ NewGUI::init ()
 void
 NewGUI::shutdown()
 {
+    DialogDict::iterator it = _active_dialogs.begin();
+    for (; it != _active_dialogs.end(); ++it) {
+        delete it->second;
+    }
+    _active_dialogs.clear();
+    
     fgUntie("/sim/menubar/visibility");
     _menubar.reset();
     _dialog_props.clear();
@@ -109,6 +119,13 @@ NewGUI::createMenuBarImplementation()
     if (fgGetBool("/sim/menubar/native", true)) {
         _menubar.reset(new FGCocoaMenuBar);
     }
+#endif
+#if defined(SG_WINDOWS)
+	if (fgGetBool("/sim/menubar/native", true)) {
+	// Windows-native menubar disabled for the moment, fall-through
+	// to PUI version
+   //     _menubar.reset(new FGWindowsMenuBar);
+    }
 #endif
     if (!_menubar.get()) {
         _menubar.reset(new FGPUIMenuBar);
@@ -118,7 +135,7 @@ NewGUI::createMenuBarImplementation()
 void
 NewGUI::reset (bool reload)
 {
-    map<string,FGDialog *>::iterator iter;
+    DialogDict::iterator iter;
     string_list openDialogs;
     // close all open dialogs and remember them ...
     for (iter = _active_dialogs.begin(); iter != _active_dialogs.end(); ++iter)
