@@ -44,8 +44,6 @@
 #include "kln89_symbols.hxx"
 #include <iostream>
 
-#include <ATCDCL/ATCProjection.hxx>
-
 #include <Main/fg_props.hxx>
 #include <simgear/structure/commands.hxx>
 #include <Airports/airport.hxx>
@@ -763,7 +761,7 @@ void KLN89::DrawMap(bool draw_avs) {
 	double mapScaleMeters = _mapScale * (_mapScaleUnits == 0 ? SG_NM_TO_METER : 1000);
 	
 	// TODO - use an aligned projection when either DTK or TK up!
-	FGATCAlignedProjection mapProj(SGGeod::fromRad(_gpsLon, _gpsLat), _mapHeading);
+	AlignedProjection mapProj(SGGeod::fromRad(_gpsLon, _gpsLat), _mapHeading);
 	double meter_per_pix = (_mapOrientation == 0 ? mapScaleMeters / 20.0f : mapScaleMeters / 29.0f);
 //	SGGeod bottomLeft = mapProj.ConvertFromLocal(SGVec3d(gps_max(-57.0 * meter_per_pix, -50000), gps_max((_mapOrientation == 0 ? -20.0 * meter_per_pix : -11.0 * meter_per_pix), -25000), 0.0));
 //	SGGeod topRight = mapProj.ConvertFromLocal(SGVec3d(gps_min(54.0 * meter_per_pix, 50000), gps_min((_mapOrientation == 0 ? 20.0 * meter_per_pix : 29.0 * meter_per_pix), 25000), 0.0));
