@@ -23,6 +23,8 @@
 #include <Navaids/waypoint.hxx>
 #include "Navaids/navrecord.hxx"
 #include "Navaids/FlightPlan.hxx"
+#include <Navaids/routePath.hxx>
+
 #include "Airports/airport.hxx"
 #include "Airports/runways.hxx"
 #include "Autopilot/route_mgr.hxx"
@@ -68,7 +70,8 @@ GPS::Config::Config() :
   _requireHardSurface(true),
   _cdiMaxDeflectionNm(3.0), // linear mode, 3nm at the peg
   _driveAutopilot(true),
-  _courseSelectable(false)
+  _courseSelectable(false),
+  _followLegTrackToFix(true)
 {
   _enableTurnAnticipation = false;
 }
@@ -82,6 +85,7 @@ void GPS::Config::bind(GPS* aOwner, SGPropertyNode* aCfg)
   aOwner->tie(aCfg, "cdi-max-deflection-nm", SGRawValuePointer<double>(&_cdiMaxDeflectionNm));
   aOwner->tie(aCfg, "drive-autopilot", SGRawValuePointer<bool>(&_driveAutopilot));
   aOwner->tie(aCfg, "course-selectable", SGRawValuePointer<bool>(&_courseSelectable));
+  aOwner->tie(aCfg, "follow-leg-track-to-fix", SGRawValuePointer<bool>(&_followLegTrackToFix));
   aOwner->tie(aCfg, "over-flight-distance-nm", SGRawValuePointer<double>(&_overflightDistance));
   aOwner->tie(aCfg, "over-flight-arm-distance-nm", SGRawValuePointer<double>(&_overflightArmDistance));
   aOwner->tie(aCfg, "over-flight-arm-angle-deg", SGRawValuePointer<double>(&_overflightArmAngle));
@@ -222,14 +226,17 @@ GPS::bind()
   tieSGGeodReadOnly(wp0_node, _wp0_position, "longitude-deg", "latitude-deg", "altitude-ft");
   tie(wp0_node, "ID", SGRawValueMethods<GPS, const char*>
       (*this, &GPS::getWP0Ident, NULL));
-    
+  tie(wp0_node, "name", SGRawValueMethods<GPS, const char*>
+      (*this, &GPS::getWP0Name, NULL));
 
   tie(_currentWayptNode, "valid", SGRawValueMethods<GPS, bool>
        (*this, &GPS::getWP1IValid, NULL));
     
   tie(_currentWayptNode, "ID", SGRawValueMethods<GPS, const char*>
     (*this, &GPS::getWP1Ident, NULL));
-  
+  tie(_currentWayptNode, "name", SGRawValueMethods<GPS, const char*>
+    (*this, &GPS::getWP1Name, NULL));
+    
   tie(_currentWayptNode, "distance-nm", SGRawValueMethods<GPS, double>
     (*this, &GPS::getWP1Distance, NULL));
   tie(_currentWayptNode, "bearing-true-deg", SGRawValueMethods<GPS, double>
@@ -315,7 +322,7 @@ GPS::update (double delta_time_sec)
 
   if (_dataValid) {
     if (_wayptController.get()) {
-      _wayptController->update();
+      _wayptController->update(delta_time_sec);
       SGGeod p(_wayptController->position());
       _currentWayptNode->setDoubleValue("longitude-deg", p.getLongitudeDeg());
       _currentWayptNode->setDoubleValue("latitude-deg", p.getLatitudeDeg());
@@ -455,13 +462,20 @@ SGGeod GPS::previousLegWaypointPosition(bool& isValid)
 	FlightPlan::Leg* leg = _route->previousLeg();
 	if (leg){
 		Waypt* waypt = leg->waypoint();
-		if(waypt){
-			isValid = true;
+		if (waypt) {
+            isValid = true;
+            // ensure computations use runway end, not threshold
+            if (waypt->type() == "runway") {
+                RunwayWaypt* rwpt = static_cast<RunwayWaypt*>(waypt);
+                return rwpt->runway()->end();
+            }
+
 			return waypt->position();
 		}
 	}
+
 	isValid = false;
-  return SGGeod();
+    return SGGeod();
 }
 ///////////////////////////////////////////////////////////////////////////
 
@@ -556,9 +570,9 @@ void GPS::currentWaypointChanged()
   }
   
   _currentWaypt = _route->currentLeg()->waypoint();
+    wp1Changed(); // rebuild the active controller
   _desiredCourse = getLegMagCourse();
   _desiredCourseNode->fireValueChanged();
-  wp1Changed();
 }
 
 
@@ -720,16 +734,18 @@ void GPS::computeTurnData()
   }
   
   WayptRef next = _route->nextLeg()->waypoint();
-  if (next->flag(WPT_DYNAMIC) || !_config.turnAnticipationEnabled()) {
+  if (next->flag(WPT_DYNAMIC) ||
+      !_config.turnAnticipationEnabled() ||
+      next->flag(WPT_OVERFLIGHT))
+  {
     _anticipateTurn = false;
     return;
   }
   
   _turnStartBearing = _desiredCourse;
 // compute next leg course
-  double crs, dist;
-  boost::tie(crs, dist) = next->courseAndDistanceFrom(_currentWaypt->position());
-    
+  RoutePath path(_route);
+  double crs = path.trackForIndex(_route->currentIndex() + 1);
 
 // compute offset bearing
   _turnAngle = crs - _turnStartBearing;
@@ -792,9 +808,14 @@ void GPS::updateRouteData()
 {
   double totalDistance = _wayptController->distanceToWayptM() * SG_METER_TO_NM;
   // walk all waypoints from wp2 to route end, and sum
- // for (int i=_routeMgr->currentIndex()+1; i<_routeMgr->numWaypts(); ++i) {
-    //totalDistance += _routeMgr->get_waypoint(i).get_distance();
-  //}
+  for (int i=_route->currentIndex()+1; i<_route->numLegs(); ++i) {
+    FlightPlan::Leg* leg = _route->legAtIndex(i);
+    // omit missed-approach waypoints in distance calculation
+    if (leg->waypoint()->flag(WPT_MISS))
+      continue;
+      
+    totalDistance += leg->distanceNm();
+  }
   
   _routeDistanceNm->setDoubleValue(totalDistance * SG_METER_TO_NM);
   if (_last_speed_kts > 1.0) {
@@ -839,7 +860,7 @@ void GPS::wp1Changed()
   if (_mode == "obs") {
     _legDistanceNm = -1.0;
   } else {
-    _wayptController->update();
+    _wayptController->update(0.0);
     _legDistanceNm = _wayptController->distanceToWayptM() * SG_METER_TO_NM;
   }
 }
@@ -922,16 +943,25 @@ double GPS::getCDIDeflection() const
 
 const char* GPS::getWP0Ident() const
 {
-  if (!_dataValid || (_mode != "leg") || (!_prevWaypt)) {
+  if (!_dataValid || (_mode != "leg") || !_prevWaypt) {
     return "";
   }
   
-  return _prevWaypt->ident().c_str();
+// work around std::string::c_str() storage lifetime with libc++
+// real fix is to allow tie-ing with std::string instead of char*
+  static char identBuf[8];
+  strncpy(identBuf, _prevWaypt->ident().c_str(), 8);
+
+  return identBuf;
 }
 
 const char* GPS::getWP0Name() const
 {
-  return "";
+    if (!_dataValid || !_prevWaypt || !_prevWaypt->source()) {
+        return "";
+    }
+    
+    return _prevWaypt->source()->name().c_str();
 }
 
 bool GPS::getWP1IValid() const
@@ -941,16 +971,25 @@ bool GPS::getWP1IValid() const
 
 const char* GPS::getWP1Ident() const
 {
-  if ((!_dataValid)||(!_currentWaypt)) {
+  if (!_dataValid || !_currentWaypt) {
     return "";
   }
   
-  return _currentWaypt->ident().c_str();
+// work around std::string::c_str() storage lifetime with libc++
+// real fix is to allow tie-ing with std::string instead of char*
+  static char identBuf[8];
+  strncpy(identBuf, _currentWaypt->ident().c_str(), 8);
+    
+  return identBuf;
 }
 
 const char* GPS::getWP1Name() const
 {
-  return "";
+    if (!_dataValid || !_currentWaypt || !_currentWaypt->source()) {
+        return "";
+    }
+    
+    return _currentWaypt->source()->name().c_str();
 }
 
 double GPS::getWP1Distance() const
@@ -1157,6 +1196,16 @@ bool GPS::isScratchPositionValid() const
   return true;
 }
 
+FGPositionedRef GPS::positionedFromScratch() const
+{
+    if (!isScratchPositionValid()) {
+        return NULL;
+    }
+    
+    std::string ident(_scratchNode->getStringValue("ident"));
+    return FGPositioned::findClosestWithIdent(ident, _scratchPos);
+}
+
 void GPS::directTo()
 {  
   if (!isScratchPositionValid()) {
@@ -1165,22 +1214,31 @@ void GPS::directTo()
   
   _prevWaypt = NULL;
   _wp0_position = _indicated_pos;
-  _currentWaypt = new BasicWaypt(_scratchPos, _scratchNode->getStringValue("ident"), NULL);
-  _mode = "dto";
-  clearScratch();
+    
+    FGPositionedRef pos = positionedFromScratch();
+    if (pos) {
+        _currentWaypt = new NavaidWaypoint(pos, NULL);
+    } else {
+        _currentWaypt = new BasicWaypt(_scratchPos, _scratchNode->getStringValue("ident"), NULL);
+    }
+    
+    _mode = "dto";
   wp1Changed();
 }
 
 void GPS::selectOBSMode(flightgear::Waypt* waypt)
 {
-  if (!waypt) {
-    // initialise from scratch
-    if (isScratchPositionValid()) {
+  if (!waypt && isScratchPositionValid()) {
+    FGPositionedRef pos = positionedFromScratch();
+    if (pos) {
+        waypt = new NavaidWaypoint(pos, NULL);
+    } else {
         waypt = new BasicWaypt(_scratchPos, _scratchNode->getStringValue("ident"), NULL);
     }
   }
   
   _mode = "obs";
+  _prevWaypt = NULL;
   _wp0_position = _indicated_pos;
   _currentWaypt = waypt;
   wp1Changed();
