@@ -36,6 +36,7 @@
 #include "mag_compass.hxx"
 #include "marker_beacon.hxx"
 #include "newnavradio.hxx"
+#include "commradio.hxx"
 #include "slip_skid_ball.hxx"
 #include "transponder.hxx"
 #include "turn_indicator.hxx"
@@ -169,6 +170,9 @@ bool FGInstrumentMgr::build (SGPropertyNode* config_props)
         } else if ( name == "marker-beacon" ) {
             set_subsystem( id, new FGMarkerBeacon( node ), 0.2 );
 
+        } else if ( name == "comm-radio" ) {
+            set_subsystem( id, Instrumentation::CommRadio::createInstance( node ) );
+
         } else if ( name == "nav-radio" ) {
             set_subsystem( id, Instrumentation::NavRadio::createInstance( node ) );
 
@@ -218,7 +222,7 @@ bool FGInstrumentMgr::build (SGPropertyNode* config_props)
             set_subsystem( id, new TCAS( node ), 0.2);
             
         } else {
-            SG_LOG( SG_ALL, SG_ALERT, "Unknown top level section: "
+            SG_LOG( SG_INSTR, SG_ALERT, "Unknown top level section: "
                     << name );
             return false;
         }
