@@ -25,6 +25,7 @@
 
 #include <sstream>
 #include <cstring>
+#include <cstdio>
 
 #include <simgear/sg_inlines.h>
 #include <simgear/timing/sg_time.hxx>
@@ -104,6 +105,7 @@ static std::auto_ptr<SGInterpTable> static_terminalRangeInterp,
 FGNavRadio::FGNavRadio(SGPropertyNode *node) :
     _operable(false),
     play_count(0),
+    _nav_search(true),
     _last_freq(0.0),
     target_radial(0.0),
     effective_range(0.0),
@@ -570,7 +572,7 @@ void FGNavRadio::updateReceiver(double dt)
     } // of false courses disabled
     
     const double VOR_FULL_ARC = 20.0; // VOR is -10 .. 10 degree swing
-    _cdiDeflection *= VOR_FULL_ARC / _localizerWidth; // increased localiser sensitivity
+    _cdiDeflection *= VOR_FULL_ARC / _localizerWidth; // increased localizer sensitivity
     
     if (backcourse_node->getBoolValue()) {
       _cdiDeflection = -_cdiDeflection;
@@ -581,7 +583,7 @@ void FGNavRadio::updateReceiver(double dt)
       r = ( r<0.0 ? -r-180.0 : -r+180.0 );
     }
     _cdiDeflection = r;
-  } // of non-localiser case
+  } // of non-localizer case
   
   SG_CLAMP_RANGE(_cdiDeflection, -10.0, 10.0 );
   _cdiDeflection *= signal_quality_norm;
