@@ -40,7 +40,7 @@
 #include <Sound/audioident.hxx>
 
 #include "navradio.hxx"
-
+#include "frequencyformatter.hxx"
 
 namespace Instrumentation {
 
@@ -261,11 +261,11 @@ void NavRadioComponent::search( double frequency, const SGGeod & aircraftPositio
 {
   _navRecord = FGNavList::findByFreq(frequency, aircraftPosition, getNavaidFilter() );
   if( NULL == _navRecord ) {
-    SG_LOG(SG_INSTR,SG_ALERT, "No " << _name << " available at " << frequency );
+    SG_LOG(SG_INSTR,SG_DEBUG, "No " << _name << " available at " << frequency );
     _ident = "";
     return;
   }
-  SG_LOG(SG_INSTR,SG_ALERT, "Using " << _name << "'" << _navRecord->get_ident() << "' for " << frequency );
+  SG_LOG(SG_INSTR,SG_INFO, "Using " << _name << "'" << _navRecord->get_ident() << "' for " << frequency );
   _ident = _navRecord->ident();
 }
 
@@ -793,49 +793,6 @@ void GS::display( NavIndicator & navIndicator )
   navIndicator.setGS( _glideslopeOffset_norm );
 }
 
-/* ------------- A NAV/COMM Frequency formatter ---------------------- */
-
-class FrequencyFormatter : public SGPropertyChangeListener {
-public:
-  FrequencyFormatter( SGPropertyNode_ptr freqNode, SGPropertyNode_ptr fmtFreqNode, double channelSpacing ) :
-    _freqNode( freqNode ),
-    _fmtFreqNode( fmtFreqNode ),
-    _channelSpacing(channelSpacing)
-  {
-    _freqNode->addChangeListener( this );
-    valueChanged(_freqNode);
-  }
-  ~FrequencyFormatter()
-  {
-    _freqNode->removeChangeListener( this );
-  }
-
-  void valueChanged (SGPropertyNode * prop)
-  {
-    // format as fixed decimal "nnn.nn"
-    std::ostringstream buf;
-    buf << std::fixed 
-        << std::setw(5) 
-        << std::setfill('0') 
-        << std::setprecision(2)
-        << getFrequency();
-    _fmtFreqNode->setStringValue( buf.str() );
-  }
-
-  double getFrequency() const 
-  {
-    double d = SGMiscd::roundToInt(_freqNode->getDoubleValue() / _channelSpacing) * _channelSpacing;
-    // strip last digit, do not round
-    return ((int)(d*100))/100.0;
-  }
-
-private:
-  SGPropertyNode_ptr _freqNode;
-  SGPropertyNode_ptr _fmtFreqNode;
-  double _channelSpacing;
-};
-
-
 /* ------------- The NavRadio implementation ---------------------- */
 
 class NavRadioImpl : public NavRadio {
@@ -886,8 +843,8 @@ NavRadioImpl::NavRadioImpl( SGPropertyNode_ptr node ) :
   _name(node->getStringValue("name", "nav")),
   _num(node->getIntValue("number", 0)),
   _rootNode(fgGetNode( std::string("/instrumentation/") + _name, _num, true)),
-  _useFrequencyFormatter( _rootNode->getNode("frequencies/selected-mhz",true), _rootNode->getNode("frequencies/selected-mhz-fmt",true), 0.05 ),
-  _stbyFrequencyFormatter( _rootNode->getNode("frequencies/standby-mhz",true), _rootNode->getNode("frequencies/standby-mhz-fmt",true), 0.05 ),
+  _useFrequencyFormatter( _rootNode->getNode("frequencies/selected-mhz",true), _rootNode->getNode("frequencies/selected-mhz-fmt",true), 0.05, 108.0, 118.0 ),
+  _stbyFrequencyFormatter( _rootNode->getNode("frequencies/standby-mhz",true), _rootNode->getNode("frequencies/standby-mhz-fmt",true), 0.05, 108.0, 118.0 ),
   _navIndicator(_rootNode),
   _stationTTL(0.0),
   _frequency(-1.0),
