@@ -39,6 +39,7 @@
 #include <Viewer/viewmgr.hxx>
 #include <Viewer/viewer.hxx>
 #include <Environment/presets.hxx>
+#include <Navaids/NavDataCache.hxx>
 
 #include "fg_init.hxx"
 #include "fg_io.hxx"
@@ -205,10 +206,32 @@ do_exit (const SGPropertyNode * arg)
 static bool
 do_reset (const SGPropertyNode * arg)
 {
-    fgReInitSubsystems();
+    fgResetIdleState();
     return true;
 }
 
+
+/**
+ * Change aircraft
+ */
+static bool
+do_switch_aircraft (const SGPropertyNode * arg)
+{
+    fgSetString("/sim/aircraft", arg->getStringValue("aircraft"));
+    // start a reset
+    fgResetIdleState();
+    return true;
+}
+
+/**
+ */
+static bool
+do_reposition (const SGPropertyNode * arg)
+{
+  fgStartReposition();
+  return true;
+}
+
 /**
  * Built-in command: replay the FDR buffer
  */
@@ -525,138 +548,6 @@ do_materials_reload (const SGPropertyNode * arg)
     return true;
 }
 
-
-#if 0
-These do_set_(some-environment-parameters) are deprecated and no longer 
-useful/functional - Torsten Dreyer, January 2011
-/**
- * Set the sea level outside air temperature and assigning that to all
- * boundary and aloft environment layers.
- */
-static bool
-do_set_sea_level_degc ( double temp_sea_level_degc)
-{
-    SGPropertyNode *node, *child;
-
-    // boundary layers
-    node = fgGetNode( "/environment/config/boundary" );
-    if ( node != NULL ) {
-      int i = 0;
-      while ( ( child = node->getNode( "entry", i ) ) != NULL ) {
-	child->setDoubleValue( "temperature-sea-level-degc",
-			       temp_sea_level_degc );
-	++i;
-      }
-    }
-
-    // aloft layers
-    node = fgGetNode( "/environment/config/aloft" );
-    if ( node != NULL ) {
-      int i = 0;
-      while ( ( child = node->getNode( "entry", i ) ) != NULL ) {
-	child->setDoubleValue( "temperature-sea-level-degc",
-			       temp_sea_level_degc );
-	++i;
-      }
-    }
-
-    return true;
-}
-
-static bool
-do_set_sea_level_degc (const SGPropertyNode * arg)
-{
-    return do_set_sea_level_degc( arg->getDoubleValue("temp-degc", 15.0) );
-}
-
-
-/**
- * Set the outside air temperature at the "current" altitude by first
- * calculating the corresponding sea level temp, and assigning that to
- * all boundary and aloft environment layers.
- */
-static bool
-do_set_oat_degc (const SGPropertyNode * arg)
-{
-    double oat_degc = arg->getDoubleValue("temp-degc", 15.0);
-    // check for an altitude specified in the arguments, otherwise use
-    // current aircraft altitude.
-    const SGPropertyNode *altitude_ft = arg->getChild("altitude-ft");
-    if ( altitude_ft == NULL ) {
-        altitude_ft = fgGetNode("/position/altitude-ft");
-    }
-
-    FGEnvironment dummy;	// instantiate a dummy so we can leech a method
-    dummy.set_elevation_ft( altitude_ft->getDoubleValue() );
-    dummy.set_temperature_degc( oat_degc );
-    return do_set_sea_level_degc( dummy.get_temperature_sea_level_degc());
-}
-
-/**
- * Set the sea level outside air dewpoint and assigning that to all
- * boundary and aloft environment layers.
- */
-static bool
-do_set_dewpoint_sea_level_degc (double dewpoint_sea_level_degc)
-{
-
-    SGPropertyNode *node, *child;
-
-    // boundary layers
-    node = fgGetNode( "/environment/config/boundary" );
-    if ( node != NULL ) {
-      int i = 0;
-      while ( ( child = node->getNode( "entry", i ) ) != NULL ) {
-	child->setDoubleValue( "dewpoint-sea-level-degc",
-			       dewpoint_sea_level_degc );
-	++i;
-      }
-    }
-
-    // aloft layers
-    node = fgGetNode( "/environment/config/aloft" );
-    if ( node != NULL ) {
-      int i = 0;
-      while ( ( child = node->getNode( "entry", i ) ) != NULL ) {
-	child->setDoubleValue( "dewpoint-sea-level-degc",
-			       dewpoint_sea_level_degc );
-	++i;
-      }
-    }
-
-    return true;
-}
-
-static bool
-do_set_dewpoint_sea_level_degc (const SGPropertyNode * arg)
-{
-    return do_set_dewpoint_sea_level_degc(arg->getDoubleValue("dewpoint-degc", 5.0));
-}
-
-/**
- * Set the outside air dewpoint at the "current" altitude by first
- * calculating the corresponding sea level dewpoint, and assigning
- * that to all boundary and aloft environment layers.
- */
-static bool
-do_set_dewpoint_degc (const SGPropertyNode * arg)
-{
-    double dewpoint_degc = arg->getDoubleValue("dewpoint-degc", 5.0);
-
-    // check for an altitude specified in the arguments, otherwise use
-    // current aircraft altitude.
-    const SGPropertyNode *altitude_ft = arg->getChild("altitude-ft");
-    if ( altitude_ft == NULL ) {
-        altitude_ft = fgGetNode("/position/altitude-ft");
-    }
-
-    FGEnvironment dummy;	// instantiate a dummy so we can leech a method
-    dummy.set_elevation_ft( altitude_ft->getDoubleValue() );
-    dummy.set_dewpoint_degc( dewpoint_degc );
-    return do_set_dewpoint_sea_level_degc(dummy.get_dewpoint_sea_level_degc());
-}
-#endif
-
 /**
  * Built-in command: toggle a bool property value.
  *
@@ -1195,7 +1086,7 @@ static bool
 do_presets_commit (const SGPropertyNode * arg)
 {
     if (fgGetBool("/sim/initialized", false)) {
-      fgReInitSubsystems();
+      fgResetIdleState();
     } else {
       // Nasal can trigger this during initial init, which confuses
       // the logic in ReInitSubsystems, since initial state has not been
@@ -1530,6 +1421,47 @@ do_profiler_stop(const SGPropertyNode *arg)
 }
 
 
+static bool
+do_set_scenery_paths(const SGPropertyNode* arg)
+{
+  SGPropertyNode* sim = fgGetNode("/sim", true);
+  sim->removeChildren("fg-scenery");
+  
+  globals->clear_fg_scenery();
+  
+  std::string terrasyncPath(fgGetString("/sim/terrasync/scenery-dir"));
+  bool seenTerrasyncPath = false;
+  
+  simgear::PropertyList paths = arg->getChildren("path");
+  for (size_t i = 0; i < paths.size(); ++i) {
+    std::string s = paths[i]->getStringValue();
+    if (s == terrasyncPath) {
+      seenTerrasyncPath = true;
+    }
+    
+    globals->append_fg_scenery(s);
+  }
+  
+  if (fgGetBool("/sim/terrasync/enabled") && !seenTerrasyncPath) {
+    globals->append_fg_scenery(terrasyncPath);
+  }
+  
+  if (paths.empty()) {
+    // no scenery paths set *at all*, use the data in FG_ROOT
+    SGPath root(globals->get_fg_root());
+    root.append("Scenery");
+    globals->append_fg_scenery(root.str());
+  }
+
+    // might need to drop ground-nets from the DB. Also need to drop
+    // them from memory, but this is tricky since FGAirportDynamics holds
+    // an instance directly, and AI code may have pointers to ground-net
+    // nodes. For now we'll leave-in memory versions untouched.
+    flightgear::NavDataCache::instance()->dropGroundnetsIfRequired();
+  
+  return true;
+}
+
 ////////////////////////////////////////////////////////////////////////
 // Command setup.
 ////////////////////////////////////////////////////////////////////////
@@ -1549,6 +1481,8 @@ static struct {
     { "nasal", do_nasal },
     { "exit", do_exit },
     { "reset", do_reset },
+    { "reposition", do_reposition },
+    { "switch-aircraft", do_switch_aircraft },
     { "pause", do_pause },
     { "load", do_load },
     { "save", do_save },
@@ -1603,7 +1537,8 @@ static struct {
     { "print-visible-scene", do_print_visible_scene_info },
     { "reload-shaders", do_reload_shaders },
     { "reload-materials", do_materials_reload },
-
+    { "set-scenery-paths", do_set_scenery_paths },
+  
     { "profiler-start", do_profiler_start },
     { "profiler-stop",  do_profiler_stop },
 
