@@ -69,6 +69,11 @@
 #include <simgear/scene/model/particles.hxx>
 #include <simgear/scene/tsync/terrasync.hxx>
 
+#include <simgear/package/Root.hxx>
+#include <simgear/package/Package.hxx>
+#include <simgear/package/Install.hxx>
+#include <simgear/package/Catalog.hxx>
+
 #include <Aircraft/controls.hxx>
 #include <Aircraft/replay.hxx>
 #include <Aircraft/FlightHistory.hxx>
@@ -78,7 +83,6 @@
 
 #include <AIModel/AIManager.hxx>
 
-#include <ATCDCL/ATISmgr.hxx>
 #include <ATC/atc_mgr.hxx>
 
 #include <Autopilot/route_mgr.hxx>
@@ -101,6 +105,7 @@
 #include <Navaids/navdb.hxx>
 #include <Navaids/navlist.hxx>
 #include <Scenery/scenery.hxx>
+#include <Scenery/SceneryPager.hxx>
 #include <Scenery/tilemgr.hxx>
 #include <Scripting/NasalSys.hxx>
 #include <Sound/voice.hxx>
@@ -122,6 +127,8 @@
 #include <Cockpit/cockpitDisplayManager.hxx>
 #include <Network/HTTPClient.hxx>
 #include <Network/fgcom.hxx>
+#include <Network/http/httpd.hxx>
+#include <Include/version.h>
 
 #include <Viewer/CameraGroup.hxx>
 
@@ -142,13 +149,13 @@
 #include <GUI/CocoaHelpers.h> // for Mac impl of platformDefaultDataPath()
 #endif
 
-//#define NEW_RESET 1
-
 using std::string;
 using std::endl;
 using std::cerr;
 using std::cout;
+
 using namespace boost::algorithm;
+using namespace simgear::pkg;
 
 extern osg::ref_ptr<osgViewer::Viewer> viewer;
 
@@ -442,7 +449,7 @@ int fgInitConfig ( int argc, char **argv, bool reinit )
     // Set /sim/fg-home and don't allow malign code to override it until
     // Nasal security is set up.  Use FG_HOME if necessary.
     SGPropertyNode *home = fgGetNode("/sim", true);
-    home->removeChild("fg-home", 0, false);
+    home->removeChild("fg-home", 0);
     home = home->getChild("fg-home", 0, true);
     home->setStringValue(dataPath.c_str());
     home->setAttribute(SGPropertyNode::WRITE, false);
@@ -464,7 +471,7 @@ int fgInitConfig ( int argc, char **argv, bool reinit )
       // told to explicitly ignore
       if (options->isOptionSet("restore-defaults") || options->isOptionSet("ignore-autosave"))
       {
-          SG_LOG(SG_ALL, SG_ALERT, "Ignoring user settings. Restoring defaults.");
+          SG_LOG(SG_GENERAL, SG_ALERT, "Ignoring user settings. Restoring defaults.");
       }
       else
       {
@@ -477,13 +484,94 @@ int fgInitConfig ( int argc, char **argv, bool reinit )
     return flightgear::FG_OPTIONS_OK;
 }
 
+static void initAircraftDirsNasalSecurity()
+{
+    SGPropertyNode* sim = fgGetNode("/sim", true);
+    sim->removeChildren("fg-aircraft");
+
+    int index = 0;
+    string_list const aircraft_paths = globals->get_aircraft_paths();
+    for( string_list::const_iterator it = aircraft_paths.begin();
+                                     it != aircraft_paths.end();
+                                   ++it, ++index )
+    {
+        SGPropertyNode* n = sim->getChild("fg-aircraft", index, true);
+        n->setStringValue(*it);
+        n->setAttribute(SGPropertyNode::WRITE, false);
+    }
+}
+
+void fgInitAircraftPaths(bool reinit)
+{
+  if (!reinit) {
+      // there is some debate if we should be using FG_HOME here (hidden
+      // location) vs a user-visible location inside Documents (especially on
+      // Windows and Mac). Really this location should be managed by FG, not
+      // the user, but it can potentially grow large.
+      SGPath packageAircraftDir = globals->get_fg_home();
+      packageAircraftDir.append("Aircraft");
+
+      SGSharedPtr<Root> pkgRoot(new Root(packageAircraftDir, FLIGHTGEAR_VERSION));
+      // set the http client later (too early in startup right now)
+      globals->setPackageRoot(pkgRoot);
+  }
+
+  SGSharedPtr<Root> pkgRoot(globals->packageRoot());
+  SGPropertyNode* aircraftProp = fgGetNode("/sim/aircraft", true);
+  aircraftProp->setAttribute(SGPropertyNode::PRESERVE, true);
+
+  if (!reinit) {
+      flightgear::Options::sharedInstance()->initPaths();
+  }
+}
+
 int fgInitAircraft(bool reinit)
 {
-    // Scan user config files and command line for a specified aircraft.
     if (!reinit) {
         flightgear::Options::sharedInstance()->initAircraft();
     }
     
+    SGSharedPtr<Root> pkgRoot(globals->packageRoot());
+    SGPropertyNode* aircraftProp = fgGetNode("/sim/aircraft", true);
+
+    string aircraftId(aircraftProp->getStringValue());
+    PackageRef acftPackage = pkgRoot->getPackageById(aircraftId);
+    if (acftPackage) {
+        if (acftPackage->isInstalled()) {
+            SG_LOG(SG_GENERAL, SG_INFO, "Loading aircraft from package:" << acftPackage->qualifiedId());
+
+            // set catalog path so intra-package dependencies within the catalog
+            // are resolved correctly.
+            globals->set_catalog_aircraft_path(acftPackage->catalog()->installRoot());
+
+            // set aircraft-dir to short circuit the search process
+            InstallRef acftInstall = acftPackage->install();
+            fgSetString("/sim/aircraft-dir", acftInstall->path().c_str());
+
+            // overwrite the fully qualified ID with the aircraft one, so the
+            // code in FindAndCacheAircraft works as normal
+            // note since we may be using a variant, we can't use the package ID
+            size_t lastDot = aircraftId.rfind('.');
+            if (lastDot != std::string::npos) {
+                aircraftId = aircraftId.substr(lastDot + 1);
+                aircraftProp->setStringValue(aircraftId);
+
+            }
+            // run the traditional-code path below
+        } else {
+#if 0
+            // naturally the better option would be to on-demand install it!
+            flightgear::fatalMessageBox("Aircraft not installed",
+                                        "Requested aircraft is not currently installed.",
+                                        aircraftId);
+
+            return flightgear::FG_OPTIONS_ERROR;
+#endif
+        }
+    }
+
+    initAircraftDirsNasalSecurity();
+
     FindAndCacheAircraft f(globals->get_props());
     if (!f.loadAircraft()) {
         return flightgear::FG_OPTIONS_ERROR;
@@ -513,7 +601,12 @@ fgInitNav ()
       return false;
     }
   }
-  
+
+    // depend on when the NavCache was initialised, scenery paths may not
+    // have been setup. This is a safe place to consistently check the value,
+    // and drop the ground-nets if something has changed
+    cache->dropGroundnetsIfRequired();
+
   FGTACANList *channellist = new FGTACANList;
   globals->set_channellist( channellist );
   
@@ -547,7 +640,7 @@ bool fgInitGeneral() {
 
     simgear::Dir cwd(simgear::Dir::current());
     SGPropertyNode *curr = fgGetNode("/sim", true);
-    curr->removeChild("fg-current", 0, false);
+    curr->removeChild("fg-current", 0);
     curr = curr->getChild("fg-current", 0, true);
     curr->setStringValue(cwd.path().str());
     curr->setAttribute(SGPropertyNode::WRITE, false);
@@ -600,10 +693,8 @@ void fgCreateSubsystems(bool duringReset) {
     // Initialize the property interpolator subsystem. Put into the INIT
     // group because the "nasal" subsystem may need it at GENERAL take-down.
     ////////////////////////////////////////////////////////////////////
-    FGInterpolator* interp = new FGInterpolator;
-    interp->setRealtimeProperty(fgGetNode("/sim/time/delta-realtime-sec", true));
-    globals->add_subsystem("prop-interpolator", interp, SGSubsystemMgr::INIT);
-    SGPropertyNode::setInterpolationMgr(interp);
+    globals->add_subsystem("prop-interpolator", new FGInterpolator, SGSubsystemMgr::INIT);
+
 
     ////////////////////////////////////////////////////////////////////
     // Add the FlightGear property utilities.
@@ -702,16 +793,6 @@ void fgCreateSubsystems(bool duringReset) {
     globals->add_subsystem("Canvas", new CanvasMgr, SGSubsystemMgr::DISPLAY);
     globals->add_subsystem("CanvasGUI", new GUIMgr, SGSubsystemMgr::DISPLAY);
 
-    ////////////////////////////////////////////////////////////////////
-    // Initialise the ATIS Manager
-    // Note that this is old stuff, but is necessary for the
-    // current ATIS implementation. Therefore, leave it in here
-    // until the ATIS system is ported over to make use of the ATIS 
-    // sub system infrastructure.
-    ////////////////////////////////////////////////////////////////////
-
-    globals->add_subsystem("ATIS", new FGATISMgr, SGSubsystemMgr::INIT, 0.4);
-
     ////////////////////////////////////////////////////////////////////
    // Initialize the ATC subsystem
     ////////////////////////////////////////////////////////////////////
@@ -778,6 +859,12 @@ void fgCreateSubsystems(bool duringReset) {
     globals->add_subsystem("fgcom", new FGCom);
 #endif
 
+    {
+      SGSubsystem * httpd = flightgear::http::FGHttpd::createInstance( fgGetNode(flightgear::http::PROPERTY_ROOT) );
+      if( NULL != httpd ) 
+        globals->add_subsystem("httpd", httpd  );
+    }
+
     ////////////////////////////////////////////////////////////////////
     // Initialize the lighting subsystem.
     ////////////////////////////////////////////////////////////////////
@@ -811,29 +898,6 @@ void fgPostInitSubsystems()
     nasal->init();
     SG_LOG(SG_GENERAL, SG_INFO, "Nasal init took:" << st.elapsedMSec());
 
-    // Ensure IOrules and path validation are working properly by trying to
-    // access a folder/file which should never be accessible.
-    const char* no_access_path =
-#ifdef _WIN32
-      "Z:"
-#endif
-      "/do-not-access";
-
-    if( fgValidatePath(no_access_path, true) )
-      SG_LOG
-      (
-        SG_GENERAL,
-        SG_ALERT,
-        "Check your IOrules! (write to '" << no_access_path << "' is allowed)"
-      );
-    if( fgValidatePath(no_access_path, false) )
-      SG_LOG
-      (
-        SG_GENERAL,
-        SG_ALERT,
-        "Check your IOrules! (read from '" << no_access_path << "' is allowed)"
-      );
-  
     // initialize methods that depend on other subsystems.
     st.stamp();
     globals->get_subsystem_mgr()->postinit();
@@ -847,100 +911,79 @@ void fgPostInitSubsystems()
     fgSetBool("/sim/initialized", true);
 
     SG_LOG( SG_GENERAL, SG_INFO, endl);
-
-                                // Save the initial state for future
-                                // reference.
-    globals->saveInitialState();
 }
 
-// Reset: this is what the 'reset' command (and hence, GUI) is attached to
-void fgReInitSubsystems()
+// re-position is a simplified version of the traditional (legacy)
+// reset procedure. We only need to poke systems which will be upset by
+// a sudden change in aircraft position. Since this potentially includes
+// Nasal, we trigger the 'reinit' signal.
+void fgStartReposition()
 {
-#ifdef NEW_RESET
-    fgResetIdleState();
-    return;
-#endif
-    
-    SGPropertyNode *master_freeze = fgGetNode("/sim/freeze/master");
-
-    SG_LOG( SG_GENERAL, SG_INFO, "fgReInitSubsystems()");
-
-// setup state to begin re-init
-    bool freeze = master_freeze->getBoolValue();
-    if ( !freeze ) {
-        master_freeze->setBoolValue(true);
-    }
-    
-    fgSetBool("/sim/signals/reinit", true);
-    fgSetBool("/sim/crashed", false);
-
-// do actual re-init steps
-    globals->get_subsystem("flight")->unbind();
-    
-  // reset control state, before restoring initial state; -set or config files
-  // may specify values for flaps, trim tabs, magnetos, etc
-    globals->get_controls()->reset_all();
-        
-    globals->restoreInitialState();
-
-    // update our position based on current presets
-    // this will mark position as needed finalized which we'll do in the
-    // main-loop
-    flightgear::initPosition();
-    
-    simgear::SGTerraSync* terraSync =
-        static_cast<simgear::SGTerraSync*>(globals->get_subsystem("terrasync"));
-    if (terraSync) {
-        terraSync->reposition();
-    }
-    
-    // Force reupdating the positions of the ai 3d models. They are used for
-    // initializing ground level for the FDM.
-    globals->get_subsystem("ai-model")->reinit();
-
-    // Initialize the FDM
-    globals->get_subsystem("flight")->reinit();
-
-    // reset replay buffers
-    globals->get_subsystem("replay")->reinit();
-    
-    // reload offsets from config defaults
-    globals->get_viewmgr()->reinit();
-
-    // ugly: finalizePosition waits for METAR to arrive for the new airport.
-    // we don't re-init the environment manager here, since historically we did
-    // not, and doing so seems to have other issues. All that's needed is to
-    // schedule METAR fetch immediately, so it's available for finalizePosition.
-    // So we manually extract the METAR-fetching component inside the environment
-    // manager, and re-init that.
-    SGSubsystemGroup* envMgr = static_cast<SGSubsystemGroup*>(globals->get_subsystem("environment"));
-    if (envMgr) {
-      envMgr->get_subsystem("realwx")->reinit();
-    }
+  SGPropertyNode *master_freeze = fgGetNode("/sim/freeze/master");
+  SG_LOG( SG_GENERAL, SG_INFO, "fgStartReposition()");
   
-    globals->get_subsystem("time")->reinit();
-
-    // need to bind FDMshell again, since we manually unbound it above...
-    globals->get_subsystem("flight")->bind();
-
-    // need to reset aircraft (systems/instruments) so they can adapt to current environment
-    globals->get_subsystem("systems")->reinit();
-    globals->get_subsystem("instrumentation")->reinit();
-
-    globals->get_subsystem("ATIS")->reinit();
-
-// setup state to end re-init
-    fgSetBool("/sim/signals/reinit", false);
-    if ( !freeze ) {
-        master_freeze->setBoolValue(false);
-    }
-    fgSetBool("/sim/sceneryloaded",false);
+  // ensure we are frozen
+  bool freeze = master_freeze->getBoolValue();
+  if ( !freeze ) {
+    master_freeze->setBoolValue(true);
+  }
+  
+  // set this signal so Nasal scripts can take action.
+  fgSetBool("/sim/signals/reinit", true);
+  fgSetBool("/sim/crashed", false);
+  
+  FDMShell* fdm = static_cast<FDMShell*>(globals->get_subsystem("flight"));
+  fdm->unbind();
+  
+  // update our position based on current presets
+  // this will mark position as needed finalized which we'll do in the
+  // main-loop
+  flightgear::initPosition();
+  
+  simgear::SGTerraSync* terraSync =
+  static_cast<simgear::SGTerraSync*>(globals->get_subsystem("terrasync"));
+  if (terraSync) {
+    terraSync->reposition();
+  }
+  
+  // Initialize the FDM
+  globals->get_subsystem("flight")->reinit();
+  
+  // reset replay buffers
+  globals->get_subsystem("replay")->reinit();
+  
+  // ugly: finalizePosition waits for METAR to arrive for the new airport.
+  // we don't re-init the environment manager here, since historically we did
+  // not, and doing so seems to have other issues. All that's needed is to
+  // schedule METAR fetch immediately, so it's available for finalizePosition.
+  // So we manually extract the METAR-fetching component inside the environment
+  // manager, and re-init that.
+  SGSubsystemGroup* envMgr = static_cast<SGSubsystemGroup*>(globals->get_subsystem("environment"));
+  if (envMgr) {
+    envMgr->get_subsystem("realwx")->reinit();
+  }
+  
+  // need to bind FDMshell again, since we manually unbound it above...
+  fdm->bind();
+  
+  // need to reset aircraft (systems/instruments/autopilot)
+  // so they can adapt to current environment
+  globals->get_subsystem("systems")->reinit();
+  globals->get_subsystem("instrumentation")->reinit();
+  globals->get_subsystem("xml-autopilot")->reinit();
+    
+  // setup state to end re-init
+  fgSetBool("/sim/signals/reinit", false);
+  if ( !freeze ) {
+    master_freeze->setBoolValue(false);
+  }
+  fgSetBool("/sim/sceneryloaded",false);
 }
 
 void fgStartNewReset()
 {
     SGPropertyNode_ptr preserved(new SGPropertyNode);
-    
+  
     if (!copyPropertiesWithAttribute(globals->get_props(), preserved, SGPropertyNode::PRESERVE))
         SG_LOG(SG_GENERAL, SG_ALERT, "Error saving preserved state");
     
@@ -982,13 +1025,17 @@ void fgStartNewReset()
         }
     } // of top-level groups iteration
     
+    FGRenderer* render = globals->get_renderer();
+    // needed or we crash in multi-threaded OSG mode
+    render->getViewer()->stopThreading();
+    
     // order is important here since tile-manager shutdown needs to
     // access the scenery object
     globals->set_tile_mgr(NULL);
     globals->set_scenery(NULL);
+    FGScenery::getPagerSingleton()->clearRequests();
     flightgear::CameraGroup::setDefault(NULL);
     
-    FGRenderer* render = globals->get_renderer();
     // don't cancel the pager until after shutdown, since AIModels (and
     // potentially others) can queue delete requests on the pager.
     render->getViewer()->getDatabasePager()->cancel();
@@ -1010,9 +1057,15 @@ void fgStartNewReset()
     simgear::GlobalParticleCallback::setSwitch(NULL);
     
     globals->resetPropertyRoot();
+    // otherwise channels are duplicated
+    globals->get_channel_options_list()->clear();
+  
     fgInitConfig(0, NULL, true);
     fgInitGeneral(); // all of this?
     
+    flightgear::Options::sharedInstance()->processOptions();
+    
+    // PRESERVED properties over-write state from options, intentionally
     if ( copyProperties(preserved, globals->get_props()) ) {
         SG_LOG( SG_GENERAL, SG_INFO, "Preserved state restored successfully" );
     } else {
@@ -1021,11 +1074,12 @@ void fgStartNewReset()
     }
 
     fgGetNode("/sim")->removeChild("aircraft-dir");
+    fgInitAircraftPaths(true);
     fgInitAircraft(true);
-    flightgear::Options::sharedInstance()->processOptions();
     
     render = new FGRenderer;
     render->setEventHandler(eventHandler);
+    eventHandler->reset();
     globals->set_renderer(render);
     render->init();
     render->setViewer(viewer.get());
@@ -1035,6 +1089,7 @@ void fgStartNewReset()
     // must do this before splashinit for Rembrandt
     flightgear::CameraGroup::buildDefaultGroup(viewer.get());
     render->splashinit();
+    viewer->startThreading();
     
     fgOSResetProperties();
 
