@@ -43,10 +43,10 @@
 #include <simgear/props/propertyObject.hxx>
 #include <simgear/props/props_io.hxx>
 #include <simgear/scene/model/modellib.hxx>
+#include <simgear/package/Root.hxx>
 
 #include <Aircraft/controls.hxx>
 #include <Airports/runways.hxx>
-#include <ATCDCL/ATISmgr.hxx>
 #include <Autopilot/route_mgr.hxx>
 #include <GUI/FGFontCache.hxx>
 #include <GUI/gui.h>
@@ -136,7 +136,6 @@ FGGlobals *globals = NULL;
 
 // Constructor
 FGGlobals::FGGlobals() :
-    initial_state( NULL ),
     renderer( new FGRenderer ),
     subsystem_mgr( new SGSubsystemMgr ),
     event_mgr( new SGEventMgr ),
@@ -146,7 +145,6 @@ FGGlobals::FGGlobals() :
     time_params( NULL ),
     ephem( NULL ),
     route_mgr( NULL ),
-    ATIS_mgr( NULL ),
     controls( NULL ),
     viewmgr( NULL ),
     commands( SGCommandMgr::instance() ),
@@ -241,7 +239,6 @@ FGGlobals::~FGGlobals()
     delete time_params;
     set_matlib(NULL);
     delete route_mgr;
-    delete ATIS_mgr;
     delete channel_options_list;
     delete initial_waypoints;
     delete fontcache;
@@ -278,7 +275,7 @@ void FGGlobals::set_fg_root (const std::string &root) {
 
     // remove /sim/fg-root before writing to prevent hijacking
     SGPropertyNode *n = fgGetNode("/sim", true);
-    n->removeChild("fg-root", 0, false);
+    n->removeChild("fg-root", 0);
     n = n->getChild("fg-root", 0, true);
     n->setStringValue(fg_root.c_str());
     n->setAttribute(SGPropertyNode::WRITE, false);
@@ -343,7 +340,6 @@ SGPath FGGlobals::find_data_dir(const std::string& pathSuffix) const
 
 void FGGlobals::append_fg_scenery (const std::string &paths)
 {
-//    fg_scenery.clear();
     SGPropertyNode* sim = fgGetNode("/sim", true);
 
   // find first unused fg-scenery property in /sim
@@ -393,9 +389,33 @@ void FGGlobals::append_fg_scenery (const std::string &paths)
         SGPropertyNode* n = sim->getChild("fg-scenery", propIndex++, true);
         n->setStringValue(abspath.str());
         n->setAttribute(SGPropertyNode::WRITE, false);
+        
+        // temporary fix so these values survive reset
+        n->setAttribute(SGPropertyNode::PRESERVE, true);
     } // of path list iteration
 }
 
+void FGGlobals::clear_fg_scenery()
+{
+  fg_scenery.clear();
+}
+
+void FGGlobals::set_catalog_aircraft_path(const SGPath& path)
+{
+    catalog_aircraft_dir = path;
+}
+
+string_list FGGlobals::get_aircraft_paths() const
+{
+    string_list r;
+    if (!catalog_aircraft_dir.isNull()) {
+        r.push_back(catalog_aircraft_dir.str());
+    }
+
+    r.insert(r.end(), fg_aircraft_dirs.begin(), fg_aircraft_dirs.end());
+    return r;
+}
+
 void FGGlobals::append_aircraft_path(const std::string& path)
 {
   SGPath dirPath(path);
@@ -403,25 +423,21 @@ void FGGlobals::append_aircraft_path(const std::string& path)
     SG_LOG(SG_GENERAL, SG_ALERT, "aircraft path not found:" << path);
     return;
   }
-    
+
   SGPath acSubdir(dirPath);
   acSubdir.append("Aircraft");
   if (acSubdir.exists()) {
-      SG_LOG(SG_GENERAL, SG_WARN, "Specified an aircraft-dir with an 'Aircraft' subdirectory:" << dirPath
-                 << ", will instead use child directory:" << acSubdir);
+      SG_LOG(
+        SG_GENERAL,
+        SG_WARN,
+        "Specified an aircraft-dir with an 'Aircraft' subdirectory:" << dirPath
+        << ", will instead use child directory:" << acSubdir
+      );
       dirPath = acSubdir;
   }
-    
+
   std::string abspath = dirPath.realpath();
-  unsigned int index = fg_aircraft_dirs.size();  
   fg_aircraft_dirs.push_back(abspath);
-  
-// make aircraft dirs available to Nasal
-  SGPropertyNode* sim = fgGetNode("/sim", true);
-  sim->removeChild("fg-aircraft", index, false);
-  SGPropertyNode* n = sim->getChild("fg-aircraft", index, true);
-  n->setStringValue(abspath);
-  n->setAttribute(SGPropertyNode::WRITE, false);
 }
 
 void FGGlobals::append_aircraft_paths(const std::string& path)
@@ -597,37 +613,12 @@ FGGlobals::resetPropertyRoot()
     
     // remove /sim/fg-root before writing to prevent hijacking
     SGPropertyNode *n = props->getNode("/sim", true);
-    n->removeChild("fg-root", 0, false);
+    n->removeChild("fg-root", 0);
     n = n->getChild("fg-root", 0, true);
     n->setStringValue(fg_root.c_str());
     n->setAttribute(SGPropertyNode::WRITE, false);
 }
 
-// Save the current state as the initial state.
-void
-FGGlobals::saveInitialState ()
-{
-  initial_state = new SGPropertyNode();
-
-  // copy properties which are READ/WRITEable - but not USERARCHIVEd or PRESERVEd
-  int checked  = SGPropertyNode::READ+SGPropertyNode::WRITE+
-                 SGPropertyNode::USERARCHIVE+SGPropertyNode::PRESERVE;
-  int expected = SGPropertyNode::READ+SGPropertyNode::WRITE;
-  if (!copyProperties(props, initial_state, expected, checked))
-    SG_LOG(SG_GENERAL, SG_ALERT, "Error saving initial state");
-    
-  // delete various properties from the initial state, since we want to
-  // preserve their values even if doing a restore
-  // => Properties should now use the PRESERVE flag to protect their values
-  // on sim-reset. Remove some specific properties for backward compatibility.
-  SGPropertyNode* sim = initial_state->getChild("sim");
-  SGPropertyNode* cameraGroupNode = sim->getNode("rendering/camera-group");
-  if (cameraGroupNode) {
-    cameraGroupNode->removeChild("camera");
-    cameraGroupNode->removeChild("gui");
-  }
-}
-
 static std::string autosaveName()
 {
     std::ostringstream os;
@@ -640,28 +631,6 @@ static std::string autosaveName()
     return os.str();
 }
 
-// Restore the saved initial state, if any
-void
-FGGlobals::restoreInitialState ()
-{
-    if ( initial_state == 0 ) {
-        SG_LOG(SG_GENERAL, SG_ALERT,
-               "No initial state available to restore!!!");
-        return;
-    }
-    // copy properties which are READ/WRITEable - but not USERARCHIVEd or PRESERVEd
-    int checked  = SGPropertyNode::READ+SGPropertyNode::WRITE+
-                   SGPropertyNode::USERARCHIVE+SGPropertyNode::PRESERVE;
-    int expected = SGPropertyNode::READ+SGPropertyNode::WRITE;
-    if ( copyProperties(initial_state, props, expected, checked)) {
-        SG_LOG( SG_GENERAL, SG_INFO, "Initial state restored successfully" );
-    } else {
-        SG_LOG( SG_GENERAL, SG_INFO,
-                "Some errors restoring initial state (read-only props?)" );
-    }
-
-}
-
 // Load user settings from autosave.xml
 void
 FGGlobals::loadUserSettings(const SGPath& dataPath)
@@ -784,4 +753,14 @@ void FGGlobals::cleanupListeners()
     _listeners_to_cleanup.clear();
 }
 
+simgear::pkg::Root* FGGlobals::packageRoot()
+{
+  return _packageRoot.get();
+}
+
+void FGGlobals::setPackageRoot(const SGSharedPtr<simgear::pkg::Root>& p)
+{
+  _packageRoot = p;
+}
+
 // end of globals.cxx
