@@ -67,6 +67,7 @@ extern bool global_crashRptEnabled;
 #include <Viewer/WindowSystemAdapter.hxx>
 #include <Navaids/NavDataCache.hxx>
 #include <Include/version.h>
+#include <Viewer/WindowBuilder.hxx>
 
 #include "fg_commands.hxx"
 #include "fg_io.hxx"
@@ -80,6 +81,10 @@ extern bool global_crashRptEnabled;
 #include "subsystemFactory.hxx"
 #include "options.hxx"
 
+#if defined(HAVE_QT)
+#include <QApplication>
+#include <GUI/QtLauncher.hxx>
+#endif
 
 using namespace flightgear;
 
@@ -394,8 +399,8 @@ static void logToFile()
 }
 
 // Main top level initialization
-int fgMainInit( int argc, char **argv ) {
-
+int fgMainInit( int argc, char **argv )
+{
     // set default log levels
     sglog().setLogLevels( SG_ALL, SG_ALERT );
 
@@ -421,11 +426,6 @@ int fgMainInit( int argc, char **argv ) {
 	SG_LOG( SG_GENERAL, SG_INFO, "Jenkins number/ID " << HUDSON_BUILD_NUMBER << ":"
 			<< HUDSON_BUILD_ID);
 
-    // Allocate global data structures.  This needs to happen before
-    // we parse command line options
-
-    
-    
     // seed the random number generator
     sg_srandom_time();
 
@@ -447,7 +447,32 @@ int fgMainInit( int argc, char **argv ) {
     } else if (configResult == flightgear::FG_OPTIONS_EXIT) {
         return EXIT_SUCCESS;
     }
+
+  // launcher needs to know the aircraft paths in use
+    fgInitAircraftPaths(false);
+
+#if defined(HAVE_QT)
+    bool showLauncher = flightgear::Options::checkForArg(argc, argv, "launcher");
+    // an Info.plist bundle can't define command line arguments, but it can set
+    // environment variables. This avoids needed a wrapper shell-script on OS-X.
+    showLauncher |= (::getenv("FG_LAUNCHER") != 0);
+
+    if (showLauncher) {        
+        QApplication app(argc, argv);
+        app.setOrganizationName("FlightGear");
+        app.setApplicationName("FlightGear");
+        app.setOrganizationDomain("flightgear.org");
     
+        // avoid double Apple menu and other weirdness if both Qt and OSG
+        // try to initialise various Cocoa structures.
+        flightgear::WindowBuilder::setPoseAsStandaloneApp(false);
+
+        if (!QtLauncher::runLauncherDialog()) {
+            return EXIT_SUCCESS;
+        }
+    }
+#endif
+
     configResult = fgInitAircraft(false);
     if (configResult == flightgear::FG_OPTIONS_ERROR) {
         return EXIT_FAILURE;
