@@ -41,6 +41,7 @@
 
 #include <iostream>
 #include <string>
+#include <sstream>
 
 #include <simgear/math/sg_random.h>
 #include <simgear/props/props_io.hxx>
@@ -50,6 +51,7 @@
 #include <simgear/sound/soundmgr_openal.hxx>
 #include <simgear/misc/strutils.hxx>
 #include <Autopilot/route_mgr.hxx>
+#include <Aircraft/replay.hxx>
 
 #include <GUI/gui.h>
 #include <GUI/MessageBox.hxx>
@@ -65,6 +67,7 @@
 #include <Viewer/viewer.hxx>
 #include <Viewer/viewmgr.hxx>
 #include <Environment/presets.hxx>
+#include <Network/http/httpd.hxx>
 #include "AircraftDirVisitorBase.hxx"
 
 #include <osg/Version>
@@ -161,7 +164,6 @@ void fgSetDefaults ()
     // we want mouse-pointer to have an undefined value if nothing is
     // specified so we can do the right thing for voodoo-1/2 cards.
     // fgSetString("/sim/startup/mouse-pointer", "disabled");
-    fgSetString("/sim/control-mode", "joystick");
     fgSetBool("/controls/flight/auto-coordination", false);
     fgSetString("/sim/logging/priority", "alert");
 
@@ -185,7 +187,6 @@ void fgSetDefaults ()
     fgSetBool("/environment/clouds/status", true);
     fgSetBool("/sim/startup/fullscreen", false);
     fgSetBool("/sim/rendering/shading", true);
-    fgSetBool("/sim/rendering/textures", true);
     fgTie( "/sim/rendering/filtering", SGGetTextureFilter, SGSetTextureFilter, false);
     fgSetInt("/sim/rendering/filtering", 1);
     fgSetBool("/sim/rendering/wireframe", false);
@@ -950,6 +951,27 @@ fgOptStartDateGmt( const char *arg )
     return FG_OPTIONS_OK;
 }
 
+static int
+fgOptJpgHttpd( const char * arg )
+{
+  SG_LOG(SG_ALL,SG_ALERT,
+   "the option --jpg-httpd is no longer supported! Please use --httpd instead."
+   " URL for the screenshot within the new httpd is http://YourFgServer:xxxx/screenshot");
+  return FG_OPTIONS_EXIT;
+}
+
+static int
+fgOptHttpd( const char * arg )
+{
+    // port may be any valid address:port notation
+    // like 127.0.0.1:8080
+    // or just the port 8080
+    string port = simgear::strutils::strip(string(arg));
+    if( port.empty() ) return FG_OPTIONS_ERROR;
+    fgSetString( string(flightgear::http::PROPERTY_ROOT).append("/options/listening-port").c_str(), port );
+    return FG_OPTIONS_OK;
+}
+
 static int
 fgSetupProxy( const char *arg )
 {
@@ -1381,6 +1403,43 @@ fgOptSetProperty(const char* raw)
   return ret ? FG_OPTIONS_OK : FG_OPTIONS_ERROR;
 }
 
+static int
+fgOptLoadTape(const char* arg)
+{
+  // load a flight recorder tape but wait until the fdm is initialized
+  class DelayedTapeLoader : SGPropertyChangeListener {
+  public:
+    DelayedTapeLoader( const char * tape ) :
+      _tape(tape)
+    {
+      SGPropertyNode_ptr n = fgGetNode("/sim/signals/fdm-initialized", true);
+      n->addChangeListener( this );
+    }
+
+    virtual ~ DelayedTapeLoader() {}
+
+    virtual void valueChanged(SGPropertyNode * node) 
+    {
+      node->removeChangeListener( this );
+
+      // tell the replay subsystem to load the tape
+      FGReplay* replay = (FGReplay*) globals->get_subsystem("replay");
+      SGPropertyNode_ptr arg = new SGPropertyNode();
+      arg->setStringValue("tape", _tape );
+      arg->setBoolValue( "same-aircraft", 0 );
+      replay->loadTape(arg);
+
+      delete this; // commence suicide
+    }
+  private:
+    std::string _tape;
+
+  };
+
+  new DelayedTapeLoader(arg);
+  return FG_OPTIONS_OK;
+}
+
 
 
 /*
@@ -1425,6 +1484,7 @@ struct OptionDesc {
 
     {"language",                     true,  OPTION_IGNORE, "", false, "", 0 },
 	{"console",                      false, OPTION_IGNORE,   "", false, "", 0 },
+    {"launcher",                     false, OPTION_IGNORE,   "", false, "", 0 },
     {"disable-rembrandt",            false, OPTION_BOOL,   "/sim/rendering/rembrandt/enabled", false, "", 0 },
     {"enable-rembrandt",             false, OPTION_BOOL,   "/sim/rendering/rembrandt/enabled", true, "", 0 },
     {"renderer",                     true,  OPTION_STRING, "/sim/rendering/rembrandt/renderer", false, "", 0 },
@@ -1455,7 +1515,6 @@ struct OptionDesc {
     {"enable-hud-3d",                false, OPTION_BOOL,   "/sim/hud/enable3d[1]", true, "", 0 },
     {"disable-anti-alias-hud",       false, OPTION_BOOL,   "/sim/hud/color/antialiased", false, "", 0 },
     {"enable-anti-alias-hud",        false, OPTION_BOOL,   "/sim/hud/color/antialiased", true, "", 0 },
-    {"control",                      true,  OPTION_STRING, "/sim/control-mode", false, "", 0 },
     {"disable-auto-coordination",    false, OPTION_BOOL,   "/controls/flight/auto-coordination", false, "", 0 },
     {"enable-auto-coordination",     false, OPTION_BOOL,   "/controls/flight/auto-coordination", true, "", 0 },
     {"browser-app",                  true,  OPTION_STRING, "/sim/startup/browser-app", false, "", 0 },
@@ -1532,8 +1591,6 @@ struct OptionDesc {
     {"restore-defaults",             false, OPTION_BOOL,   "/sim/startup/restore-defaults", true, "", 0 },
     {"shading-flat",                 false, OPTION_BOOL,   "/sim/rendering/shading", false, "", 0 },
     {"shading-smooth",               false, OPTION_BOOL,   "/sim/rendering/shading", true, "", 0 },
-    {"disable-textures",             false, OPTION_BOOL,   "/sim/rendering/textures", false, "", 0 },
-    {"enable-textures",              false, OPTION_BOOL,   "/sim/rendering/textures", true, "", 0 },
     {"texture-filtering",            false, OPTION_INT,    "/sim/rendering/filtering", 1, "", 0 },
     {"disable-wireframe",            false, OPTION_BOOL,   "/sim/rendering/wireframe", false, "", 0 },
     {"enable-wireframe",             false, OPTION_BOOL,   "/sim/rendering/wireframe", true, "", 0 },
@@ -1557,10 +1614,8 @@ struct OptionDesc {
     {"hud-culled",                   false, OPTION_STRING, "/sim/hud/frame-stat-type", false, "culled", 0 },
     {"atcsim",                       true,  OPTION_CHANNEL, "", false, "dummy", 0 },
     {"atlas",                        true,  OPTION_CHANNEL | OPTION_MULTI, "", false, "", 0 },
-    {"httpd",                        true,  OPTION_CHANNEL, "", false, "", 0 },
-#ifdef FG_JPEG_SERVER
-    {"jpg-httpd",                    true,  OPTION_CHANNEL, "", false, "", 0 },
-#endif
+    {"httpd",                        true,  OPTION_FUNC   , "", false, "", fgOptHttpd },
+    {"jpg-httpd",                    true,  OPTION_FUNC,    "", false, "", fgOptJpgHttpd },
     {"native",                       true,  OPTION_CHANNEL | OPTION_MULTI, "", false, "", 0 },
     {"native-ctrls",                 true,  OPTION_CHANNEL | OPTION_MULTI, "", false, "", 0 },
     {"native-fdm",                   true,  OPTION_CHANNEL | OPTION_MULTI, "", false, "", 0 },
@@ -1626,6 +1681,7 @@ struct OptionDesc {
     {"fgviewer",                     false, OPTION_IGNORE,   "", false, "", 0},
     {"no-default-config",            false, OPTION_IGNORE, "", false, "", 0},
     {"prop",                         true,  OPTION_FUNC | OPTION_MULTI,   "", false, "", fgOptSetProperty},
+    {"load-tape",                    true,  OPTION_FUNC,   "", false, "", fgOptLoadTape },
     {0}
 };
 
@@ -1836,10 +1892,9 @@ void Options::init(int argc, char **argv, const SGPath& appDataPath)
       SGPath f(argv[i]);
       if (!f.exists()) {
         SG_LOG(SG_GENERAL, SG_ALERT, "config file not found:" << f.str());
-        return;
+      } else {
+        p->propertyFiles.push_back(f);
       }
-      
-      p->propertyFiles.push_back(f);
     }
   } // of arguments iteration
   p->insertGroupMarker(); // command line is one group
@@ -1899,18 +1954,22 @@ void Options::init(int argc, char **argv, const SGPath& appDataPath)
   config.append( "system.fgfsrc" );
   readConfig(config);
 }
-  
+
+void Options::initPaths()
+{
+    BOOST_FOREACH(const string& paths, valuesForOption("fg-aircraft")) {
+        globals->append_aircraft_paths(paths);
+    }
+
+    const char* envp = ::getenv("FG_AIRCRAFT");
+    if (envp) {
+        globals->append_aircraft_paths(envp);
+    }
+
+}
+
 void Options::initAircraft()
 {
-  BOOST_FOREACH(const string& paths, valuesForOption("fg-aircraft")) {
-    globals->append_aircraft_paths(paths);
-  }
-  
-  const char* envp = ::getenv("FG_AIRCRAFT");
-  if (envp) {
-    globals->append_aircraft_paths(envp);
-  }
-
   string aircraft;
   if (isOptionSet("aircraft")) {
     aircraft = valueForOption("aircraft");
@@ -1924,10 +1983,6 @@ void Options::initAircraft()
   } else {
     SG_LOG(SG_INPUT, SG_INFO, "No user specified aircraft, using default" );
   }
-  
-// persist across reset
-  SGPropertyNode* aircraftProp = fgGetNode("/sim/aircraft", true);
-  aircraftProp->setAttribute(SGPropertyNode::PRESERVE, true);
     
   if (p->showAircraft) {
     fgOptLogLevel( "alert" );
@@ -2164,11 +2219,6 @@ OptionResult Options::processOptions()
   }
 
   BOOST_FOREACH(const SGPath& file, p->propertyFiles) {
-    if (!file.exists()) {
-      SG_LOG(SG_GENERAL, SG_ALERT, "config file not found:" << file.str());
-      continue;
-    }
-    
     SG_LOG(SG_GENERAL, SG_INFO,
            "Reading command-line property file " << file.str());
 	  readProperties(file.str(), globals->get_props());
@@ -2181,7 +2231,7 @@ OptionResult Options::processOptions()
   }
     
 // terrasync directory fixup
-  string terrasyncDir = fgGetString("/sim/terrasync/scenery-dir");
+    string terrasyncDir = simgear::strutils::strip(fgGetString("/sim/terrasync/scenery-dir"));
   if (terrasyncDir.empty()) {
 	  terrasyncDir = defaultTerrasyncDir();
 	  // auto-save it for next time
@@ -2205,6 +2255,17 @@ OptionResult Options::processOptions()
   if (!objectsDir.exists()) {
       objectsDir.create(0755);
   }
+
+    // check the above actuall worked
+    if (!objectsDir.exists() || !terrainDir.exists()) {
+        std::stringstream ss;
+        ss << "Scenery download will be disabled. The configured location is '" << terrasyncDir << "'.";
+        flightgear::modalMessageBox("Invalid scenery download location",
+                                    "Automatic scenery download is configured to use a location (path) which invalid.",
+                                    ss.str());
+        fgSetBool("/sim/terrasync/enabled", false);
+    }
+
   if (fgGetBool("/sim/terrasync/enabled")) {
     const string_list& scenery_paths(globals->get_fg_scenery());
     if (std::find(scenery_paths.begin(), scenery_paths.end(), terrasyncDir) == scenery_paths.end()) {
@@ -2364,9 +2425,7 @@ string Options::platformDefaultRoot() const
 #elif defined(SG_WINDOWS)
 string Options::platformDefaultRoot() const
 {
-	// for 3.0 release, adjusting this to allow for the
-	// bin\Win32 and bin\Win64 structure we install
-	return "..\\..\\data";
+  return "..\\data";
 }
 #elif defined(SG_MAC)
 // platformDefaultRoot defined in CocoaHelpers.mm
@@ -2423,6 +2482,22 @@ bool Options::shouldLoadDefaultConfig() const
 {
   return p->shouldLoadDefaultConfig;
 }
-  
+
+bool Options::checkForArg(int argc, char* argv[], const char* checkArg)
+{
+    for (int i = 0; i < argc; ++i) {
+        char* arg = argv[i];
+        if (!strncmp("--", arg, 2) && !strcmp(arg + 2, checkArg)) {
+            return true;
+        }
+        
+        if ((arg[0] == '-') && !strcmp(arg + 1, checkArg)) {
+            return true;
+        }
+    }
+    
+    return false;
+}
+    
 } // of namespace flightgear
 
