@@ -49,6 +49,7 @@
 #include "Main/fg_props.hxx"
 #include <Navaids/procedure.hxx>
 #include <Navaids/waypoint.hxx>
+#include <Navaids/routePath.hxx>
 
 using std::string;
 using std::vector;
@@ -63,6 +64,8 @@ static FPDelegateFactoryVec static_delegateFactories;
 FlightPlan::FlightPlan() :
   _delegateLock(0),
   _currentIndex(-1),
+    _followLegTrackToFix(true),
+    _aircraftCategory(ICAO_AIRCRAFT_CATEGORY_C),
   _departureRunway(NULL),
   _destinationRunway(NULL),
   _sid(NULL),
@@ -358,6 +361,17 @@ int FlightPlan::findWayptIndex(const SGGeod& aPos) const
   
   return -1;
 }
+  
+int FlightPlan::findWayptIndex(const FGPositionedRef aPos) const
+{
+  for (int i=0; i<numLegs(); ++i) {
+    if (_legs[i]->waypoint()->source() == aPos) {
+      return i;
+    }
+  }
+  
+  return -1;
+}
 
 FlightPlan::Leg* FlightPlan::currentLeg() const
 {
@@ -828,12 +842,14 @@ void FlightPlan::loadVersion2XMLRoute(SGPropertyNode_ptr routeData)
   
   // route nodes
   _legs.clear();
-  SGPropertyNode_ptr routeNode = routeData->getChild("route", 0);    
-  for (int i=0; i<routeNode->nChildren(); ++i) {
-    SGPropertyNode_ptr wpNode = routeNode->getChild("wp", i);
-    Leg* l = new Leg(this, Waypt::createFromProperties(NULL, wpNode));
-    _legs.push_back(l);
-  } // of route iteration
+  SGPropertyNode_ptr routeNode = routeData->getChild("route", 0);
+  if (routeNode.valid()) {
+    for (int i=0; i<routeNode->nChildren(); ++i) {
+      SGPropertyNode_ptr wpNode = routeNode->getChild("wp", i);
+      Leg* l = new Leg(this, Waypt::createFromProperties(NULL, wpNode));
+      _legs.push_back(l);
+    } // of route iteration
+  }
   _waypointsChanged = true;
 }
 
@@ -1173,60 +1189,29 @@ double FlightPlan::Leg::distanceAlongRoute() const
 void FlightPlan::rebuildLegData()
 {
   _totalDistance = 0.0;
-  int lastLeg = static_cast<int>(_legs.size()) - 1;
-  for (int l=0; l<lastLeg; ++l) {
-    Leg* cur = _legs[l];
-    Leg* next = _legs[l + 1];
+  double totalDistanceIncludingMissed = 0.0;
+  RoutePath path(this);
+  
+  for (unsigned int l=0; l<_legs.size(); ++l) {
+    _legs[l]->_courseDeg = path.trackForIndex(l);
+    _legs[l]->_pathDistance = path.distanceForIndex(l) * SG_METER_TO_NM;
+
+    totalDistanceIncludingMissed += _legs[l]->_pathDistance;
+    // distance along path includes our own leg distance
+    _legs[l]->_distanceAlongPath = totalDistanceIncludingMissed;
     
-    std::pair<double, double> crsDist =
-      next->waypoint()->courseAndDistanceFrom(cur->waypoint()->position());
-    _legs[l]->_courseDeg = crsDist.first;
-    _legs[l]->_pathDistance = crsDist.second * SG_METER_TO_NM;
-    _legs[l]->_distanceAlongPath = _totalDistance;
-    _totalDistance += crsDist.second * SG_METER_TO_NM;
-  } // of legs iteration
+    // omit missed-approach waypoints from total distance calculation
+    if (!_legs[l]->waypoint()->flag(WPT_MISS)) {
+      _totalDistance += _legs[l]->_pathDistance;
+    }
+} // of legs iteration
   
-// set some data on the final leg
-  if (lastLeg > 0) {
-    // keep the same course as the final leg, when passing the final
-    // waypoint
-    _legs[lastLeg]->_courseDeg = _legs[lastLeg - 1]->_courseDeg;
-    _legs[lastLeg]->_pathDistance = 0.0;
-    _legs[lastLeg]->_distanceAlongPath = _totalDistance;
-  }
 }
   
 SGGeod FlightPlan::pointAlongRoute(int aIndex, double aOffsetNm) const
 {
-  if (aIndex >= (int) _legs.size()) {
-    throw sg_range_exception();
-  }
-  
-  const int lastLeg = static_cast<int>(_legs.size()) - 1;
-// convert the relative offset and leg index into an absolute, positive
-// distance in nm from the route origin. This means we can simply walk
-// forwards to find the actual leg.
-  Leg* leg = _legs[(aIndex >= 0) ? aIndex : lastLeg];
-  double absolutePathDistance = leg->_distanceAlongPath + aOffsetNm;
-  if (absolutePathDistance < 0.0) {
-    return _legs[0]->waypoint()->position(); // begining of route
-  }
-  
-  if (absolutePathDistance > _totalDistance) {
-    return _legs[lastLeg]->waypoint()->position(); // end of route
-  }
-  
-// find the leg containing the absolute distance
-  for (int l=0; l<lastLeg; ++l) {
-    leg = _legs[l];
-    if (absolutePathDistance < leg->_pathDistance) {
-      break; // found our matching leg
-    }
-    absolutePathDistance -= leg->_pathDistance;
-  } // of forwards walk along route to find leg
-  
-  return SGGeodesy::direct(leg->waypoint()->position(),
-                               leg->_courseDeg, absolutePathDistance * SG_NM_TO_METER);
+    RoutePath rp(this);
+    return rp.positionForDistanceFrom(aIndex, aOffsetNm * SG_NM_TO_METER);
 }
     
 void FlightPlan::lockDelegate()
@@ -1376,5 +1361,36 @@ void FlightPlan::Delegate::runFinished()
     if (_inner) _inner->runFinished();
     endOfFlightPlan();
 }
+
+void FlightPlan::setFollowLegTrackToFixes(bool tf)
+{
+    _followLegTrackToFix = tf;
+}
+
+bool FlightPlan::followLegTrackToFixes() const
+{
+    return _followLegTrackToFix;
+}
+
+std::string FlightPlan::icaoAircraftCategory() const
+{
+    std::string r;
+    r.push_back(_aircraftCategory);
+    return r;
+}
+
+void FlightPlan::setIcaoAircraftCategory(const std::string& cat)
+{
+    if (cat.empty()) {
+        throw sg_range_exception("Invalid ICAO aircraft category:", cat);
+    }
+
+    if ((cat[0] < ICAO_AIRCRAFT_CATEGORY_A) || (cat[0] > ICAO_AIRCRAFT_CATEGORY_E)) {
+        throw sg_range_exception("Invalid ICAO aircraft category:", cat);
+    }
+
+    _aircraftCategory = cat[0];
+}
+
     
 } // of namespace flightgear
