@@ -53,26 +53,81 @@
 
 using flightgear::SceneryPager;
 
+class FGTileMgr::TileManagerListener : public SGPropertyChangeListener
+{
+public:
+    TileManagerListener(FGTileMgr* manager) :
+        _manager(manager),
+        _useVBOsProp(fgGetNode("/sim/rendering/use-vbos", true)),
+        _enableCacheProp(fgGetNode("/sim/tile-cache/enable", true)),
+        _pagedLODMaximumProp(fgGetNode("/sim/rendering/max-paged-lod", true))
+    {
+        _useVBOsProp->addChangeListener(this, true);
+      
+        _enableCacheProp->addChangeListener(this, true);
+        if (_enableCacheProp->getType() == simgear::props::NONE) {
+            _enableCacheProp->setBoolValue(true);
+        }
+      
+        if (_pagedLODMaximumProp->getType() == simgear::props::NONE) {
+            // not set, use OSG default / environment value variable
+            osg::ref_ptr<osgViewer::Viewer> viewer(globals->get_renderer()->getViewer());
+            int current = viewer->getDatabasePager()->getTargetMaximumNumberOfPageLOD();
+            _pagedLODMaximumProp->setIntValue(current);
+        }
+        _pagedLODMaximumProp->addChangeListener(this, true);
+    }
+    
+    ~TileManagerListener()
+    {
+        _useVBOsProp->removeChangeListener(this);
+        _enableCacheProp->removeChangeListener(this);
+        _pagedLODMaximumProp->removeChangeListener(this);
+    }
+    
+    virtual void valueChanged(SGPropertyNode* prop)
+    {
+        if (prop == _useVBOsProp) {
+            bool useVBOs = prop->getBoolValue();
+            _manager->_options->setPluginStringData("SimGear::USE_VBOS",
+                                                useVBOs ? "ON" : "OFF");
+        } else if (prop == _enableCacheProp) {
+            _manager->_enableCache = prop->getBoolValue();
+        } else if (prop == _pagedLODMaximumProp) {
+          int v = prop->getIntValue();
+          osg::ref_ptr<osgViewer::Viewer> viewer(globals->get_renderer()->getViewer());
+          viewer->getDatabasePager()->setTargetMaximumNumberOfPageLOD(v);
+        }
+    }
+    
+private:
+    FGTileMgr* _manager;
+    SGPropertyNode_ptr _useVBOsProp,
+      _enableCacheProp,
+      _pagedLODMaximumProp;
+};
 
 FGTileMgr::FGTileMgr():
     state( Start ),
     last_state( Running ),
-    longitude(-1000.0),
-    latitude(-1000.0),
     scheduled_visibility(100.0),
     _terra_sync(NULL),
+    _listener(NULL),
     _visibilityMeters(fgGetNode("/environment/visibility-m", true)),
     _maxTileRangeM(fgGetNode("/sim/rendering/static-lod/bare", true)),
     _disableNasalHooks(fgGetNode("/sim/temp/disable-scenery-nasal", true)),
     _scenery_loaded(fgGetNode("/sim/sceneryloaded", true)),
     _scenery_override(fgGetNode("/sim/sceneryloaded-override", true)),
-    _pager(FGScenery::getPagerSingleton())
+    _pager(FGScenery::getPagerSingleton()),
+    _enableCache(true)
 {
 }
 
 
 FGTileMgr::~FGTileMgr()
 {
+    delete _listener;
+    
     // remove all nodes we might have left behind
     osg::Group* group = globals->get_scenery()->get_terrain_branch();
     group->removeChildren(0, group->getNumChildren());
@@ -82,39 +137,48 @@ FGTileMgr::~FGTileMgr()
 
 
 // Initialize the Tile Manager subsystem
-void FGTileMgr::init() {
-    SG_LOG( SG_TERRAIN, SG_INFO, "Initializing Tile Manager subsystem." );
+void FGTileMgr::init()
+{
+    reinit();
+}
 
+void FGTileMgr::reinit()
+{
+    SG_LOG( SG_TERRAIN, SG_INFO, "Initializing Tile Manager subsystem." );
+    _terra_sync = static_cast<simgear::SGTerraSync*> (globals->get_subsystem("terrasync"));
+
+  // drops the previous options reference
     _options = new simgear::SGReaderWriterOptions;
+    _listener = new TileManagerListener(this);
     
     materialLibChanged();
     _options->setPropertyNode(globals->get_props());
-
+    
     osgDB::FilePathList &fp = _options->getDatabasePathList();
     const string_list &sc = globals->get_fg_scenery();
     fp.clear();
     std::copy(sc.begin(), sc.end(), back_inserter(fp));
     _options->setPluginStringData("SimGear::FG_ROOT", globals->get_fg_root());
     
-    if (globals->get_subsystem("terrasync")) {
-        _options->setPluginStringData("SimGear::TERRASYNC_ROOT", fgGetString("/sim/terrasync/scenery-dir"));
+    if (_terra_sync) {
+      _options->setPluginStringData("SimGear::TERRASYNC_ROOT", fgGetString("/sim/terrasync/scenery-dir"));
     }
     
     if (!_disableNasalHooks->getBoolValue())
-        _options->setModelData(new FGNasalModelDataProxy);
-
-    reinit();
-}
-
-void FGTileMgr::reinit()
-{
-    _terra_sync = static_cast<simgear::SGTerraSync*> (globals->get_subsystem("terrasync"));
-    
-    // protect against multiple scenery reloads and properly reset flags,
-    // otherwise aircraft fall through the ground while reloading scenery
-    if (!fgGetBool("/sim/sceneryloaded",true))
+      _options->setModelData(new FGNasalModelDataProxy);
+  
+  
+    if (state != Start)
+    {
+      // protect against multiple scenery reloads and properly reset flags,
+      // otherwise aircraft fall through the ground while reloading scenery
+      if (_scenery_loaded->getBoolValue() == false) {
+        SG_LOG( SG_TERRAIN, SG_INFO, "/sim/sceneryloaded already false, avoiding duplicate re-init of tile manager" );
         return;
-    fgSetBool("/sim/sceneryloaded",false);
+      }
+    }
+  
+    _scenery_loaded->setBoolValue(false);
     fgSetDouble("/sim/startup/splash-alpha", 1.0);
     
     materialLibChanged();
@@ -134,7 +198,6 @@ void FGTileMgr::reinit()
     
     previous_bucket.make_bad();
     current_bucket.make_bad();
-    longitude = latitude = -1000.0;
     scheduled_visibility = 100.0;
 
     // force an update now
@@ -144,7 +207,6 @@ void FGTileMgr::reinit()
 void FGTileMgr::materialLibChanged()
 {
     _options->setMaterialLib(globals->get_matlib());
-    _options->getMaterialLib()->refreshActiveMaterials();
 }
 
 /* schedule a tile for loading, keep request for given amount of time.
@@ -185,21 +247,20 @@ bool FGTileMgr::sched_tile( const SGBucket& b, double priority, bool current_vie
 void FGTileMgr::schedule_needed(const SGBucket& curr_bucket, double vis)
 {
     // sanity check (unfortunately needed!)
-    if ( longitude < -180.0 || longitude > 180.0 
-         || latitude < -90.0 || latitude > 90.0 )
+    if (!curr_bucket.isValid() )
     {
         SG_LOG( SG_TERRAIN, SG_ALERT,
-                "Attempting to schedule tiles for bogus lon and lat  = ("
-                << longitude << "," << latitude << ")" );
+                "Attempting to schedule tiles for invalid bucket" );
         return;
     }
 
-    SG_LOG( SG_TERRAIN, SG_INFO,
-            "scheduling needed tiles for " << longitude << " " << latitude << ", curr_bucket:"
-           <<  curr_bucket.gen_base_path() << "/" << curr_bucket.gen_index_str());
-
     double tile_width = curr_bucket.get_width_m();
     double tile_height = curr_bucket.get_height_m();
+    SG_LOG( SG_TERRAIN, SG_INFO,
+            "scheduling needed tiles for " << curr_bucket
+           << ", tile-width-m:" << tile_width << ", tile-height-m:" << tile_height);
+
+    
     // cout << "tile width = " << tile_width << "  tile_height = "
     //      << tile_height << endl;
 
@@ -234,7 +295,11 @@ void FGTileMgr::schedule_needed(const SGBucket& curr_bucket, double vis)
     {
         for ( y = -yrange; y <= yrange; ++y )
         {
-            SGBucket b = sgBucketOffset( longitude, latitude, x, y );
+            SGBucket b = curr_bucket.sibling(x, y);
+            if (!b.isValid()) {
+                continue;
+            }
+            
             float priority = (-1.0) * (x*x+y*y);
             sched_tile( b, priority, true, 0.0 );
             
@@ -246,7 +311,7 @@ void FGTileMgr::schedule_needed(const SGBucket& curr_bucket, double vis)
 }
 
 /**
- * Update the various queues maintained by the tilemagr (private
+ * Update the various queues maintained by the tilemgr (private
  * internal function, do not call directly.)
  */
 void FGTileMgr::update_queues(bool& isDownloadingScenery)
@@ -258,7 +323,6 @@ void FGTileMgr::update_queues(bool& isDownloadingScenery)
     TileEntry *e;
     int loading=0;
     int sz=0;
-    bool didRefreshMaterialCache = false;
     
     tile_cache.set_current_time( current_time );
     tile_cache.reset_traversal();
@@ -274,11 +338,6 @@ void FGTileMgr::update_queues(bool& isDownloadingScenery)
             e->prep_ssg_node(vis);
             
             if (!e->is_loaded()) {
-                if (!didRefreshMaterialCache) {
-                    didRefreshMaterialCache = true;
-                    globals->get_matlib()->refreshActiveMaterials();
-                }
-                
                 bool nonExpiredOrCurrent = !e->is_expired(current_time) || e->is_current_view();
                 bool downloading = isTileDirSyncing(e->tileFileName);
                 isDownloadingScenery |= downloading;
@@ -301,14 +360,24 @@ void FGTileMgr::update_queues(bool& isDownloadingScenery)
     }
 
     int drop_count = sz - tile_cache.get_max_cache_size();
-    if (( drop_count > 0 )&&
-         ((loading==0)||(drop_count > 10)))
+    bool dropTiles = false;
+    if (_enableCache) {
+      dropTiles = ( drop_count > 0 ) && ((loading==0)||(drop_count > 10));
+    } else {
+      dropTiles = true;
+      drop_count = sz; // no limit on tiles to drop
+    }
+  
+    if (dropTiles)
     {
-        long drop_index = tile_cache.get_drop_tile();
+        long drop_index = _enableCache ? tile_cache.get_drop_tile() :
+                                         tile_cache.get_first_expired_tile();
         while ( drop_index > -1 )
         {
             // schedule tile for deletion with osg pager
             TileEntry* old = tile_cache.get_tile(drop_index);
+            SG_LOG(SG_TERRAIN, SG_DEBUG, "Dropping:" << old->get_tile_bucket());
+
             tile_cache.clear_entry(drop_index);
             
             osg::ref_ptr<osg::Object> subgraph = old->getNode();
@@ -317,13 +386,16 @@ void FGTileMgr::update_queues(bool& isDownloadingScenery)
             // zeros out subgraph ref_ptr, so subgraph is owned by
             // the pager and will be deleted in the pager thread.
             _pager->queueDeleteRequest(subgraph);
-            
-            if (--drop_count > 0)
+          
+            if (!_enableCache)
+                drop_index = tile_cache.get_first_expired_tile();
+            // limit tiles dropped to drop_count
+            else if (--drop_count > 0)
                 drop_index = tile_cache.get_drop_tile();
             else
-                drop_index = -1;
+               drop_index = -1;
         }
-    }
+    } // of dropping tiles loop
 }
 
 // given the current lon/lat (in degrees), fill in the array of local
@@ -372,13 +444,10 @@ void FGTileMgr::update(double)
 // (FDM/AI/groundcache/... should use "schedule_scenery" instead)
 void FGTileMgr::schedule_tiles_at(const SGGeod& location, double range_m)
 {
-    longitude = location.getLongitudeDeg();
-    latitude = location.getLatitudeDeg();
-
     // SG_LOG( SG_TERRAIN, SG_DEBUG, "FGTileMgr::update() for "
     //         << longitude << " " << latitude );
 
-    current_bucket.set_bucket( location );
+    current_bucket = SGBucket( location );
 
     // schedule more tiles when visibility increased considerably
     // TODO Calculate tile size - instead of using fixed value (5000m)
@@ -399,7 +468,8 @@ void FGTileMgr::schedule_tiles_at(const SGGeod& location, double range_m)
         if (current_bucket != previous_bucket) {
             // We've moved to a new bucket, we need to schedule any
             // needed tiles for loading.
-            SG_LOG( SG_TERRAIN, SG_DEBUG, "FGTileMgr::update()" );
+            SG_LOG( SG_TERRAIN, SG_INFO, "FGTileMgr: at " << location << ", scheduling needed for:" << current_bucket
+                   << ", visbility=" << range_m);
             scheduled_visibility = range_m;
             schedule_needed(current_bucket, range_m);
         }
@@ -422,21 +492,19 @@ void FGTileMgr::schedule_tiles_at(const SGGeod& location, double range_m)
  */
 bool FGTileMgr::schedule_scenery(const SGGeod& position, double range_m, double duration)
 {
-    const float priority = 0.0;
-    double current_longitude = position.getLongitudeDeg();
-    double current_latitude = position.getLatitudeDeg();
-    bool available = true;
-    
     // sanity check (unfortunately needed!)
-    if (current_longitude < -180 || current_longitude > 180 ||
-        current_latitude < -90 || current_latitude > 90)
+    if (!position.isValid())
         return false;
-  
+    const float priority = 0.0;
+    bool available = true;
+
     SGBucket bucket(position);
     available = sched_tile( bucket, priority, false, duration );
   
-    if ((!available)&&(duration==0.0))
+    if ((!available)&&(duration==0.0)) {
+        SG_LOG( SG_TERRAIN, SG_DEBUG, "schedule_scenery: Scheduling tile at bucket:" << bucket << " return false" );
         return false;
+    }
 
     SGVec3d cartPos = SGVec3d::fromGeod(position);
 
@@ -457,8 +525,11 @@ bool FGTileMgr::schedule_scenery(const SGGeod& position, double range_m, double
             // We have already checked for the center tile.
             if ( x != 0 || y != 0 )
             {
-                SGBucket b = sgBucketOffset( current_longitude,
-                                             current_latitude, x, y );
+                SGBucket b = bucket.sibling(x, y );
+                if (!b.isValid()) {
+                    continue;
+                }
+                
                 double distance2 = distSqr(cartPos, SGVec3d::fromGeod(b.get_center()));
                 // Do not ask if it is just the next tile but way out of range.
                 if (distance2 <= max_dist2)
@@ -481,7 +552,7 @@ bool FGTileMgr::isSceneryLoaded()
     if (scheduled_visibility < range_m)
         range_m = scheduled_visibility;
 
-    return schedule_scenery(SGGeod::fromDeg(longitude, latitude), range_m, 0.0);
+    return schedule_scenery(globals->get_view_position(), range_m, 0.0);
 }
 
 bool FGTileMgr::isTileDirSyncing(const std::string& tileFileName) const
