@@ -443,6 +443,8 @@ static const char* waypointCommonGetMember(naContext c, Waypt* wpt, const char*
     } else {
       *out = stringToNasal(c, wpt->flag(WPT_OVERFLIGHT) ? "flyOver" : "flyBy");
     }
+  } else if (!strcmp(fieldName, "heading_course")) {
+      *out = naNum(wpt->headingRadialDeg());
   } else {
     return NULL; // member not found
   }
@@ -461,6 +463,10 @@ static void waypointCommonSetMember(naContext c, Waypt* wpt, const char* fieldNa
     }
     
     wpt->setFlag(f, true);
+  } else if (!strcmp(fieldName, "fly_type")) {
+      if (!naIsString(value)) naRuntimeError(c, "fly_type must be a string");
+      bool flyOver = (strcmp(naStr_data(value), "flyOver") == 0);
+      wpt->setFlag(WPT_OVERFLIGHT, flyOver);
   }
 }
 
@@ -567,6 +573,8 @@ static const char* flightplanGhostGetMember(naContext c, void* g, naRef field, n
   else if (!strcmp(fieldName, "star_trans")) *out = ghostForProcedure(c, fp->starTransition());
   else if (!strcmp(fieldName, "approach")) *out = ghostForProcedure(c, fp->approach());
   else if (!strcmp(fieldName, "current")) *out = naNum(fp->currentIndex());
+    else if (!strcmp(fieldName, "aircraftCategory")) *out = stringToNasal(c, fp->icaoAircraftCategory());
+    else if (!strcmp(fieldName, "followLegTrackToFix")) *out = naNum(fp->followLegTrackToFixes());
   else {
     return 0;
   }
@@ -689,6 +697,12 @@ static void flightplanGhostSetMember(naContext c, void* g, naRef field, naRef va
     }
     
     naRuntimeError(c, "bad argument type setting approach");
+  } else if (!strcmp(fieldName, "aircraftCategory")) {
+      if (!naIsString(value)) naRuntimeError(c, "aircraftCategory must be a string");
+      fp->setIcaoAircraftCategory(naStr_data(value));
+  } else if (!strcmp(fieldName, "followLegTrackToFix")) {
+      int b = (int) value.num;
+      fp->setFollowLegTrackToFixes(b);
   }
 }
 
@@ -2213,6 +2227,27 @@ static naRef f_flightplan_finish(naContext c, naRef me, int argc, naRef* args)
     return naNil();
 }
 
+static naRef f_flightplan_indexOfWp(naContext c, naRef me, int argc, naRef* args)
+{
+  FlightPlan* fp = flightplanGhost(me);
+  if (!fp) {
+    naRuntimeError(c, "flightplan.indexOfWP called on non-flightplan object");
+  }
+  
+  FGPositioned* positioned = positionedGhost(args[0]);
+  if (positioned) {
+    return naNum(fp->findWayptIndex(positioned));
+  }
+  
+  SGGeod pos;
+  int argOffset = geodFromArgs(args, 0, argc, pos);
+  if (argOffset > 0) {
+    return naNum(fp->findWayptIndex(pos));
+  }
+
+  return naNum(-1);
+}
+
 static naRef f_leg_setSpeed(naContext c, naRef me, int argc, naRef* args)
 {
   FlightPlan::Leg* leg = fpLegGhost(me);
@@ -2278,11 +2313,12 @@ static naRef f_leg_courseAndDistanceFrom(naContext c, naRef me, int argc, naRef*
     
     SGGeod pos;
     geodFromArgs(args, 0, argc, pos);
-    
-    double courseDeg;
-    double distanceM;
-    boost::tie(courseDeg, distanceM) = leg->waypoint()->courseAndDistanceFrom(pos);
-    
+  
+    RoutePath path(leg->owner());
+    SGGeod wpPos = path.positionForIndex(leg->index());
+    double courseDeg, az2, distanceM;
+    SGGeodesy::inverse(pos, wpPos, courseDeg, az2, distanceM);
+  
     naRef result = naNewVector(c);
     naVec_append(result, naNum(courseDeg));
     naVec_append(result, naNum(distanceM * SG_METER_TO_NM));
@@ -2384,7 +2420,6 @@ static naRef f_procedure_route(naContext c, naRef me, int argc, naRef* args)
     WayptVec r;
     Approach* app = (Approach*) proc;
     if (!app->route(iaf, r)) {
-      SG_LOG(SG_NASAL, SG_WARN, "procedure.route failed for Approach somehow");
       return naNil();
     }
     
@@ -2479,6 +2514,7 @@ naRef initNasalPositioned(naRef globals, naContext c)
     hashset(c, flightplanPrototype, "clone", naNewFunc(c, naNewCCode(c, f_flightplan_clone))); 
     hashset(c, flightplanPrototype, "pathGeod", naNewFunc(c, naNewCCode(c, f_flightplan_pathGeod)));
     hashset(c, flightplanPrototype, "finish", naNewFunc(c, naNewCCode(c, f_flightplan_finish)));
+    hashset(c, flightplanPrototype, "indexOfWP", naNewFunc(c, naNewCCode(c, f_flightplan_indexOfWp)));
     
     waypointPrototype = naNewHash(c);
     naSave(c, waypointPrototype);
