@@ -23,6 +23,7 @@
 #include <simgear/math/sg_random.h>
 #include <simgear/misc/sg_path.hxx>
 #include <simgear/misc/sg_dir.hxx>
+#include <simgear/misc/SimpleMarkdown.hxx>
 #include <simgear/structure/commands.hxx>
 #include <simgear/math/sg_geodesy.hxx>
 #include <simgear/structure/event_mgr.hxx>
@@ -36,6 +37,7 @@
 #include "NasalSGPath.hxx"
 #include "NasalSys.hxx"
 #include "NasalSys_private.hxx"
+#include "NasalAircraft.hxx"
 #include "NasalModelData.hxx"
 #include "NasalPositioned.hxx"
 #include "NasalCanvas.hxx"
@@ -144,11 +146,14 @@ public:
   
   void invoke()
   {
+    if( _singleShot )
+      // Callback may restart the timer, so update status before callback is
+      // called (Prevent warnings of deleting not existing tasks from the
+      // event manager).
+      _isRunning = false;
+
     naRef *args = NULL;
     _sys->callMethod(_func, _self, 0, args, naNil() /* locals */);
-    if (_singleShot) {
-      _isRunning = false;
-    }
   }
   
   void setSingleShot(bool aSingleShot)
@@ -201,7 +206,8 @@ static char* readfile(const char* file, int* lenOut)
     return buf;
 }
 
-FGNasalSys::FGNasalSys()
+FGNasalSys::FGNasalSys() :
+    _inited(false)
 {
     nasalSys = this;
     _context = 0;
@@ -235,6 +241,11 @@ naRef FGNasalSys::call(naRef code, int argc, naRef* args, naRef locals)
   return callMethod(code, naNil(), argc, args, locals);
 }
 
+naRef FGNasalSys::callWithContext(naContext ctx, naRef code, int argc, naRef* args, naRef locals)
+{
+  return callMethodWithContext(ctx, code, naNil(), argc, args, locals);
+}
+
 // Does a naCall() in a new context.  Wrapped here to make lock
 // tracking easier.  Extension functions are called with the lock, but
 // we have to release it before making a new naCall().  So rather than
@@ -247,18 +258,30 @@ naRef FGNasalSys::callMethod(naRef code, naRef self, int argc, naRef* args, naRe
   return naCallMethod(code, self, argc, args, locals);
 }
 
+naRef FGNasalSys::callMethodWithContext(naContext ctx, naRef code, naRef self, int argc, naRef* args, naRef locals)
+{
+  return naCallMethodCtx(ctx, code, self, argc, args, locals);
+}
+
 FGNasalSys::~FGNasalSys()
 {
+    if (_inited) {
+        SG_LOG(SG_GENERAL, SG_ALERT, "Nasal was not shutdown");
+    }
     nasalSys = 0;
 }
 
 bool FGNasalSys::parseAndRun(const char* sourceCode)
 {
-    naRef code = parse("FGNasalSys::parseAndRun()", sourceCode,
+    naContext ctx = naNewContext();
+    naRef code = parse(ctx, "FGNasalSys::parseAndRun()", sourceCode,
                        strlen(sourceCode));
-    if(naIsNil(code))
+    if(naIsNil(code)) {
+        naFreeContext(ctx);
         return false;
-    call(code, 0, 0, naNil());
+    }
+    callWithContext(ctx, code, 0, 0, naNil());
+    naFreeContext(ctx);
     return true;
 }
 
@@ -291,21 +314,26 @@ FGNasalScript* FGNasalSys::parseScript(const char* src, const char* name)
 // This allows a Nasal object to hold onto a property path and use it
 // like a node object, e.g. setprop(ObjRoot, "size-parsecs", 2.02).  This
 // is the utility function that walks the property tree.
-// Future enhancement: support integer arguments to specify array
-// elements.
-static SGPropertyNode* findnode(naContext c, naRef* vec, int len)
+static SGPropertyNode* findnode(naContext c, naRef* vec, int len, bool create=false)
 {
     SGPropertyNode* p = globals->get_props();
     try {
         for(int i=0; i<len; i++) {
             naRef a = vec[i];
-            if(!naIsString(a)) return 0;
-            p = p->getNode(naStr_data(a));
+            if(!naIsString(a)) {
+                naRuntimeError(c, "bad argument to setprop/getprop path: expected a string");
+            }
+            naRef b = i < len-1 ? naNumValue(vec[i+1]) : naNil();
+            if (!naIsNil(b)) {
+                p = p->getNode(naStr_data(a), (int)b.num, create);
+                i++;
+            } else {
+                p = p->getNode(naStr_data(a), create);
+            }
             if(p == 0) return 0;
         }
     } catch (const string& err) {
         naRuntimeError(c, (char *)err.c_str());
-        return 0;
     }
     return p;
 }
@@ -316,7 +344,10 @@ static SGPropertyNode* findnode(naContext c, naRef* vec, int len)
 static naRef f_getprop(naContext c, naRef me, int argc, naRef* args)
 {
     using namespace simgear;
-    const SGPropertyNode* p = findnode(c, args, argc);
+    if (argc < 1) {
+        naRuntimeError(c, "getprop() expects at least 1 argument");
+    }
+    const SGPropertyNode* p = findnode(c, args, argc, false);
     if(!p) return naNil();
 
     switch(p->getType()) {
@@ -352,45 +383,29 @@ static naRef f_getprop(naContext c, naRef me, int argc, naRef* args)
 // final argument.
 static naRef f_setprop(naContext c, naRef me, int argc, naRef* args)
 {
-#define BUFLEN 1024
-    char buf[BUFLEN + 1];
-    buf[BUFLEN] = 0;
-    char* p = buf;
-    int buflen = BUFLEN;
-    if(argc < 2) naRuntimeError(c, "setprop() expects at least 2 arguments");
-    for(int i=0; i<argc-1; i++) {
-        naRef s = naStringValue(c, args[i]);
-        if(naIsNil(s)) return naNil();
-        strncpy(p, naStr_data(s), buflen);
-        p += naStr_len(s);
-        buflen = BUFLEN - (p - buf);
-        if(i < (argc-2) && buflen > 0) {
-            *p++ = '/';
-            buflen--;
-        }
+    if (argc < 2) {
+        naRuntimeError(c, "setprop() expects at least 2 arguments");
     }
+    naRef val = args[argc - 1];
+    SGPropertyNode* p = findnode(c, args, argc-1, true);
 
-    SGPropertyNode* props = globals->get_props();
-    naRef val = args[argc-1];
     bool result = false;
     try {
-        if(naIsString(val)) result = props->setStringValue(buf, naStr_data(val));
+        if(naIsString(val)) result = p->setStringValue(naStr_data(val));
         else {
-            naRef n = naNumValue(val);
-            if(naIsNil(n))
+            if(!naIsNum(val))
                 naRuntimeError(c, "setprop() value is not string or number");
                 
-            if (SGMisc<double>::isNaN(n.num)) {
+            if (SGMisc<double>::isNaN(val.num)) {
                 naRuntimeError(c, "setprop() passed a NaN");
             }
             
-            result = props->setDoubleValue(buf, n.num);
+            result = p->setDoubleValue(val.num);
         }
     } catch (const string& err) {
         naRuntimeError(c, (char *)err.c_str());
     }
     return naNum(result);
-#undef BUFLEN
 }
 
 // print() extension function.  Concatenates and prints its arguments
@@ -443,14 +458,13 @@ static naRef f_fgcommand(naContext c, naRef me, int argc, naRef* args)
     naRef props = argc > 1 ? args[1] : naNil();
     if(!naIsString(cmd) || (!naIsNil(props) && !naIsGhost(props)))
         naRuntimeError(c, "bad arguments to fgcommand()");
-    SGPropertyNode_ptr tmp, *node;
+    SGPropertyNode_ptr node;
     if(!naIsNil(props))
-        node = (SGPropertyNode_ptr*)naGhost_ptr(props);
-    else {
-        tmp = new SGPropertyNode();
-        node = &tmp;
-    }
-    return naNum(globals->get_commands()->execute(naStr_data(cmd), *node));
+        node = static_cast<SGPropertyNode*>(naGhost_ptr(props));
+    else
+        node = new SGPropertyNode;
+
+    return naNum(globals->get_commands()->execute(naStr_data(cmd), node));
 }
 
 // settimer(func, dt, simtime) extension function.  Falls through to
@@ -476,7 +490,7 @@ static naRef f_makeTimer(naContext c, naRef me, int argc, naRef* args)
   }
   
   TimerObj* timerObj = new TimerObj(nasalSys, func, self, args[0].num);
-  return NasalTimerObj::create(c, timerObj);
+  return nasal::to_nasal(c, timerObj);
 }
 
 // setlistener(func, property, bool) extension function.  Falls through to
@@ -501,7 +515,7 @@ static naRef f_cmdarg(naContext c, naRef me, int argc, naRef* args)
 }
 
 // Sets up a property interpolation.  The first argument is either a
-// ghost (SGPropertyNode_ptr*) or a string (global property path) to
+// ghost (SGPropertyNode*) or a string (global property path) to
 // interpolate.  The second argument is a vector of pairs of
 // value/delta numbers.
 static naRef f_interpolate(naContext c, naRef me, int argc, naRef* args)
@@ -509,7 +523,7 @@ static naRef f_interpolate(naContext c, naRef me, int argc, naRef* args)
   SGPropertyNode* node;
   naRef prop = argc > 0 ? args[0] : naNil();
   if(naIsString(prop)) node = fgGetNode(naStr_data(prop), true);
-  else if(naIsGhost(prop)) node = *(SGPropertyNode_ptr*)naGhost_ptr(prop);
+  else if(naIsGhost(prop)) node = static_cast<SGPropertyNode*>(naGhost_ptr(prop));
   else return naNil();
 
   naRef curve = argc > 1 ? args[1] : naNil();
@@ -686,6 +700,35 @@ static naRef f_parsexml(naContext c, naRef me, int argc, naRef* args)
     return naStr_fromdata(naNewString(c), const_cast<char*>(file), strlen(file));
 }
 
+/**
+ * Parse very simple and small subset of markdown
+ *
+ * parse_markdown(src)
+ */
+static naRef f_parse_markdown(naContext c, naRef me, int argc, naRef* args)
+{
+  nasal::CallContext ctx(c, me, argc, args);
+  return ctx.to_nasal(
+    simgear::SimpleMarkdown::parse(ctx.requireArg<std::string>(0))
+  );
+}
+
+/**
+ * Create md5 hash from given string
+ *
+ * md5(str)
+ */
+static naRef f_md5(naContext c, naRef me, int argc, naRef* args)
+{
+  if( argc != 1 || !naIsString(args[0]) )
+    naRuntimeError(c, "md5(): wrong type or number of arguments");
+
+  return nasal::to_nasal(
+    c,
+    simgear::strutils::md5(naStr_data(args[0]), naStr_len(args[0]))
+  );
+}
+
 // Return UNIX epoch time in seconds.
 static naRef f_systime(naContext c, naRef me, int argc, naRef* args)
 {
@@ -724,6 +767,8 @@ static struct { const char* name; naCFunction func; } funcs[] = {
     { "resolvepath", f_resolveDataPath },
     { "finddata", f_findDataDir },
     { "parsexml", f_parsexml },
+    { "parse_markdown", f_parse_markdown },
+    { "md5", f_md5 },
     { "systime", f_systime },
     { 0, 0 }
 };
@@ -740,6 +785,9 @@ void FGNasalSys::setCmdArg(SGPropertyNode* aNode)
 
 void FGNasalSys::init()
 {
+    if (_inited) {
+        SG_LOG(SG_GENERAL, SG_ALERT, "duplicate init of Nasal");
+    }
     int i;
 
     _context = naNewContext();
@@ -773,6 +821,7 @@ void FGNasalSys::init()
 
     initNasalPositioned(_globals, _context);
     initNasalPositioned_cppbind(_globals, _context);
+    initNasalAircraft(_globals, _context);
     NasalClipboard::init(this);
     initNasalCanvas(_globals, _context);
     initNasalCondition(_globals, _context);
@@ -803,7 +852,13 @@ void FGNasalSys::init()
     const char *s = "nasal-dir-initialized";
     SGPropertyNode *signal = fgGetNode("/sim/signals", true);
     signal->setBoolValue(s, true);
-    signal->removeChildren(s, false);
+    signal->removeChildren(s);
+
+    if( !checkIOrules() )
+    {
+      SG_LOG(SG_NASAL, SG_ALERT, "Required IOrules check failed.");
+      exit(-1);
+    }
 
     // Pull scripts out of the property tree, too
     loadPropertyScripts();
@@ -811,10 +866,16 @@ void FGNasalSys::init()
     // now Nasal modules are loaded, we can do some delayed work
     postinitNasalPositioned(_globals, _context);
     postinitNasalGUI(_globals, _context);
+    
+    _inited = true;
 }
 
 void FGNasalSys::shutdown()
 {
+    if (!_inited) {
+        return;
+    }
+    
     shutdownNasalPositioned();
     
     map<int, FGNasalListener *>::iterator it, end = _listener.end();
@@ -845,7 +906,7 @@ void FGNasalSys::shutdown()
     _globals = naNil();    
     
     naGC();
-    
+    _inited = false;
 }
 
 naRef FGNasalSys::wrappedPropsNode(SGPropertyNode* aProps)
@@ -858,7 +919,7 @@ naRef FGNasalSys::wrappedPropsNode(SGPropertyNode* aProps)
     naRef args[1];
     args[0] = propNodeGhost(aProps);
     naContext ctx = naNewContext();
-    naRef wrapped = naCall(ctx, _wrappedNodeFunc, 1, args, naNil(), naNil());
+    naRef wrapped = naCallMethodCtx(ctx, _wrappedNodeFunc, naNil(), 1, args, naNil());
     naFreeContext(ctx);
     return wrapped;
 }
@@ -890,6 +951,9 @@ void FGNasalSys::update(double)
         _unloadList.pop()->unload();
     }
 
+    // Destroy all queued ghosts
+    nasal::ghostProcessDestroyList();
+
     // The global context is a legacy thing.  We use dynamically
     // created contexts for naCall() now, so that we can call them
     // recursively.  But there are still spots that want to use it for
@@ -1067,11 +1131,13 @@ bool FGNasalSys::createModule(const char* moduleName, const char* fileName,
                               const SGPropertyNode* cmdarg,
                               int argc, naRef* args)
 {
-    naRef code = parse(fileName, src, len);
-    if(naIsNil(code))
-        return false;
-
     naContext ctx = naNewContext();
+    naRef code = parse(ctx, fileName, src, len);
+    if(naIsNil(code)) {
+        naFreeContext(ctx);
+        return false;
+    }
+
     
     // See if we already have a module hash to use.  This allows the
     // user to, for example, add functions to the built-in math
@@ -1084,7 +1150,7 @@ bool FGNasalSys::createModule(const char* moduleName, const char* fileName,
 
     _cmdArg = (SGPropertyNode*)cmdarg;
 
-    call(code, argc, args, locals);
+    callWithContext(ctx, code, argc, args, locals);
     hashset(_globals, moduleName, locals);
     
     naFreeContext(ctx);
@@ -1093,6 +1159,12 @@ bool FGNasalSys::createModule(const char* moduleName, const char* fileName,
 
 void FGNasalSys::deleteModule(const char* moduleName)
 {
+    if (!_inited) {
+        // can occur on shutdown due to us being shutdown first, but other
+        // subsystems having Nasal objects.
+        return;
+    }
+    
     naContext ctx = naNewContext();
     naRef modname = naNewString(ctx);
     naStr_fromdata(modname, (char*)moduleName, strlen(moduleName));
@@ -1100,10 +1172,9 @@ void FGNasalSys::deleteModule(const char* moduleName)
     naFreeContext(ctx);
 }
 
-naRef FGNasalSys::parse(const char* filename, const char* buf, int len)
+naRef FGNasalSys::parse(naContext ctx, const char* filename, const char* buf, int len)
 {
     int errLine = -1;
-    naContext ctx = naNewContext();
     naRef srcfile = naNewString(ctx);
     naStr_fromdata(srcfile, (char*)filename, strlen(filename));
     naRef code = naParseCode(ctx, srcfile, 1, (char*)buf, len, &errLine);
@@ -1111,14 +1182,11 @@ naRef FGNasalSys::parse(const char* filename, const char* buf, int len)
         SG_LOG(SG_NASAL, SG_ALERT,
                "Nasal parse error: " << naGetError(ctx) <<
                " in "<< filename <<", line " << errLine);
-        naFreeContext(ctx);
         return naNil();
     }
 
     // Bind to the global namespace before returning
-    naRef bound = naBindFunction(ctx, code, _globals);
-    naFreeContext(ctx);
-    return bound;
+    return naBindFunction(ctx, code, _globals);
 }
 
 bool FGNasalSys::handleCommand( const char* moduleName,
@@ -1126,22 +1194,24 @@ bool FGNasalSys::handleCommand( const char* moduleName,
                                 const char* src,
                                 const SGPropertyNode* arg )
 {
-    naRef code = parse(fileName, src, strlen(src));
-    if(naIsNil(code)) return false;
+    naContext ctx = naNewContext();
+    naRef code = parse(ctx, fileName, src, strlen(src));
+    if(naIsNil(code)) {
+        naFreeContext(ctx);
+        return false;
+    }
 
     // Commands can be run "in" a module.  Make sure that module
     // exists, and set it up as the local variables hash for the
     // command.
     naRef locals = naNil();
     if(moduleName[0]) {
-        naContext ctx = naNewContext();
         naRef modname = naNewString(ctx);
         naStr_fromdata(modname, (char*)moduleName, strlen(moduleName));
         if(!naHash_get(_globals, modname, &locals)) {
             locals = naNewHash(ctx);
             naHash_set(_globals, modname, locals);
         }
-        naFreeContext(ctx);
     }
 
     // Cache this command's argument for inspection via cmdarg().  For
@@ -1149,7 +1219,8 @@ bool FGNasalSys::handleCommand( const char* moduleName,
     // code doesn't need it.
     _cmdArg = (SGPropertyNode*)arg;
 
-    call(code, 0, 0, locals);
+    callWithContext(ctx, code, 0, 0, locals);
+    naFreeContext(ctx);
     return true;
 }
 
@@ -1159,7 +1230,7 @@ bool FGNasalSys::handleCommand(const SGPropertyNode* arg)
   const char* moduleName = arg->getStringValue("module");
 
   return handleCommand( moduleName,
-                        arg ? arg->getPath(true).c_str() : moduleName,
+                        arg->getPath(true).c_str(),
                         src,
                         arg );
 }
@@ -1218,6 +1289,47 @@ void FGNasalSys::gcRelease(int key)
     naGCRelease(key);
 }
 
+//------------------------------------------------------------------------------
+bool FGNasalSys::checkIOrules()
+{
+  // Ensure IOrules and path validation are working properly by trying to
+  // access a folder/file which should never be accessible.
+  const char* no_access_path =
+#ifdef _WIN32
+    "Z:"
+#endif
+    "/do-not-access";
+
+  bool success = true;
+
+  // write access
+  if( fgValidatePath(no_access_path, true) )
+  {
+    success = false;
+    SG_LOG
+    (
+      SG_GENERAL,
+      SG_ALERT,
+      "Check your IOrules! (write to '" << no_access_path << "' is allowed)"
+    );
+  }
+
+  // read access
+  if( fgValidatePath(no_access_path, false) )
+  {
+    success = false;
+    SG_LOG
+    (
+      SG_GENERAL,
+      SG_ALERT,
+      "Check your IOrules! (read from '" << no_access_path << "' is allowed)"
+    );
+  }
+
+  return success;
+}
+
+//------------------------------------------------------------------------------
 void FGNasalSys::NasalTimer::timerExpired()
 {
     nasal->handleTimer(this);
@@ -1228,7 +1340,7 @@ int FGNasalSys::_listenerId = 0;
 
 // setlistener(<property>, <func> [, <initial=0> [, <persistent=1>]])
 // Attaches a callback function to a property (specified as a global
-// property path string or a SGPropertyNode_ptr* ghost). If the third,
+// property path string or a SGPropertyNode* ghost). If the third,
 // optional argument (default=0) is set to 1, then the function is also
 // called initially. If the fourth, optional argument is set to 0, then the
 // function is only called when the property node value actually changes.
@@ -1241,7 +1353,7 @@ naRef FGNasalSys::setListener(naContext c, int argc, naRef* args)
     SGPropertyNode_ptr node;
     naRef prop = argc > 0 ? args[0] : naNil();
     if(naIsString(prop)) node = fgGetNode(naStr_data(prop), true);
-    else if(naIsGhost(prop)) node = *(SGPropertyNode_ptr*)naGhost_ptr(prop);
+    else if(naIsGhost(prop)) node = static_cast<SGPropertyNode*>(naGhost_ptr(prop));
     else {
         naRuntimeError(c, "setlistener() with invalid property argument");
         return naNil();
