@@ -25,6 +25,10 @@
 
 #include <sstream>
 
+#if defined(HAVE_QT) && defined(SG_MAC)
+    #include <osgViewer/api/Cocoa/GraphicsWindowCocoa>
+#endif
+
 using namespace std;
 using namespace osg;
 
@@ -41,6 +45,10 @@ ref_ptr<WindowBuilder> WindowBuilder::windowBuilder;
 
 const string WindowBuilder::defaultWindowName("FlightGear");
 
+// default to true (historical behaviour), we will clear the flag if
+// we run another GUI.
+bool WindowBuilder::poseAsStandaloneApp = true;
+
 void WindowBuilder::initWindowBuilder(bool stencil)
 {
     windowBuilder = new WindowBuilder(stencil);
@@ -65,13 +73,10 @@ WindowBuilder::makeDefaultTraits(bool stencil)
         traits->screenNum = 0;
 
     int bpp = fgGetInt("/sim/rendering/bits-per-pixel");
-    bool alpha = fgGetBool("/sim/rendering/clouds3d-enable");
     int cbits = (bpp <= 16) ?  5 :  8;
     int zbits = (bpp <= 16) ? 16 : 24;
     traits->red = traits->green = traits->blue = cbits;
     traits->depth = zbits;
-    if (alpha)
-        traits->alpha = 8;
 
     if (stencil)
         traits->stencil = 8;
@@ -177,6 +182,7 @@ GraphicsWindow* WindowBuilder::buildWindow(const SGPropertyNode* winNode)
     traitsSet |= setFromProperty(traits->screenNum, winNode, "screen");
 
     const SGPropertyNode* fullscreenNode = winNode->getNode("fullscreen");
+    const SGPropertyNode* orrNode = winNode->getNode("overrideRedirect");
 
     if (fullscreenNode && fullscreenNode->getBoolValue()) {
         // fullscreen mode
@@ -187,6 +193,8 @@ GraphicsWindow* WindowBuilder::buildWindow(const SGPropertyNode* winNode)
         traits->width = width;
         traits->height = height;
         traits->supportsResize = false;
+	bool overrideRedirect = orrNode && orrNode->getBoolValue();
+	traits->overrideRedirect = overrideRedirect;
         traits->x = 0;
         traits->y = 0;
         traitsSet = 1;
@@ -244,7 +252,18 @@ GraphicsWindow* WindowBuilder::getDefaultWindow()
     GraphicsContext::Traits* traits
         = new GraphicsContext::Traits(*defaultTraits);
     traits->windowName = "FlightGear";
-    
+
+#if defined(HAVE_QT) && defined(SG_MAC)
+    int flags = osgViewer::GraphicsWindowCocoa::WindowData::CheckForEvents;
+
+    // avoid both QApplication and OSG::CocoaViewer doing single-application
+    // init (Apple menu, making front process, etc)
+    if (poseAsStandaloneApp) {
+        flags |= osgViewer::GraphicsWindowCocoa::WindowData::PoseAsStandaloneApp;
+    }
+    traits->inheritedWindowData = new osgViewer::GraphicsWindowCocoa::WindowData(flags);
+#endif
+
     GraphicsContext* gc = GraphicsContext::createGraphicsContext(traits);
     if (gc) {
         defaultWindow = WindowSystemAdapter::getWSA()
@@ -255,4 +274,10 @@ GraphicsWindow* WindowBuilder::getDefaultWindow()
         return 0;
     }
 }
+
+void WindowBuilder::setPoseAsStandaloneApp(bool b)
+{
+    poseAsStandaloneApp = b;
 }
+
+} // of namespace flightgear
