@@ -86,9 +86,6 @@
 #include <simgear/timing/sg_time.hxx>
 #include <simgear/ephemeris/ephemeris.hxx>
 #include <simgear/math/sg_random.h>
-#ifdef FG_JPEG_SERVER
-#include <simgear/screen/jpgfactory.hxx>
-#endif
 
 #include <Time/light.hxx>
 #include <Time/light.hxx>
@@ -385,13 +382,6 @@ public:
 };
 
 bool FGScenerySwitchCallback::scenery_enabled = false;
-                                    
-#ifdef FG_JPEG_SERVER
-static void updateRenderer()
-{
-    globals->get_renderer()->update();
-}
-#endif
 
 FGRenderer::FGRenderer() :
     _sky(NULL),
@@ -406,16 +396,15 @@ FGRenderer::FGRenderer() :
     _shadowDistances( new osg::Uniform( "fg_ShadowDistances", osg::Vec4f(5.0, 50.0, 500.0, 5000.0 ) ) ),
     _depthInColor( new osg::Uniform( "fg_DepthInColor", false ) )
 {
-#ifdef FG_JPEG_SERVER
-   jpgRenderFrame = updateRenderer;
-#endif
-    
     // it's not the real root, whatever that means
     _root = new osg::Group;
     _root->setName("fakeRoot");
 
     _updateVisitor = new SGUpdateVisitor;
-    _root = new osg::Group;
+  
+  // when Rembrandt is enabled, we use this group to access the whole
+  // scene. Since the only child is the _viewerSceneRoot, we could
+  // simply copy the reference, we don't need the additional group.
     _deferredRealRoot = new osg::Group;
     
    _numCascades = 4;
@@ -437,9 +426,6 @@ FGRenderer::~FGRenderer()
         getViewer()->setSceneData(new osg::Group);
     }
     
-#ifdef FG_JPEG_SERVER
-   jpgRenderFrame = NULL;
-#endif
     delete _sky;
 }
 
@@ -568,7 +554,6 @@ FGRenderer::init( void )
     _enhanced_lighting    = fgGetNode("/sim/rendering/enhanced-lighting", true);
     _distance_attenuation = fgGetNode("/sim/rendering/distance-attenuation", true);
     _horizon_effect       = fgGetNode("/sim/rendering/horizon-effect", true);
-    _textures             = fgGetNode("/sim/rendering/textures", true);
 
     _altitude_ft = fgGetNode("/position/altitude-ft", true);
 
@@ -1407,6 +1392,46 @@ CameraInfo* FGRenderer::buildCameraFromRenderingPipeline(FGRenderingPipeline* rp
     return info;
 }
 
+void FGRenderer::setupRoot()
+{
+    osg::StateSet* stateSet = _root->getOrCreateStateSet();
+    
+    stateSet->setMode(GL_LIGHTING, osg::StateAttribute::OFF);
+    
+    stateSet->setAttribute(new osg::Depth(osg::Depth::LESS));
+    stateSet->setMode(GL_DEPTH_TEST, osg::StateAttribute::OFF);
+    
+    stateSet->setAttribute(new osg::BlendFunc);
+    stateSet->setMode(GL_BLEND, osg::StateAttribute::OFF);
+    
+    stateSet->setMode(GL_FOG, osg::StateAttribute::OFF);
+    
+    // this will be set below
+    stateSet->setMode(GL_NORMALIZE, osg::StateAttribute::OFF);
+    
+    osg::Material* material = new osg::Material;
+    stateSet->setAttribute(material);
+    
+    stateSet->setTextureAttribute(0, new osg::TexEnv);
+    stateSet->setTextureMode(0, GL_TEXTURE_2D, osg::StateAttribute::OFF);
+    
+    osg::Hint* hint = new osg::Hint(GL_FOG_HINT, GL_DONT_CARE);
+    hint->setUpdateCallback(new FGHintUpdateCallback("/sim/rendering/fog"));
+    stateSet->setAttribute(hint);
+    hint = new osg::Hint(GL_POLYGON_SMOOTH_HINT, GL_DONT_CARE);
+    hint->setUpdateCallback(new FGHintUpdateCallback("/sim/rendering/polygon-smooth"));
+    stateSet->setAttribute(hint);
+    hint = new osg::Hint(GL_LINE_SMOOTH_HINT, GL_DONT_CARE);
+    hint->setUpdateCallback(new FGHintUpdateCallback("/sim/rendering/line-smooth"));
+    stateSet->setAttribute(hint);
+    hint = new osg::Hint(GL_POINT_SMOOTH_HINT, GL_DONT_CARE);
+    hint->setUpdateCallback(new FGHintUpdateCallback("/sim/rendering/point-smooth"));
+    stateSet->setAttribute(hint);
+    hint = new osg::Hint(GL_PERSPECTIVE_CORRECTION_HINT, GL_DONT_CARE);
+    hint->setUpdateCallback(new FGHintUpdateCallback("/sim/rendering/perspective-correction"));
+    stateSet->setAttribute(hint);
+}
+                                    
 void
 FGRenderer::setupView( void )
 {
@@ -1419,6 +1444,8 @@ FGRenderer::setupView( void )
     osg::PolygonOffset::setUnitsMultiplier(1);
     osg::PolygonOffset::setFactorMultiplier(1);
 
+    setupRoot();
+  
 // build the sky    
     // The sun and moon diameters are scaled down numbers of the
     // actual diameters. This was needed to fit both the sun and the
@@ -1437,55 +1464,7 @@ FGRenderer::setupView( void )
     viewer->getCamera()
         ->setComputeNearFarMode(osg::CullSettings::DO_NOT_COMPUTE_NEAR_FAR);
     
-    osg::StateSet* stateSet = _root->getOrCreateStateSet();
-
-    stateSet->setMode(GL_LIGHTING, osg::StateAttribute::OFF);
-    
-    stateSet->setAttribute(new osg::Depth(osg::Depth::LESS));
-    stateSet->setMode(GL_DEPTH_TEST, osg::StateAttribute::OFF);
-
-    stateSet->setAttribute(new osg::AlphaFunc(osg::AlphaFunc::GREATER, 0.01));
-    stateSet->setMode(GL_ALPHA_TEST, osg::StateAttribute::OFF);
-    stateSet->setAttribute(new osg::BlendFunc);
-    stateSet->setMode(GL_BLEND, osg::StateAttribute::OFF);
-
-    stateSet->setMode(GL_FOG, osg::StateAttribute::OFF);
-    
-    // this will be set below
-    stateSet->setMode(GL_NORMALIZE, osg::StateAttribute::OFF);
-
-    osg::Material* material = new osg::Material;
-    stateSet->setAttribute(material);
-    
-    stateSet->setTextureAttribute(0, new osg::TexEnv);
-    stateSet->setTextureMode(0, GL_TEXTURE_2D, osg::StateAttribute::OFF);
-
-    osg::Hint* hint = new osg::Hint(GL_FOG_HINT, GL_DONT_CARE);
-    hint->setUpdateCallback(new FGHintUpdateCallback("/sim/rendering/fog"));
-    stateSet->setAttribute(hint);
-    hint = new osg::Hint(GL_POLYGON_SMOOTH_HINT, GL_DONT_CARE);
-    hint->setUpdateCallback(new FGHintUpdateCallback("/sim/rendering/polygon-smooth"));
-    stateSet->setAttribute(hint);
-    hint = new osg::Hint(GL_LINE_SMOOTH_HINT, GL_DONT_CARE);
-    hint->setUpdateCallback(new FGHintUpdateCallback("/sim/rendering/line-smooth"));
-    stateSet->setAttribute(hint);
-    hint = new osg::Hint(GL_POINT_SMOOTH_HINT, GL_DONT_CARE);
-    hint->setUpdateCallback(new FGHintUpdateCallback("/sim/rendering/point-smooth"));
-    stateSet->setAttribute(hint);
-    hint = new osg::Hint(GL_PERSPECTIVE_CORRECTION_HINT, GL_DONT_CARE);
-    hint->setUpdateCallback(new FGHintUpdateCallback("/sim/rendering/perspective-correction"));
-    stateSet->setAttribute(hint);
-
-    osg::Group* sceneGroup = new osg::Group;
-    sceneGroup->setName("rendererScene");
-    sceneGroup->addChild(globals->get_scenery()->get_scene_graph());
-    sceneGroup->setNodeMask(~simgear::BACKGROUND_BIT);
-
-    //sceneGroup->addChild(thesky->getCloudRoot());
-
-    stateSet = sceneGroup->getOrCreateStateSet();
-    stateSet->setMode(GL_DEPTH_TEST, osg::StateAttribute::ON);
-
+  
     // need to update the light on every frame
     // OSG LightSource objects are rather confusing. OSG only supports
     // the 10 lights specified by OpenGL itself; if more than one
@@ -1496,7 +1475,7 @@ FGRenderer::setupView( void )
     // has the corresponding OpenGL light enabled: a LightSource will
     // affect geometry anywhere in the scene graph that has its light
     // number enabled in a state set. 
-    LightSource* lightSource = new LightSource;
+    osg::ref_ptr<LightSource> lightSource = new LightSource;
     lightSource->setName("FGLightSource");
     lightSource->getLight()->setDataVariance(Object::DYNAMIC);
     // relative because of CameraView being just a clever transform node
@@ -1506,7 +1485,7 @@ FGRenderer::setupView( void )
     _viewerSceneRoot->addChild(lightSource);
     
     // we need a white diffuse light for the phase of the moon
-    osg::LightSource* sunLight = new osg::LightSource;
+    osg::ref_ptr<LightSource> sunLight = new osg::LightSource;
     sunLight->setName("sunLightSource");
     sunLight->getLight()->setDataVariance(Object::DYNAMIC);
     sunLight->getLight()->setLightNum(1);
@@ -1516,20 +1495,22 @@ FGRenderer::setupView( void )
     
     // Hang a StateSet above the sky subgraph in order to turn off
     // light 0
-    Group* skyGroup = new Group;
-    skyGroup->setName("rendererSkyParent");
+    Group* skyGroup = _sky->getPreRoot();
     StateSet* skySS = skyGroup->getOrCreateStateSet();
     skySS->setMode(GL_LIGHT0, StateAttribute::OFF);
-    skyGroup->addChild(_sky->getPreRoot());
     sunLight->addChild(skyGroup);
     
-    _root->addChild(sceneGroup);
-    if ( _classicalRenderer )
+    if ( _classicalRenderer ) {
         _root->addChild(sunLight);
-    
-    // Clouds are added to the scene graph later
-    stateSet = globals->get_scenery()->get_scene_graph()->getOrCreateStateSet();
-    stateSet->setMode(GL_ALPHA_TEST, osg::StateAttribute::ON);
+    }
+  
+    osg::Group* sceneGroup = globals->get_scenery()->get_scene_graph();
+    sceneGroup->setName("rendererScene");
+    sceneGroup->setNodeMask(~simgear::BACKGROUND_BIT);
+    _root->addChild(sceneGroup);
+  
+    // setup state-set for main scenery (including models and aircraft)
+    osg::StateSet* stateSet = sceneGroup->getOrCreateStateSet();
     stateSet->setMode(GL_LIGHTING, osg::StateAttribute::ON);
     stateSet->setMode(GL_DEPTH_TEST, osg::StateAttribute::ON);
 
@@ -1553,14 +1534,13 @@ FGRenderer::setupView( void )
     // plug in the GUI
     osg::Camera* guiCamera = getGUICamera(CameraGroup::getDefault());
     if (guiCamera) {
-        
-        osg::Geode* geode = new osg::Geode;
-        geode->addDrawable(new SGPuDrawable);
-        geode->addDrawable(new SGHUDDrawable);
-        guiCamera->addChild(geode);
-      
-        
-      guiCamera->addChild(FGPanelNode::create2DPanelNode());
+      osg::Geode* geode = new osg::Geode;
+      geode->addDrawable(new SGHUDDrawable);
+      geode->addDrawable(new SGPuDrawable);
+
+      // Draw first (eg. before Canvas GUI)
+      guiCamera->insertChild(0, geode);
+      guiCamera->insertChild(0, FGPanelNode::create2DPanelNode());
     }
     
     osg::Switch* sw = new osg::Switch;
@@ -1571,10 +1551,11 @@ FGRenderer::setupView( void )
     // The clouds are attached directly to the scene graph root
     // because, in theory, they don't want the same default state set
     // as the rest of the scene. This may not be true in practice.
-	if ( _classicalRenderer ) {
-		_viewerSceneRoot->addChild(_sky->getCloudRoot());
-		_viewerSceneRoot->addChild(FGCreateRedoutNode());
-	}
+    if ( _classicalRenderer ) {
+      _viewerSceneRoot->addChild(_sky->getCloudRoot());
+      _viewerSceneRoot->addChild(FGCreateRedoutNode());
+    }
+  
     // Attach empty program to the scene root so that shader programs
     // don't leak into state sets (effects) that shouldn't have one.
     stateSet = _viewerSceneRoot->getOrCreateStateSet();
@@ -1635,10 +1616,14 @@ FGRenderer::update( ) {
   
     osg::Camera *camera = viewer->getCamera();
 
-    if ( _textures->getBoolValue() ) {
-        SGVec4f clearColor(l->adj_fog_color());
-        camera->setClearColor(toOsg(clearColor));
-    }
+    osg::Vec4 clear_color = _altitude_ft->getDoubleValue() < 250000
+                          ? toOsg(l->adj_fog_color())
+                          // skydome ends at ~262000ft (default rendering)
+                          // ~328000 ft (ALS) and would produce a strange
+                          // looking greyish space -> black looks much
+                          // better :-)
+                          : osg::Vec4(0, 0, 0, 1);
+    camera->setClearColor(clear_color);
 
     updateSky();
     
